@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: sv_reminder.pl,v 1.7 2005/06/30 16:33:50 toddy Exp $
+# $Id: sv_reminder.pl,v 1.8 2005/09/19 11:11:39 yeupou Exp $
 #
 #  Copyright 2004 (c) Mathieu Roy <yeupou--at--gnu.org> 
 #
@@ -366,6 +366,11 @@ if ($sys_https_host) {
 while (my ($user_id,) = each(%user)) {
     $count++;
     last if $count > $max;
+    
+    # skip the entry if there is no user_id
+    next unless $user_id;
+    # skip the entry if there is no user_id email
+    next unless $user_email{$user_id};
 
     my $title = $sys_name." Reminder";
 
@@ -409,10 +414,12 @@ too long, high priority, etc...).
 # Now reset lastsent value. 
 unless ($debug) {
     foreach my $user_id (@user_case2) {
+	next unless $user_id;
 	SetDBSettings("user_preferences", "user_id='$user_id' AND preference_name='batch_lastsent'", "preference_value='".$now."'");
     }
 
     foreach my $group_id (@group_case3) {
+	next unless $group_id;
 	SetDBSettings("group_preferences", "group_id='$group_id' AND preference_name='batch_lastsent'", "preference_value='".$now."'");
     }
 }
