@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: sv_users.pl,v 1.54 2005/07/01 10:25:46 zerodeux Exp $
+# $Id: sv_users.pl,v 1.55 2005/09/11 14:17:05 yeupou Exp $
 #
 #  Copyright 2001-2005 (c) Loic Dachary <loic--gnu.org> (sv_cvs.pl)
 #                          Mathieu Roy <yeupou--gnu.org> 
@@ -518,8 +518,10 @@ foreach my $user (@well_known) {
     
     my %seen_before = (); # remove duplicates
     @groups_list = grep { ! $seen_before{$_} ++ } @groups_list;
+   
     
-
+    # Update groups: check if the user is removed from a group in the
+    # database.
     if (@groups_list ne @groups_list_etc) {
 	my $groups = join(",", @groups_list);
 	
@@ -533,10 +535,6 @@ foreach my $user (@well_known) {
     } else {
 	print "DBG update: NO UPDATE for user $user that belongs to \t[db+sys]\t".join(", ", @groups_list)."\t[sys]\t".join(", ", @groups_list_etc)."\n" if $debug;
     }
-    
-    # Update groups: check if the user is removed from a group in the
-    # database.
-
 
     # Update name (name, email) if not accurate.
     my $password_realname = $etc_password{$user}->[6];
@@ -611,12 +609,15 @@ foreach my $user (@well_known) {
 	    foreach my $thisgroup (@{$db_user_group{$user}}) {
 		
 		# Add the group to the list of update candidate, unless
-		# already there, if there were changes
-		if ($keys_differs) {
+		# already there, if there were changes.
+		# Add the group to the list of update candidates if the 
+		# user joined/quitted a group.
+		if ($keys_differs or @groups_list ne @groups_list_etc) {
 		    $gpg_keyrings_to_rebuild{$thisgroup} = 1
 			unless $gpg_keyrings_to_rebuild{$thisgroup};
 		}
 		
+		
 		# Store the key content if it is something worth being
 		# registered, in any cases (other users can cause the
 		# update to be necessary, so it's irrelevant whether this
