@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: sv_update_conf.pl,v 1.33 2005/06/30 16:33:51 toddy Exp $
+# $Id: sv_update_conf.pl,v 1.38 2005/09/21 12:56:23 yeupou Exp $
 #
 #  Copyright 2002-2005 (c) Mathieu Roy <yeupou--at--gnu.org>
 #                          Sylvain Beucler <beuc--beuc.net>
@@ -211,10 +211,7 @@ if ($recreate) {
       AskSetting("sys_default_domain", "Default hostname", "It must be the naked form of the domain", "savannah.gnu.org", $sys_default_domain);
 
       AskSetting("sys_https_host", "HTTPS hostname", "It must be the naked form of the domain. If you do not have https server, comment out", "savannah.gnu.org, \$sys_default_domain", $sys_https_host);
-# Seem useless, yeupou, 2005-06-22
-#      AskSetting("sys_https_port", "HTTPS port", "Port number. If you do not have https server, comment out", "443", $sys_https_port);
-
-      AskSetting("sys_brother_domain", "Brother hostname", "You can run Savannah with two different domain names. You'll be able to write a different configuration for each one. The two brother/companion sites will share the same database. /etc/savannah/local.inc.pl is far more important since the default access to the database is done using this one. Here you can let your savannah installation aware of the existence of a brother/companion site, so while people login, it will be allowed to them to login on both site in one click. If you do not have brother/companion site, comment out. If you do not understand what is it about, you probably do not need that feature, comment out.", "savannah.nongnu.org", $sys_brother_domain);
+      AskSetting("sys_brother_domain", "Brother hostname", "You can run Savane with two different domain names. You will be able to write a different configuration for each one. The two brother/companion sites will share the same database. If you do not have brother/companion site, comment out. If you do not understand what is it about, you probably do not need that feature, comment out.", "savannah.nongnu.org", $sys_brother_domain);
 
     
       AskSetting("sys_dbhost", "SQL database hostname", "--", "localhost", $sys_dbhost);
@@ -226,28 +223,26 @@ if ($recreate) {
 
     ## INSTALLATION PATHS ##
     
-      AskSetting("sys_www_topdir", "Path to the PHP frontend top directory (in the source package, it's the directory savane/frontend/php)", "IT MUST BE AN ABSOLUTE PATH NAME", "/usr/local/sv/src/savane", $sys_www_topdir);
+      AskSetting("sys_www_topdir", "Path to the PHP frontend top directory (in the source package, it is the directory frontend/php)", "IT MUST BE AN ABSOLUTE PATH NAME", "/usr/src/savane/frontend/php", $sys_www_topdir);
       AskSetting("sys_url_topdir", "Default web directory", "Suffix appended to the default domain", "/", $sys_url_topdir);
-      AskSetting("sys_incdir", "Local dir of the site-specific content", "--", "/etc/savannah/savannah-content", $sys_incdir);
-      AskSetting("sys_miscdir", "Misc directory", "Local dir where dumps will be stored etc", "/subversions/sv", $sys_miscdir);
-
+      AskSetting("sys_incdir", "Directory contain the site-specific content", "--", "/etc/savannah/savannah-content", $sys_incdir);
 
     ## GUI ##
 
-      AskSetting("sys_name", "Platform name", "Name shown on public pages for the whole service", "A New Savane Installation", $sys_name, 1);
+      AskSetting("sys_name", "Platform name", "Name shown on public pages for the whole service", "New Savane Installation", $sys_name, 1);
       AskSetting("sys_unix_group_name", "Server administration project unix name", "Unix group name of the meta-project used for administration. Take care to avoid conflicts with group name existing on your system, take care to select a valid unix group name: no checks will be done for this project unix group name.", "admin", $sys_unix_group_name);
 
-      AskSetting("sys_default_locale", "Default locale", "It must be a valid locale name", "french", $sys_default_locale);
+      AskSetting("sys_default_locale", "Default locale", "It must be a valid locale name.", "french", $sys_default_locale);
       AskSetting("sys_datefmt", "Date format", "Date formatting. If you want to use the default locale formating, comment out (it's usually a good idea)", "Y-M-d H:i", $sys_datefmt);
 
-      AskSetting("sys_themedefault", "Default theme", "--", "light", $sys_themedefault);
+      AskSetting("sys_themedefault", "Default theme", "--", "light2", $sys_themedefault);
       AskSetting("sys_logo_name", "Logo name", "The engine will search for a file like savannah/frontend/php/images/\$theme.theme/\$sys_logo_name. If you do not want any logo, comment out", "floating.png", $sys_logo_name);
 
 
     ## MAIL, MAILING-LIST ##
 
       AskSetting("sys_mail_domain", "Mail domain", "--", "gnu.org, \$sys_default_domain", $sys_mail_domain);
-      AskSetting("sys_mail_admin", "Admin mail address", "The mail domain we'll be added to this username", "savannah-hackers", $sys_mail_admin);
+      AskSetting("sys_mail_admin", "Admin mail address", "The mail domain we'll be added to this username", "help", $sys_mail_admin);
       AskSetting("sys_mail_replyto", "No reply address used in the trackers", "--", "NO-REPLY.INVALID-ADDRESS", $sys_replyto);
       AskSetting("sys_mail_list", "[BACKEND SPECIFIC] List of emails", "If you do not want such file to be updated by the backend, comment out", "/etc/email-addresses", $sys_mail_list);
       AskSetting("sys_mail_aliases", "[BACKEND SPECIFIC] List of emails aliases", "If you do not want such file to be updated by the backend, comment out", "/etc/aliases", $sys_mail_aliases);
@@ -255,7 +250,7 @@ if ($recreate) {
 
     ## USERS ACCOUNTS ##
     
-    AskSetting("sys_use_pamauth", "PAM support", "AFS, Kerberos (...) authentication can be made via PAM", "no", $sys_use_pamauth);
+    AskSetting("sys_use_pamauth", "PAM support", "AFS, Kerberos (...) authentication can be made via PAM. If you need users to log in the web interface using PAM, this is what you want. If you do not know what it is about, comment out.", "no", $sys_use_pamauth);
     AskSetting("sys_use_krb5", "Kerberos 5", "If you do not know what it is about, you surely don't have to deal with a kerberos server, say no here.", "no", $sys_use_krb5);
     
     AskSetting("sys_homedir", "[BACKEND SPECIFIC] User home directory", "Usually /home. You can uncomment if you do not plan to provide accounts", "/home", $sys_homedir);
@@ -285,12 +280,7 @@ if ($recreate) {
         # data, for security reasons, on most installations.
 
       AskSetting("sys_viewcvs_conffile", "[BACKEND SPECIFIC] Viewcvs configuration file", "Path to the viewcvs conffile. If you do not use viewcvs or if you do not want the fordibben setting of this configuration file to be edit by Savannah, comment out", "/etc/viewcvs/viewcvs.conf", $sys_viewcvs_conffile);
-      #AskSetting("sys_webalizer_dir", "Statistics: webalizer dir", "Where webalizer store its output. If you do not have webalizer, comment out", "/subversions/sv/src/savannah/www/webalizer", $sys_webalizer_dir);
-      #AskSetting("sys_webalizer_url", "Statistics: webalizer url", "http url for webalizer output. If you do not have webalizer, comment out", "http://savannah.gnu.org/webalizer", $sys_webalizer_url);
-      #AskSetting("sys_mrtg_dir", "Statistics: mrtg dir", "Where mrtg store its output. If you do not have mrtg, comment out", "/home/www/html/mrtg", $sys_mrtg_dir);
-      #AskSetting("sys_mrtg_url", "Statistics: mrtg url", "http url for webalizer output. If you do not have mrtg, comment out", "http://subversions.gnu.org/mrtg", $sys_mrtg_url);
       AskSetting("sys_use_google", "Google search", "Add a search via google option to the search module. If you do not want this search facility, comment out", "", $sys_use_google);
-
       AskSetting("sys_localdoc_file", "Local Administration Documentation File", "Will make available the content of a specific file to site admins. Give the path to the file or comment out", "", $sys_localdoc_file);
 
     ## SPECIFIC and (usually) DEPRECATED
@@ -310,7 +300,7 @@ if ($recreate) {
 #
 # Savane Site Configuration:
 #
-# $Id: sv_update_conf.pl,v 1.33 2005/06/30 16:33:51 toddy Exp $
+# \$Id: sv_update_conf.pl,v 1.38 2005/09/21 12:56:23 yeupou Exp $
 #
 # This file has been generated by sv_update_conf
 # If you modify it, run sv_update_conf --update
@@ -320,78 +310,88 @@ if ($recreate) {
 # Ex: sv_update_conf --conffile=$conffile --update
 #     sv_update_conf --conffile=$conffile --recreate
 #
-# IMPORTANT SECURITY NOTE.
-# Configuration files should be rwx-only for root and apache's
-# user (usually "www-data" on Debian GNU/Linux).
-# So the owner should be apache's user.
+# IMPORTANT SECURITY NOTE:
+#   Configuration files should be rwx-only for root and apache's
+#   user (usually "www-data" on Debian GNU/Linux, "apache" on RedHat).
+#   So the owner should be apache's user.
 #      - there is a mysql password
 #      - these files are executed
-# While it offers the incredible advantage to avoid reinventing a boring
-# config parser and to permit hackers to create very efficient config
-# by using perl/php, if anybody can edit it, anybody can push savannah to 
-# execute malicious code when looking for it's configuration.
-# (But it's like a /etc/profile ... /etc is for admins).
+#  While it offers the incredible advantage to avoid reinventing a boring
+#  config parser and to permit hackers to create very efficient config
+#  by using perl/php, if anybody can edit it, anybody can push savannah to 
+#  execute malicious code when looking for it's configuration.
+#  (But it's like a /etc/profile ... /etc is for admins).
 #
 # By default:
 #      Access: (0750/-rwxr-x---)
 #      Uid: (    0/root)
 #      Gid: (   33/www-data)
-    
+#
+# HOWTO MODIFY THIS FILE:
+#   Some settings are required, and should be marked as such. Other can be
+#   commented out, at your convenience (usually, if something is referring
+#   to something else you have no clue about, let it commented out)
+
 use strict;
+use warnings;
 
     ## SERVER(S) ##
 
       # Default HTTP domain
       # It must be the naked form of the domain
       # Ex: "savannah.gnu.org"
-      $sys_default_domain
+        # REQUIRED
+        $sys_default_domain
 
       # Default HTTPS domain
       # It must be the naked form of the domain
       # Ex: "savannah.gnu.org"
-      $sys_https_host
+        # OPTIONAL (comment out if not appliable)
+        $sys_https_host
       
       # Brother HTTP(s) domain:
       # You can run Savannah with two different domain names. You'll be able 
       # to write a different configuration for each one.
       # The two brother/companion sites will share the same database.
-      # /etc/savannah/savannah.conf.pl is far more important since the default
-      # access to the database is done using this one.
       # Here you can let your savannah installation aware of the existence
       # of a brother/companion site, so while people login, it will be allowed 
       # to them to login on both site in one click.
       # If you do not have brother/companion site, comment out.
-      $sys_brother_domain
+        # OPTIONAL (comment out if not appliable)
+        $sys_brother_domain
 
       # SQL server:
       # Ex: "localhost", "savannah", "mysqluser", "mysqlpasswd",
       #     "mysql_socket=/non-standard-path-to/mysqld.sock"
-      $sys_dbhost
-      $sys_dbname
-      $sys_dbuser
-      $sys_dbpasswd
-      $sys_dbparams
+        # REQUIRED
+        $sys_dbhost
+        # REQUIRED
+        $sys_dbname
+        # REQUIRED	
+        $sys_dbuser
+        # REQUIRED
+        $sys_dbpasswd
+        # OPTIONAL (comment out if not appliable)
+        $sys_dbparams
 
 
     ## INSTALLATION PATHS ##
 
       # Local dir of the installation of the PHP frontend
       # IT MUST BE AN ABSOLUTE PATH NAME
-      # Ex: "/usr/local/sv/src/savannah/frontend/php"
-      $sys_www_topdir
+      # Ex: "/usr/src/savane/frontend/php"
+        # REQUIRED
+        $sys_www_topdir
       
       # Default web directory - suffix appended to the default domain 
-      # Ex: "/", "/savannah"
-      $sys_url_topdir
+      # Ex: "/", "/savane"
+        # REQUIRED
+        $sys_url_topdir
     
       # Local dir of the site-specific content
       # Ex: "/etc/savannah/savannah-content"
-      $sys_incdir
-
-      # [BACKEND ONLY]
-      # Local dir where dumps will be stored etc
-      # Ex: "/subversions/sv"
-      $sys_miscdir
+        # REQUIRED
+        $sys_incdir
 
 
     ## GUI ##
@@ -399,75 +399,92 @@ use strict;
       # Platform name, server administration project:
       # Name of the platform running and unix_group_name of the project 
       # dedicated of the server administration
-      # Ex: "Savannah", "savannah", 
-      $sys_name
-      $sys_unix_group_name
+      # Ex: "New Savane Installation", "admin", 
+        # REQUIRED
+        $sys_name
+        # REQUIRED
+        $sys_unix_group_name
       
       # Default locale and date formatting.
       # Ex: "fr_FR", "Y-M-d H:i"
-      $sys_default_locale
+        # OPTIONAL (comment out if not appliable)
+        $sys_default_locale
       # If you want to use the default locale formating, comment out
-      $sys_datefmt
+        # OPTIONAL (comment out if not appliable)
+        $sys_datefmt
 
       # Frontend look:
-      # Default theme, logo name and dimensions.
+      # Default theme, logo filename
       # The engine will search for a file like 
-      # savannah/www/images/\$theme.theme/$sys_logo_name
-      # Ex: "savannah", "floating.png", "150", "130"
-      $sys_themedefault
-      $sys_logo_name      
+      #    frontend/php/images/\$theme.theme/$sys_logo_name
+      # Ex: "light2", "floating.png"
+        # REQUIRED
+        $sys_themedefault
+        # OPTIONAL (comment out if not appliable)
+        $sys_logo_name      
 
     ## MAIL, MAILING-LIST ##
 
-      # Mail domain, admin mail address, default replyto, mail address list,
-      # mail aliases:
-      # Ex: "gnu.org", "savannah-hackers", "nobody", "/etc/email-addresses,"
-      # "/etc/aliases"
-      $sys_mail_domain
-      $sys_mail_admin
-      $sys_mail_replyto
-      $sys_mail_list
-      $sys_mail_aliases
+      # Mail domain, admin mail address, default replyto when
+      # no reply is possible, email addresses list, email aliases
+      # Ex: "gnu.org", "help", "NO-REPLY.INVALID-ADDRESS", 
+      # "/etc/email-addresses," "/etc/aliases"
+        # REQUIRED
+        $sys_mail_domain
+        # REQUIRED
+        $sys_mail_admin
+        # REQUIRED
+        $sys_mail_replyto
+        # OPTIONAL (comment out if not appliable)
+        $sys_mail_list
+        # OPTIONAL (comment out if not appliable)
+        $sys_mail_aliases
 
     
     ## USERS ACCOUNTS ##
       
-      # [BACKEND ONLY]
-      # user* binaries path
-      # If you do not want to use useradd/usermod/userdel that are in the
-      # usual PATH but specific ones, you can type here their prefix. 
-      # Otherwise, comment out.
-      # If you do not know that this setting is about, comment out.
-      $sys_userx_prefix
-
-      # Provide login through PAM
+      # Provide web interface login through PAM
       # (it can be AFS, Kerberos...)
       # Ex: "yes", "no"
-      $sys_use_pamauth
+        # OPTIONAL (comment out if not appliable)
+        $sys_use_pamauth
       
       # Kerberos:
       # If you do not know what it is about, you surely don't have to
       # deal with a kerberos server, say no here.
       # IMPORTANT: this part will be removed, replaced by PAM
       # Ex: "no"
-      $sys_use_krb5
+        # OPTIONAL (comment out if not appliable)
+        $sys_use_krb5
+
+      # [BACKEND ONLY]
+      # user* binaries path
+      # If you do not want to use useradd/usermod/userdel that are in the
+      # usual PATH but specific ones, you can type here their prefix. 
+      # Otherwise, comment out.
+      # If you do not know that this setting is about, comment out.
+        # OPTIONAL (comment out if not appliable)
+        $sys_userx_prefix
 
       # [BACKEND ONLY]
       # User home directory
       # You can safely uncomment all these settings if you do not use
-      # the savannah backend.
+      # the backend.
       # Ex: "/home"
-      $sys_homedir
+        # OPTIONAL (comment out if not appliable)
+        $sys_homedir
 
       # [BACKEND ONLY]
       # User home directory subdirs
       # Ex: "2" means users will have $sys_homedir/u/us/user as home.
-      $sys_homedir_subdirs
+        # OPTIONAL (comment out if not appliable)
+        $sys_homedir_subdirs
 
       # [BACKEND ONLY]
       # User default shell.
-      # Ex: "/usr/local/bin/cvssh"
-      $sys_shell
+      # Ex: "/usr/local/bin/sv_membersh" or "/bin/bash"
+        # OPTIONAL (comment out if not appliable)
+        $sys_shell
 
 
     ## CRONJOBS ##
@@ -477,13 +494,20 @@ use strict;
       # If you do not want system to be synchronized with database
       # automatically
       # on the following topics, by the backend, comment out.
-      $sys_cron_users
-      $sys_cron_groups
-      $sys_cron_viewcvs_forbidden
-      $sys_cron_mail
-      $sys_cron_mailman
-      $sys_cron_cleaner
-      $sys_cron_reminder
+        # OPTIONAL but highly recommended, almost required.
+        $sys_cron_cleaner
+        # OPTIONAL but recommended
+        $sys_cron_reminder
+        # OPTIONAL but recommended
+        $sys_cron_mail
+        # OPTIONAL (comment out if not appliable)
+        $sys_cron_users
+        # OPTIONAL (comment out if not appliable)
+        $sys_cron_groups
+        # OPTIONAL (comment out if not appliable)
+        $sys_cron_mailman
+        # OPTIONAL (comment out if not appliable)
+        $sys_cron_viewcvs_forbidden
 
     
     ## EXTRA FEATURES ##
@@ -492,19 +516,17 @@ use strict;
       # viewcvs ignore list
       # If you do not use viewcvs, if you do not want the backend to
       # edit that list comment out
-      $sys_viewcvs_conffile 
+        # OPTIONAL (comment out if not appliable)
+        $sys_viewcvs_conffile 
 
-      # Statistics
-      # If you do not have webalizer or mrtg, if you do not want comment out.
-      $sys_webalizer_dir
-      $sys_webalizer_url
-      $sys_mrtg_dir
-      $sys_mrtg_url
       # search via google added to the search module
-      $sys_use_google 
+        # OPTIONAL (comment out if not appliable)
+        $sys_use_google 
+
       # local admin doc: path of this path will be made available to site
       # admins
-      $sys_localdoc_file
+        # OPTIONAL (comment out if not appliable)
+        $sys_localdoc_file
 
     ## DEVELOPMENT ##
 
@@ -516,8 +538,8 @@ use strict;
     ## WORKAROUNDS ##
 
       # DEPRECATED:
-      # settings from the original SF code that does not seems usable nor 
-      # usefull. They are needed in order for the PHP frontend to run for now.$s
+      # settings from the original code that does not seems usable nor 
+      # usefull. They are needed in order for the PHP frontend to run for now.
       #our \$sys_urlroot=\"\$sys_www_topdir\"\;
       our \$sys_replyto=\"\$sys_mail_replyto\"\;
       our \$sys_admin_list=\"\$sys_mail_admin\"\;
