@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: sv_mailman.pl,v 1.13 2005/06/30 16:33:51 toddy Exp $
+# $Id: sv_mailman.pl,v 1.16 2005/09/13 09:39:08 yeupou Exp $
 #
 #  Copyright 2004 (c) Mathieu Roy <yeupou--at--gnu.org> 
 #
@@ -29,6 +29,7 @@ use strict;
 use Getopt::Long;
 use Savane;
 use POSIX qw(strftime);
+use File::Temp qw(tempfile tempdir);
 
 my $script = "sv_mailman";
 my $logfile = "/var/log/sv_database2system.log";
@@ -110,32 +111,27 @@ foreach my $line (GetDB("mail_group_list",
     print LOG strftime "[$script] %c - List $name <$admin> newlist.\n", localtime;
     
     # Configure the list.
-    
-    # Avoid race conditions
-    system("/bin/rm", "-rf", "/tmp/mmcfg");
-    mkdir("/tmp/mmcfg", 0700)
-	or die "Unable to create /tmp/mmcfg safely. Exiting";
+    my ($tmpcfgfh, $tmpcfg) = tempfile(UNLINK => 1);
 
-    open(TMPCFG, "> /tmp/mmcfg/mmcfg");
     # Always set description
-    print TMPCFG "description = '".Escape($description)."'\n";
+    print $tmpcfgfh "description = '".Escape($description)."'\n";
     # mailman is not useful to fight spam, in fact being forced to use
     # it's interface instead of having a spamassassin doing the job
     # can be seen as a pain.
-    print TMPCFG "require_explicit_destination = 0\n";
+    print $tmpcfgfh "require_explicit_destination = 0\n";
     # Do not advertise, hide archives, require approval if private list
-    print TMPCFG "archive_private = 1\n" unless $is_public;
-    print TMPCFG "advertised = 0\n" unless $is_public;
-    print TMPCFG "subscribe_policy = 3\n" unless $is_public;
+    print $tmpcfgfh "archive_private = 1\n" unless $is_public;
+    print $tmpcfgfh "advertised = 0\n" unless $is_public;
+    print $tmpcfgfh "subscribe_policy = 3\n" unless $is_public;
     # Always give access to the member list only to list admins
-    print TMPCFG "private_roster = 2\n";
+    print $tmpcfgfh "private_roster = 2\n";
     # Set the message limit size reasonnably big
     ## Set in mm_cfg.py
     ## print TMPCFG "max_message_size = 10240\n";
-    close(TMPCFG);
+    close($tmpcfgfh);
     system("/usr/sbin/config_list",
 	   "--inputfile",
-	   "/tmp/mmcfg/mmcfg",
+	   $tmpcfg,
 	   $name);
     print LOG strftime "[$script] %c - List $name <$admin> config_list.\n", localtime;
 
@@ -179,8 +175,7 @@ Regards,";
 # Final exit
 print LOG strftime "[$script] %c - work finished\n", localtime;
 print LOG "[$script] ------------------------------------------------------\n";
-unlink($lockfile, "/tmp/mmcfg/mmcfg");
-system("/bin/rm", "-rf", "/tmp/mmcfg");
+unlink($lockfile);
 
 # END
 
