@@ -2,10 +2,10 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: change.php,v 1.14 2005/08/03 19:14:04 beuc Exp $
+# $Id: change.php,v 1.15 2005/09/07 08:21:36 yeupou Exp $
 #
-#  Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
-#                          Yves Perrin <yves.perrin--at--cern.ch>
+#  Copyright 2003-2005 (c) Mathieu Roy <yeupou--gnu.org>
+#                          Yves Perrin <yves.perrin--cern.ch>
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -318,7 +318,7 @@ else if ($item == "password")
     $input4_title = "<br />Instead of providing a new Savannah password you
       may choose to authenticate via an <b>AFS</b> account you own
       at this site (this requires your Savannah login name to be the
-      same as the AFS account name). Check the following box:";
+      same as the AFS account name). In this case, you don't need to fill the two \"New Password\" fields. Instead, check the following box:"; 
 
     db_query("SELECT user_pw FROM user WHERE user_id=" . user_getid());
     $row_pw = db_fetch_array();
