@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: index.php,v 1.56 2005/06/30 17:19:33 toddy Exp $
+# $Id: index.php,v 1.57 2005/09/07 10:45:24 toddy Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -24,6 +24,14 @@
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 
+# we need to define the theme before loading the pre.php init script,
+# otherwise the page needs to be reloaded for the change to take effect.
+# see bug #1987
+if ($update and $user_theme != "random" and $user_theme != "rotate")
+  {
+    define ("SV_THEME", $user_theme);
+  }
+
 require "../include/pre.php";
 
 
@@ -43,7 +51,7 @@ if ($update)
     }
   else
     {
-      setcookie("SV_THEME", $user_theme, time() + 60*60*24*365, $GLOBALS['sys_home']);
+      setcookie("SV_THEME", $user_theme, time() + 60*60*24*365, $GLOBALS['sys_url_topdir']);
     }
 
   $success = db_query("UPDATE user SET "
@@ -69,7 +77,7 @@ if ($update)
 
   if ($success)
     {
-      fb(_("Successful update, theme/color changes will be effective the next time a page is loaded"));
+      fb(_("Database successfully updated"));
     }
   else
     {
