@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: login.php,v 1.58 2005/06/30 17:19:33 toddy Exp $
+# $Id: login.php,v 1.59 2005/09/06 13:09:55 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -30,6 +30,16 @@ Header( "Cache-Control: must-revalidate");
 require '../include/pre.php';
 require '../include/account.php';
 
+# CERN HACK: remove old cookies of domain cern.ch (!= savannah.cern.ch)
+# This could be removed in 2006.
+if ($GLOBALS['sys_https_host'] == "savannah.cern.ch")
+{
+  setcookie('session_hash','',0,"/",".cern.ch");
+  setcookie('session_uid','',0,"/",".cern.ch");
+  setcookie('session_hash','',0,"/","cern.ch");
+  setcookie('session_uid','',0,"/","cern.ch");
+}
+
 if ($GLOBALS['sys_https_host'] != "" && !session_issecure())
 {
   #force use of SSL for login
