@@ -2,12 +2,13 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: lostpw-confirm.php,v 1.25 2005/06/30 17:19:33 toddy Exp $
+# $Id: lostpw-confirm.php,v 1.27 2005/09/14 16:18:31 toddy Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
 #
-#  Copyright 2004      (c) Mathieu Roy <yeupou--at--gnu.org>
+#  Copyright 2004-2005 (c) Mathieu Roy <yeupou--gnu.org>
+#                          Joxean Koret <joxeankoret--yahoo.es>
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -25,6 +26,7 @@
 
 require "../include/pre.php";
 
+$form_loginname = addslashes($form_loginname);
 
 # CERN_SPECIFIC: here we also have a speech about AFS which must not be
 # hardcoded
@@ -43,14 +45,63 @@ if ($GLOBALS['sys_use_pamauth'] == "yes") {
 
 $confirm_hash = md5($session_hash . strval(time()) . strval(rand()));
 
+########################
+# Account check
 $res_user = db_query("SELECT * FROM user WHERE user_name='$form_loginname' AND status='A'");
 if (db_numrows($res_user) < 1)
 {
   exit_error(_("Invalid User"), _("This account does exist or has not been activated"));
 }
-
 $row_user = db_fetch_array($res_user);
 
+########################
+# Notification count check:
+# This code would allow to define the number of request that can be made
+# per hour.
+# By default, we set it to one
+$notifications_max = 1;
+unset($email_notifications);
+
+$res_emails = db_query("SELECT count FROM user_lostpw WHERE user_id='".$row_user['user_id']."' and DAYOFYEAR(date) = DAYOFYEAR(CURRENT_DATE) AND HOUR(DATE) = HOUR(NOW())");
+
+if (db_numrows($res_emails) < 1)
+{
+  $row_emails = 0;
+}
+else
+{
+  $row_emails = db_fetch_array($res_emails);
+  $email_notifications = strval($row_emails[0]);
+}
+
+if ($email_notifications == 0)
+{
+  # This would be made empty by itself. We could have the login form
+  # to remove old request.
+  # But sv_cleaner will take care of it.
+  $sql = "INSERT INTO user_lostpw VALUES ('".$row_user['user_id']."', CURRENT_TIMESTAMP, 1)";
+  db_query($sql);
+}
+else
+{
+  if ($email_notifications >= $notifications_max)
+    {
+      exit_error(_("An email for your lost password has already been sent. Please wait one hour and try again."));
+    }
+  else
+    {
+      $sql = "UPDATE user_lostpw SET
+			    	count = count + 1
+			    WHERE
+			    	user_id = '".$row_user['user_id']."' and DAYOFYEAR(DATE) = DAYOFYEAR(CURRENT_DATE)
+	                        and HOUR(DATE) = HOUR(NOW())";
+      db_query($sql);
+    }
+}
+
+
+# If we get here, it is OK to continue
+
 db_query("UPDATE user SET confirm_hash='$confirm_hash' WHERE user_id=$row_user[user_id]");
 
 $message = sprintf(_("Someone (presumably you) on the %s site requested a password change through email verification."),$GLOBALS['sys_default_domain']);
@@ -70,11 +121,11 @@ $message_for_admin =
 "Someone attempted to change a password via email verification\n"
 . "on ".$GLOBALS['sys_default_domain']."\n\n"
 . "Someone is maybe trying to steal a user account.\n\n"
-. "The user concerned is ".$form_loginname."\n\n"
+. "The user affected is ".$form_loginname."\n\n"
 . "The request comes from ".gethostbyaddr($GLOBALS['REMOTE_ADDR'])." "
 . "(IP: ".$GLOBALS['REMOTE_ADDR']." port: ".$GLOBALS['REMOTE_PORT'].") "
 . "with ".$GLOBALS['HTTP_USER_AGENT']."\n\n"
-. "RFC 822 (updated by RFC 1123) date:\n"
+. "Date:"
 . gmdate('D, d M Y H:i:s \G\M\T')
      . "\n";
 
