@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: triggercreation.php,v 1.5 2005/06/30 17:19:33 toddy Exp $
+# $Id: triggercreation.php,v 1.6 2005/09/19 11:57:15 yeupou Exp $
 #
 #  Copyright 2004 (c) Mathieu Roy <yeupou--at--gnu.org>
 # 
@@ -22,12 +22,13 @@
 
 
 require "../include/pre.php";
-require ($GLOBALS['sys_www_topdir'].'/include/proj_email.php');
+require "../include/proj_email.php";
 
 # Skip admin rights check if we are dealing with the sys group
 if ($GLOBALS['sys_group_id'] != $group_id)
 { session_require(array('group'=>'1','admin_flags'=>'A')); }
 
+################
 # Configure the project according to group type settings:
 #   if a project can use a feature for its group type, assume he would
 #   use it by default
@@ -72,6 +73,58 @@ if ($upd_list)
     }
 }
 
+################
+# Now set a default notification setup for the trackers. 
+# We do not even check whether the trackers are used, because we want this
+# configuration to be already done if at some point the tracker gets activated,
+# if it is not the case by default.
+unset($to_update, $upd_list);
+
+# Build the notification list
+$res_admins = db_query("SELECT user.user_name FROM user,user_group WHERE "
+		       . "user.user_id=user_group.user_id AND user_group.group_id='$group_id' AND "
+		       . "user_group.admin_flags='A'");
+if (db_numrows($res_admins) > 0)
+{
+  unset($admin_list);
+  while ($row_admins = db_fetch_array($res_admins))
+    {
+      $admin_list .= ($admin_list ? ', ':'').$row_admins['user_name'];
+    }
+  
+  $to_update = array("news", "support", "task", "bugs", "patch");
+  while (list(,$field) = each($to_update))
+    {
+      $upd_list .= "new_".$field."_address='$admin_list',";
+      if ($field != "news")
+	{
+	  $upd_list .= "send_all_".$field."='$value',";
+	}
+    }
+}
+if ($upd_list)
+{
+  # strip the excess comma at the end of the update field list
+  $upd_list = substr($upd_list,0,-1);
+  
+  $sql="UPDATE groups SET $upd_list ".
+     " WHERE group_id='$group_id'";
+  $result=db_affected_rows(db_query($sql));
+
+  if (!$result)
+    { 
+      fb(_("No field to update or SQL error"));
+
+    }
+  else
+    { 
+      fb_dbsuccess();  
+      group_add_history('Set Mail Notification to a sensible default',user_getname($user_id),$group_id);
+    }
+}
+
+
+################
 # Send email and do site specific triggered stuff that comes along
 send_new_project_email($group_id);
 fb(_("Mail sent, site-specific triggers executed"));
