@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: admin.php,v 1.23 2005/06/30 17:19:34 toddy Exp $
+# $Id: admin.php,v 1.24 2005/09/20 13:40:42 yeupou Exp $
 #
 #  Copyright 2002-2004 (c) Mathieu Roy <yeupou@gnu.org>
 # 
@@ -20,29 +20,30 @@
 # along with the Savane project; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-
 require "../include/pre.php";    
 
-$project=project_get_object($sys_group_id);
-$title = $project->getPublicName().': '._("Admin documentation");
+if (!user_can_be_super_user())
+{
+  exit_permission_denied();
+}
+else
+{
 
-site_admin_header(array('title'=>$title,'group'=>$sys_group_id,'toptab'=>'special'));
+  $project=project_get_object($sys_group_id);
+  $title = $project->getPublicName().': '._("Admin documentation");
+  
+  site_header(array('title'=>$title,'group'=>$sys_group_id,'toptab'=>'special'));
 
 # we get *.html content and we show only <body>content</body>
 
 # Currently not advertised: with the local option in the link, it will print
 # the content of a file in set by sys_localdoc_file, if exiting.
 # If this file exists, it will show up in the menu links too.
-
-if ($local && $GLOBALS['sys_localdoc_file']) 
-{
-  print utils_remove_htmlheader(utils_read_file($GLOBALS['sys_localdoc_file']));
+  if ($local && $GLOBALS['sys_localdoc_file']) 
+    {
+      print utils_remove_htmlheader(utils_read_file($GLOBALS['sys_localdoc_file']));
+    }
+  
+  $HTML->footer(array());
 }
-else 
-{
-  print utils_remove_htmlheader(utils_read_file($sys_www_topdir."/docs/savannah.html"));
-}
-
-$HTML->footer(array());
-
 ?>
