@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: account.php,v 1.24 2005/06/30 17:19:35 toddy Exp $
+# $Id: account.php,v 1.25 2005/09/05 13:26:58 toddy Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -27,12 +27,13 @@
 
 function account_pwvalid ($pw) 
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':account_pwvalid ($pw) ';
+  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':account_pwvalid ($pw) ';
   $MIN_PASSWD_LENGTH=3;
   if (strlen($pw) < $MIN_PASSWD_LENGTH)
     {
-      $GLOBALS['register_error'] = sprintf(_("Password must be at least %s characters."),$MIN_PASSWD_LENGTH);
-      fb(sprintf(_("Password must be at least %s characters."),$MIN_PASSWD_LENGTH),1);
+      $err_msg = sprintf(ngettext("Password must be at least %s character.", "Password must be at least %s characters.", $MIN_PASSWD_LENGTH), $MIN_PASSWD_LENGTH);
+      $GLOBALS['register_error'] = $err_msg;
+      fb($err_msg, 1);
       return 0;
     }
   return 1;
@@ -67,13 +68,13 @@ function account_namevalid ($name, $allow_dashes=0, $allow_underscores=1)
 
   if (strlen($name) < $MIN_ACCNAME_LENGTH)
     {
-      fb(sprintf(_("Account name is too short. It must be at least %s characters."), $MIN_ACCNAME_LENGTH),1);
+      fb(sprintf(ngettext("Account name is too short. It must be at least %s character.", "Account name is too short. It must be at least %s characters.", $MIN_ACCNAME_LENGTH), $MIN_ACCNAME_LENGTH),1);
       return 0;
     }
 
   if (strlen($name) > $MAX_ACCNAME_LENGTH)
     {
-      fb(sprintf(_("Account name is too long. It must be at most %s characters."), $MAX_ACCNAME_LENGTH),1);
+      fb(sprintf(ngettext("Account name is too long. It must be at most %s character.", "Account name is too long. It must be at most %s characters.", $MAX_ACCNAME_LENGTH), $MAX_ACCNAME_LENGTH),1);
       return 0;
     }
 
