@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: html.php,v 1.61 2005/06/30 17:19:35 toddy Exp $
+# $Id: html.php,v 1.69 2005/09/28 08:12:18 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -24,6 +24,45 @@
 # along with the Savane project; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
+# display browsing/display options: should be on top of pages, after the 
+# specific content/page description.
+# The form should end by #options so it the user does not have to scroll down
+# too much
+function html_show_displayoptions ($content, $form_opening=0, $submit=0)
+{
+  return html_show_boxoptions(_("Display Criteria"), $content, $form_opening, $submit);
+}
+
+function html_show_boxoptions ($legend, $content, $form_opening=0, $submit=0)
+{
+  $ret = '
+<fieldset class="boxoptions">
+<a name="options"></a><legend>'.$legend.'</legend>';
+  
+  if ($form_opening && $submit)
+    { 
+      $ret .= '
+'.$form_opening.'
+<span class="boxoptionssubmit">'.$submit.'</span>';
+    }
+
+$ret .= '
+<span class="smaller">'.$content.'</span>';
+  
+  if ($form_opening && $submit)
+    { 
+      $ret .= '
+</form>';
+    }
+
+  $ret .= '
+</fieldset>
+';
+
+  return $ret;
+}
+
+
 function html_splitpage ($how)
 {
   if ($how == 'start' || $how == '1')
@@ -43,6 +82,7 @@ function html_splitpage ($how)
     }
 }
 
+
 function html_nextprev ($search_url, $rows, $rows_returned)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_nextprev ($search_url, $rows, $rows_returned) ';
@@ -54,7 +94,7 @@ function html_nextprev ($search_url, $rows, $rows_returned)
 
       if ($offset != 0)
 	{
-	  print '<a href="'.$search_url.'&amp;offset='.($offset-$rows).'&amp;max_rows='.$max_rows.'">';
+	  print '<a href="'.$search_url.'&amp;offset='.($offset-$rows).'&amp;max_rows='.$max_rows.'#results">';
 	  print '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/previous.png" border="0" alt="'._("Previous Results").'" />'._("Previous Results").'</a>';
 
 	}
@@ -67,7 +107,7 @@ function html_nextprev ($search_url, $rows, $rows_returned)
 
       if ($rows_returned > $rows)
 	{
-	  print '<a href="'.$search_url.'&amp;offset='.($offset+$rows).'&amp;max_rows='.$max_rows.'">';
+	  print '<a href="'.$search_url.'&amp;offset='.($offset+$rows).'&amp;max_rows='.$max_rows.'#results">';
 	  print _("Next Results").' <img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/next.png" border="0" alt="'._("Next Results").'" /></a>';
 	}
       else
@@ -201,7 +241,7 @@ function html_build_list_table_top ($title_arr,$links_arr=false,$table=true)
       for ($i=0; $i<$count; $i++)
 	{
 	  $return .= '
-			<td class="boxtitle"><a class=sortbutton href="'.$links_arr[$i].'">'.$title_arr[$i].'</a></td>';
+			<td class="boxtitle"><a class="sortbutton" href="'.$links_arr[$i].'">'.$title_arr[$i].'</a></td>';
 	}
     }
   else
@@ -237,6 +277,7 @@ function utils_get_alt_row_color ($i)
 }
 
 
+
 function html_build_select_box_from_array ($vals,$select_name,$checked_val='xzxz',$samevals = 0)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_build_select_box_from_array ';
@@ -551,9 +592,11 @@ function html_select_permission_box ($artifact, $row, $level="member")
 }
 
 
-function html_select_restriction_box ($artifact, $row, $level="group", $notd=0)
+function html_select_restriction_box ($artifact, $row, $level="group", $notd=0, $event=1)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_select_permission_box ($artifact, $row, $level="member")';
+  # event = 1 : posting items
+  # event = 2 : posting comments
+
   # If $row['user_id'] does not exists, we havent got a row but simple value
   # and it means that we are about to modify per group default
   if ($level == "type")
@@ -564,7 +607,14 @@ function html_select_restriction_box ($artifact, $row, $level="group", $notd=0)
   else
     {
       $value = $row;
-      $default = _("Group Type Default");
+      if ($event == 2) 
+	{
+	  $default = _("Same as for new items");
+	}
+      else
+	{
+	  $default = _("Group Type Default");
+	}
     }
 
   if (!$notd)
@@ -574,7 +624,7 @@ function html_select_restriction_box ($artifact, $row, $level="group", $notd=0)
     }
 
   print '
-      <select name="'.$artifact.'_restrict">';
+      <select name="'.$artifact.'_restrict_event'.$event.'">';
 
   if ($default)
     {
@@ -591,7 +641,7 @@ function html_select_restriction_box ($artifact, $row, $level="group", $notd=0)
   print '
       </select>';
 
-  if (!$value && $level == "group")
+  if (!$value && $level == "group" && $event == 1)
     {
       $value = group_gettyperestrictions($GLOBALS[group_id], $artifact);
       print '<br />('.
