@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: menu.php,v 1.123 2005/08/31 21:05:09 yeupou Exp $
+# $Id: menu.php,v 1.127 2005/09/27 13:15:24 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -57,7 +57,7 @@ function menu_print_sidebar($params)
   print menu_thispage($params['title'], $params['toptab'], $params['group']);
   print menu_search();
   # Site Admin menu added here
-  if (user_is_super_user())
+  if (user_can_be_super_user())
     {
       print menu_site_admin();
     }
@@ -77,13 +77,13 @@ function menu_print_sidebar($params)
 # Menu entry  for all admin tasks when logged as site administor
 function menu_site_admin()
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':menu_site_admin() ';
-
+  # This menu is shown whether the user is a logged as super user or not
   global $HTML;
+  $is_su = user_is_super_user();
   $HTML->menuhtml_top($GLOBALS['sys_name'].' '._("Administration"));
-  $HTML->menu_entry($GLOBALS['sys_home'].'admin/',_("Main page"));
-  $HTML->menu_entry($GLOBALS['sys_home'].'task/?group='.$GLOBALS['sys_unix_group_name'].'&amp;category_id=1&amp;status_id=1&amp;set=custom',_("Pending projects"));
-  $HTML->menu_entry($GLOBALS['sys_home'].'news/approve.php?group='.$GLOBALS['sys_unix_group_name'],_("Site news approval"));
+  $HTML->menu_entry($GLOBALS['sys_home'].'admin/',_("Main page"), $is_su);
+  $HTML->menu_entry($GLOBALS['sys_home'].'task/?group='.$GLOBALS['sys_unix_group_name'].'&amp;category_id=1&amp;status_id=1&amp;set=custom#results',_("Pending projects"));
+  $HTML->menu_entry($GLOBALS['sys_home'].'news/approve.php?group='.$GLOBALS['sys_unix_group_name'],_("Site news approval"), $is_su);
 
   $HTML->menuhtml_bottom();
 
@@ -95,7 +95,7 @@ function menu_search()
   global $HTML,$group_id;
   $HTML->menuhtml_top(_("Search"));
   print '       <li class="menusearch">';
-  search_box();
+  print search_box("", "menu");
   print '       </li><!-- end menusearch -->';
   $HTML->menuhtml_bottom();
 }
@@ -215,18 +215,9 @@ function menu_documentation()
 		    _("User Docs (FAQ)"),
 		    1,
 		    _("Documentation dedicated to any users, including Project Admins"));
-  if (user_can_be_super_user())
+  if (user_can_be_super_user() && $GLOBALS['sys_localdoc_file'])
     {
-      $HTML->menu_entry($GLOBALS['sys_home'].'docs/admin.php',_("Server Admin Docs"));
-      if ($GLOBALS['sys_localdoc_file'])
-	{
-	  $HTML->menu_entry($GLOBALS['sys_home'].'docs/admin.php?local=1',_("Local Server Admin Docs"));
-	}
-    }
-
-  if ($GLOBALS['sys_mrtg_dir'] || $GLOBALS['sys_webalizer_dir'])
-    {
-      $HTML->menu_entry($GLOBALS['sys_home'].'docs/webalizer.php',_("Statistics"));
+      $HTML->menu_entry($GLOBALS['sys_home'].'docs/admin.php?local=1',_("Local Server Admin Docs"));
     }
   $HTML->menu_entry($GLOBALS['sys_home'].'contact.php',
 		    _("Contact Us"),
