@@ -2,11 +2,11 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: general.php,v 1.14 2005/07/05 15:40:43 yeupou Exp $
+# $Id: general.php,v 1.17 2005/09/21 15:53:23 yeupou Exp $
 #
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
 #
-#  Copyright 2003-2005 (c) Mathieu Roy <yeupou--at--gnu.org>
+#  Copyright 2003-2005 (c) Mathieu Roy <yeupou--gnu.org>
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -248,8 +248,8 @@ function my_item_list ($role="assignee", $threshold="5", $status="open") {
       $count = count($thisgroupcontent);
 
       list($hide_now,$count_diff,$hide_url) = my_hide_url($role,$thisgroupid,$GLOBALS['hide_group_id'],$count,$GLOBALS['hide_'.$role], '&nbsp;<b>'.$thisgroupfullname.'</b>');
-
-      print '<div class="boxitem">'.$hide_url.' <font class="smaller">'.my_item_count($count,max(0, $count_diff)).'</font></div>';
+      
+      print '<div class="'.utils_altrow(1).'"> '.$hide_url.' <font class="smaller">'.my_item_count($count,max(0, $count_diff)).'</font></div>';
 
       if (!$hide_now)
         {
@@ -258,8 +258,9 @@ function my_item_list ($role="assignee", $threshold="5", $status="open") {
              print $line;
            }
         }
-      print '<br />';
 
+      # Add extra space to make the page easier to read
+      print '<br />';
     }
 
 
@@ -356,10 +357,10 @@ function my_incoming_unassigned_item_list ($groups) {
 
   # Print the title (here in the function because we do not want to show
   # this table to people that are not even project member).
-  print '<br /><div class="boxtitle">'._("New and Unassigned Items").'</div>';
+  print '<br /><div class="box"><div class="boxtitle">'._("New and Unassigned Items").'</div>';
 
   # Go thru the group list and list items
-  asort($groups_with_items);
+  asort($groups_with_items);  
   while (list($thisgroup,$thisgroupfullname) = each($groups_with_items))
     {
       $thisgroupid = group_getid($thisgroup);
@@ -392,7 +393,7 @@ function my_incoming_unassigned_item_list ($groups) {
 
       list($hide_now,$count_diff,$hide_url) = my_hide_url("unassigned",$thisgroupid,$GLOBALS['hide_group_id'],$count,$GLOBALS['hide_unassigned'], '&nbsp;<b>'.$thisgroupfullname.'</b>');
 
-      print '<div class="boxitem">'.$hide_url.' <font class="smaller">'.my_item_count($count,max(0, $count_diff)).'</font></div>';
+      print '<div class="'.utils_altrow(1).'">'.$hide_url.' <font class="smaller">'.my_item_count($count,max(0, $count_diff)).'</font></div>';
 
       if (!$hide_now)
         {
@@ -401,10 +402,10 @@ function my_incoming_unassigned_item_list ($groups) {
              print $line;
            }
         }
-      print '<br />';
+      print '<br />';      
 
     }
-
+  print '</div>';
 
 }
 
@@ -584,7 +585,7 @@ function my_incoming_assigned_item_list ($groups) {
 
       list($hide_now,$count_diff,$hide_url) = my_hide_url("newlyassigned",$thisgroupid,$GLOBALS['hide_group_id'],$count,$GLOBALS['hide_newlyassigned'], '&nbsp;<b>'.$thisgroupfullname.'</b>');
 
-      print '<div class="boxitem">'.$hide_url.' <font class="smaller">'.my_item_count($count,max(0, $count_diff)).'</font></div>';
+      print '<div class="'.utils_altrow(1).'">'.$hide_url.' <font class="smaller">'.my_item_count($count,max(0, $count_diff)).'</font></div>';
 
       if (!$hide_now)
         {
