@@ -2,26 +2,26 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: general.php,v 1.3 2005/04/11 21:38:02 toddy Exp $
+# $Id: general.php,v 1.5 2005/08/31 21:05:09 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
 #
 #  Copyright 2004      (c) Mathieu Roy <yeupou--at--gnu.org>
 #
-# This program is free software; you can redistribute it and/or
+# The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
 # as published by the Free Software Foundation; either version 2
 # of the License, or (at your option) any later version.
 #
-# This program is distributed in the hope that it will be useful,
+# The Savane project is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+# along with the Savane project; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 # This file contains all the functions for the people module
 # Since all three files orginial were included by pre.php
@@ -89,14 +89,15 @@ function people_show_category_list()
   $result=db_query($sql);
   $rows=db_numrows($result);
   if (!$result || $rows < 1)
-    {    $return .= _("No Categories Found");
+    {    
+      $return .= _("No Categories Found");
     }
   else
     {
       for ($i=0; $i<$rows; $i++)
 	{
 	  $count_res=db_query("SELECT count(*) AS count FROM people_job WHERE category_id='". db_result($result,$i,'category_id') ."' AND status_id='1'");
-	  print db_error();
+
 	  # Print only if there are result within the category
 	  if (db_result($count_res,0,'count') > 0)
 	    {
@@ -107,6 +108,9 @@ function people_show_category_list()
 	    }
 	}
     }
+  if (!$return) 
+    { return false; }
+
   return "<ul class=\"boxli\">".$return."</ul>";
 }
 
