@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: pre.php,v 1.83 2005/06/30 17:19:35 toddy Exp $
+# $Id: pre.php,v 1.84 2005/09/19 08:41:19 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -252,6 +252,13 @@ if (user_isloggedin())
 # defines the artifact we are using
 define("ARTIFACT", get_module_include_dir($GLOBALS['REQUEST_URI'], 1));
 
+# Keep only numerical characters in the item_id
+if ($item_id && !ctype_digit($item_id))
+{
+  preg_match("/(\d+)/", $item_id, $match);
+  $item_id = $match[0];
+}
+
 # if we got an item_id and no group_id we need to get the appropriate
 # group_id
 if (!isset($group_id) && !isset($group_name) && isset($item_id))
@@ -282,7 +289,6 @@ if (!isset($group_id) && !isset($group_name) && isset($msg_id))
 }
 
 
-
 # defines group_id if group is set
 # defines group_name if group_id is set
 if (isset($group) && !isset($group_id))
