@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: project_home.php,v 1.122 2005/06/30 17:19:35 toddy Exp $
+# $Id: project_home.php,v 1.123 2005/09/27 13:15:24 yeupou Exp $
 #
 # Copyright 1999-2000 (c) The SourceForge Crew
 # Copyright 2000-2003 (c) Free Software Foundation
@@ -95,6 +95,21 @@ print '</font></div><div class="'.utils_get_alt_row_color($j++).'"><font class="
 print _("Group Type:").' <b>'.$project->getTypeName().'</b>';
 print '</font>';
 print $HTML->box_bottom();
+print '<br />
+';
+
+if ($project->Uses("bugs") || 
+    $project->Uses("task") || 
+    $project->Uses("support") ||
+    $project->Uses("patch"))
+{
+  
+  print $HTML->box_top(_("Search in this Group"));
+  print '<font class="smaller">';
+  print search_box('','');
+  print '</font>';
+  print $HTML->box_bottom();
+}
 
 
 print '
