@@ -2,9 +2,9 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: sendmail.php,v 1.23 2005/08/31 21:05:09 yeupou Exp $
+# $Id: sendmail.php,v 1.24 2005/09/19 09:34:13 yeupou Exp $
 #
-#  Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
+#  Copyright 2003-2005 (c) Mathieu Roy <yeupou--gnu.org>
 # 
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -70,7 +70,7 @@ function sendmail_mail ($from,
   $more_headers = "From: ".sendmail_encode_header_content($from)."\n";
   if ($reply_to)
     { $more_headers .= "Reply-To: ".$reply_to."\n"; }
-  $more_headers .= "X-Savane-Server: ".$GLOBALS['SERVER_NAME'].":".$GLOBALS['SERVER_PORT']." [".$GLOBALS['SERVER_ADDR']."]\n";
+  $more_headers .= "X-Savane-Server: ".$_SERVER['SERVER_NAME'].":".$_SERVER['SERVER_PORT']." [".$_SERVER['SERVER_ADDR']."]\n";
 
   # Necessary for proper utf-8 support
   $more_headers .= "MIME-Version: 1.0\n";
@@ -86,9 +86,18 @@ function sendmail_mail ($from,
   if ($additional_headers) 
     { $more_headers .= $additional_headers."\n";  }
 
-  # User details
-  $more_headers .= "User-Agent: ".$GLOBALS['HTTP_USER_AGENT']."\n";
-  $more_headers .= "X-Apparently-From: ".$GLOBALS['REMOTE_ADDR']."\n";
+  # User details.
+  # Tell what is the user agent, tell which authenticated user made
+  # the mail to be sent
+  $more_headers .= "User-Agent: ".$_SERVER['HTTP_USER_AGENT']."\n";
+  if (user_isloggedin())
+    {
+      $more_headers .= "X-Apparently-From: ".$_SERVER['REMOTE_ADDR']." (Savane authenticated user ".user_getname(user_getid()).")\n";
+    }
+  else
+    {
+      $more_headers .= "X-Apparently-From: ".$_SERVER['REMOTE_ADDR']."\n";
+    }
 
   # Message ID
   $msg_id = sendmail_create_msgid();
