@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: general.php,v 1.2 2005/06/30 17:19:36 toddy Exp $
+# $Id: general.php,v 1.3 2005/09/22 09:02:53 yeupou Exp $
 #
 #  Copyright 2004-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
 #                          Yves Perrin <yves.perrin--at--cern.ch>
@@ -89,5 +89,10 @@ function stats_getitems($tracker, $only_open="",$period="")
   return stats_get_generic("SELECT count(*) AS count FROM $tracker WHERE group_id<>'100' $only_open $period");
 }
 
+function stats_getthemeusers($theme="") 
+{
+  return stats_get_generic("SELECT count(*) AS count FROM user WHERE status='A' AND theme='$theme'");
+}
+
 
 ?>
\ No newline at end of file
