@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: theme.php,v 1.13 2005/06/30 17:19:35 toddy Exp $
+# $Id: theme.php,v 1.14 2005/09/21 16:07:06 yeupou Exp $
 #
 #  Copyright 2002-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
 # 
@@ -77,6 +77,9 @@ function theme_list ($strict=0)
 	}
     }
   closedir($dir);
+  
+  # Sort themes
+  asort($theme);
 
   # No result? Return only the default theme. 
   # (If there were no result, there is a problem anyway somewhere in the
