@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: data.php,v 1.29 2005/08/31 21:05:09 yeupou Exp $
+# $Id: data.php,v 1.36 2005/09/26 16:35:41 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
@@ -141,10 +141,12 @@ function &trackers_data_get_notification_settings($group_id, $tracker_name)
   #          and patch related tables. For now these fileds are called bug_xxx whatever
   #          the service related tables. Too much work to make all the changes in the code.
   $sql="SELECT ".$tracker_name."_field_value.bug_fv_id,".$tracker_name."_field_value.value,".$tracker_name."_field_value.email_ad,".$tracker_name."_field_value.send_all_flag ".
-     "FROM ".$tracker_name."_field, ".$tracker_name."_field_value ".
-     "WHERE ".$tracker_name."_field_value.group_id='$group_id' ".
-     "AND ".$tracker_name."_field.field_name='$cat_field_name' ".
-     "AND ".$tracker_name."_field_value.bug_field_id=".$tracker_name."_field.bug_field_id";
+    "FROM ".$tracker_name."_field, ".$tracker_name."_field_value ".
+    "WHERE ".$tracker_name."_field_value.group_id='$group_id' ".
+    "AND ".$tracker_name."_field.field_name='$cat_field_name' ".
+    "AND ".$tracker_name."_field_value.bug_field_id=".$tracker_name."_field.bug_field_id ".
+    "AND ".$tracker_name."_field_value.status!='H'";
+
   $result=db_query($sql);
   $settings['nb_categories']=db_numrows($result);
   $settings['category'] = array();
@@ -538,8 +540,17 @@ function trackers_data_is_special($field, $by_field_id=false)
   return($by_field_id ? $BF_USAGE_BY_ID[$field]['special']: $BF_USAGE_BY_NAME[$field]['special']);
 }
 
-function trackers_data_is_empty_ok($field, $by_field_id=false)
+# deprecated
+function trackers_data_is_empty_ok ($field, $by_field_id=false)
 {
+  return trackers_data_mandatory_flag($field, $by_field_id);
+}		  
+
+function trackers_data_mandatory_flag ($field, $by_field_id=false)
+{
+  # 1 = not mandatory
+  # 0 = relaxed mandatory (mandatory if it was to the submitter)
+  # 3 = mandatory whenever possible 
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_data_is_empty_ok($field, $by_field_id=false)';
   global $BF_USAGE_BY_ID,$BF_USAGE_BY_NAME;
   if ($by_field_id)
@@ -556,6 +567,7 @@ function trackers_data_is_empty_ok($field, $by_field_id=false)
   return($val);
 }
 
+
 function trackers_data_do_keep_history($field, $by_field_id=false)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_data_do_keep_history($field, $by_field_id=false)';
@@ -1155,8 +1167,8 @@ function trackers_data_update_usage($field_name,
 				    $use_it,
 				    $rank,
 				    $display_size,
-				    $empty_ok=0,
-				    $keep_history=0,
+				    $empty_ok,
+				    $keep_history,
 				    $show_on_add_members=0,
 				    $show_on_add=0,
 				    $transition_default_auth='A')
@@ -1218,15 +1230,9 @@ function trackers_data_update_usage($field_name,
     }
 
   if (db_affected_rows($result) < 1)
-    {
-      fb(_("Update of field usage failed."), 0);
-      ' - '.db_error();
-    }
+    { fb(_("Update of field usage failed."), 1); }
   else
-    {
-
-      fb(_("Field usage updated."));
-    }
+    { fb(_("Field usage updated.")); }
 
 }
 
@@ -1462,14 +1468,24 @@ function trackers_data_handle_update ($group_id,
   # return true if bug updated, false if nothing changed or
   # DB update failed
 
-  # Make sure  required fields are not empty
-  if (!$group_id || !$item_id || !$canned_response ||
-      (trackers_check_empty_fields($vfl) == false) )
+  # Make sure absolutely required fields are not empty
+  if (!$group_id || !$item_id || !$canned_response)
     {
       dbg("params were group_id:$group_id item_id:$item_id canned_response:$canned_response");
       exit_missing_param();
     }
 
+  # Make sure mandatory fields are not empty, otherwise we want the form
+  # to be re-submissed
+  if ((trackers_check_empty_fields($vfl, false) == false))
+    {
+      # In such circonstances, we reprint the form
+      # highligthing missing fields.
+      # (It is important that trackers_check_empty_fields set the global var
+      # previous_form_bad_fields)
+      return false;      
+    }
+
   # Get this bug from the db
 
   $sql="SELECT * FROM ".ARTIFACT." WHERE bug_id='$item_id'";
@@ -1495,7 +1511,13 @@ function trackers_data_handle_update ($group_id,
   $changes = array();
   reset($vfl);
   while (list($field,$value) = each($vfl))
-    {
+    { 
+      # $field_transition_id needed to be reset for every field in the loop
+      # and $field_transition_accepted filled only if $field_transition_id
+      # is not empty (otherwise transition automatic updates risk to be
+      # done by error if a transition is defined for any field!)
+      unset($field_transition_id);
+
       # skip over special fields  except for summary which in this
       # particular case can be processed normally
       if (trackers_data_is_special($field) && ($field != 'summary'))
@@ -1602,9 +1624,11 @@ function trackers_data_handle_update ($group_id,
 	  $changes[$field]['add']=
 	     trackers_field_display($field,$group_id,$value,false,false,true,true);
 
-          # Register transition id
-	  $field_transition_accepted[] = $field_transition_id;
-
+          # Register transition id, if not empty
+          if ($field_transition_id != '') 
+            {
+	      $field_transition_accepted[] = $field_transition_id;
+            }
 	}
     }
 
@@ -1732,7 +1756,6 @@ function trackers_data_handle_update ($group_id,
 	}
       else
 	{
-	  #fb(_("Item Successfully Updated"));
 	  return true;
 	}
     }
@@ -2035,7 +2058,13 @@ function trackers_data_create_item($group_id,$vfl,&$extra_addresses)
 
   # make sure required fields are not empty
   if (trackers_check_empty_fields($vfl) == false)
-    { exit_error("Exiting"); }
+    {
+      # In such circonstances, we reprint the form
+      # highligthing missing fields.
+      # (It is important that trackers_check_empty_fields set the global var
+      # previous_form_bad_fields)
+      return false; 
+    }
 
   # Finally, create the bug itself
   # Remark: this SQL query only sets up the values for fields used by
@@ -2224,23 +2253,29 @@ function trackers_data_get_canned_responses ($group_id)
   return db_query($sql);
 }
 
-function trackers_data_get_reports($group_id, $user_id)
+function trackers_data_get_reports($group_id, $user_id=100)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_data_get_reports($group_id, $user_id)';
-
+  # Currently, reports are group based.
+  # Print first system reports.
+  
   # If user is unknown then get only project-wide and system wide reports
   # else get personal reports in addition  project-wide and system wide.
+  
+
   $sql = 'SELECT report_id,name FROM '.ARTIFACT.'_report WHERE ';
-  if (!$user_id || ($user_id == 100))
-    {
-      $sql .= "(group_id=$group_id AND scope='P') OR scope='S' ".
-	 'ORDER BY report_id';
-    }  else
-      {
-	$sql .= "(group_id=$group_id AND (user_id=$user_id OR scope='P')) OR ".
-	   "scope='S' ORDER BY scope,report_id";
-      }
-  #print "DBG sql report = $sql";
+
+#  if (!$user_id || ($user_id == 100))
+#    {
+
+ $sql .= "(group_id=$group_id AND scope='P') OR scope='S' ORDER BY scope DESC , report_id ASC ";
+
+#    }  else
+#      {
+#        $sql .= "(group_id=$group_id AND (user_id=$user_id OR scope='P')) OR ".
+#	   "scope='S' ORDER BY scope,report_id";
+#      }
+# print "DBG sql report = $sql";
+
   return db_query($sql);
 }
 
