@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: format.php,v 1.24 2005/07/05 17:31:01 yeupou Exp $
+# $Id: format.php,v 1.26 2005/09/23 10:37:41 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
@@ -111,8 +111,15 @@ function format_item_details ($item_id, $group_id, $ascii=false, $item_assigned_
 	      # put the comment type in bold
 	      $comment_type = '<font class="bold">'.$comment_type.'</font><br />';
 	    } 
-
-          $comment_number = ($rows-$i);
+	  
+	  if (!user_get_preference("reverse_comments_order"))
+	    {
+	      $comment_number = ($rows-$i);
+	    }
+	  else
+	    {
+	      $comment_number = ($i+1);
+	    }
 
           $class = utils_get_alt_row_color($i);
 	  unset($icon, $assignee);
@@ -177,12 +184,12 @@ function format_item_details ($item_id, $group_id, $ascii=false, $item_assigned_
 
           if ($icon)
 	    {
-	      $out .= '<br /><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/'.$icon.'.png" alt="'.$icon_alt.'" />';
+	      $out .= '<br /><font class="help" title="'.$icon_alt.'"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/'.$icon.'.png" alt="'.$icon_alt.'" /></font>';
 	    }
 	  
 	  if ($assignee)
 	    {
-	      $out .= '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/assignee.png" alt="'._("In charge of this item.").'" />';
+	      $out .= '<font class="help" title="'._("In charge of this item.").'"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/assignee.png" alt="'._("In charge of this item.").'" /></font>';
 	    }
 	  
 	  $out .= '</td></tr>';
