@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: general.php,v 1.21 2005/07/05 15:32:05 yeupou Exp $
+# $Id: general.php,v 1.36 2005/09/29 11:50:42 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
@@ -72,6 +72,7 @@ function trackers_header($params)
   global $group_id,$is_bug_page,$DOCUMENT_ROOT,$advsrch;
 
   #used so the search box will add the necessary element to the pop-up box
+  # yeupou, 2005-09-11: is that still useful?
   $is_bug_page=1;
 
   #required params for site_project_header();
@@ -142,7 +143,7 @@ function trackers_list_all_fields($sort_func=false,$by_field_id=false)
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_list_all_fields($sort_func=false,$by_field_id=false)';
   global $BF_USAGE_BY_ID, $BF_USAGE_BY_NAME, $AT_START;
 
-  # If it's the first element we fetch then apply the sort
+  # If its the first element we fetch then apply the sort
   # function
   if ($AT_START)
     {
@@ -173,7 +174,7 @@ function trackers_list_all_fields($sort_func=false,$by_field_id=false)
     }
 }
 
-function trackers_field_label_display($field_name, $group_id,$break=false,$ascii=false)
+function trackers_field_label_display ($field_name, $group_id,$break=false,$ascii=false, $tab=25)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_field_label_display($field_name, $group_id,$break=false,$ascii=false)';
   $label = trackers_data_get_label($field_name).':';
@@ -189,7 +190,7 @@ function trackers_field_label_display($field_name, $group_id,$break=false,$ascii
         { $output .= '&nbsp;'; }
       else
         {
-          $output .= sprintf("%25s", $label).' ';
+          $output .= sprintf("%".$tab."s", $label).' ';
         }
      }
 
@@ -208,7 +209,8 @@ function trackers_field_display ($field_name,
 				 $show_any=false, #10
 				 $text_any='Any',
                                  $allowed_transition_only=false, #12
-                                 $show_unknown=false)
+                                 $show_unknown=false,
+				 $tab=25)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_field_display  ';
   /*
@@ -236,7 +238,11 @@ function trackers_field_display ($field_name,
 
   if ($label)
     {
-      $output = trackers_field_label_display($field_name,$group_id,$break,$ascii);
+      $output = trackers_field_label_display($field_name,
+					     $group_id,
+					     $break,
+					     $ascii,
+					     $tab);
     }
 
   # display depends upon display type of this field
@@ -358,7 +364,7 @@ function trackers_field_date($field_name,$value='',$size=0,$maxlength=0,$ro=fals
 	{ $year = ($today[5]+1900); }
 
       # FIXME: order of year/day/month must be local specific
-      $html = calendar_selectbox("day", $day, $field_name.'_dayfd').calendar_selectbox("month", $month, $field_name.'_monthfd').' <input type="text" name="'.$field_name.'_yearfd" size="4" maxlength="4" value="'.$year.'">';
+      $html = calendar_selectbox("day", $day, $field_name.'_dayfd').calendar_selectbox("month", $month, $field_name.'_monthfd').' <input type="text" name="'.$field_name.'_yearfd" size="4" maxlength="4" value="'.$year.'" />';
     }
   return($html);
 
@@ -645,35 +651,122 @@ function trackers_extract_field_list($post_method=true)
   return($vfl);
 }
 
-function trackers_check_empty_fields($field_array)
+# Check whether a field was shown to the submitter
+# (useful if a field is mandatory if shown to the submitter)
+function trackers_check_is_shown_to_submitter ($field_name, $group_id, $submitter_id) 
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_check_empty_fields($field_array)';
-
-  /*
-      Check whether empty values are allowed for the bug fields
-      Params:
-      field_array: associative array of field_name -> value
-  */
-  $bad_fields = array();
+  if ($submitter_id == 100)
+    {
+      # Anonymous user
+      if (trackers_data_is_showed_on_add_nologin($field_name)) 
+	{ return true; }
+    } 
+  else 
+    {
+      if (!member_check($submitter_id, $group_id)) 
+	{
+          # Not a member of the group
+	  if (trackers_data_is_showed_on_add($field_name)) 
+	    { return true; }
+	} 
+      else
+	{
+          # Group member
+	  if (trackers_data_is_showed_on_add_members($field_name)) 
+	    { return true; }
+	}
+    }
+
+  # if we reach this point, it was not mandatory
+  return false;
+}
+
+
+function trackers_check_empty_fields($field_array, $new_item=true)
+{
+  # Check whether empty values are allowed for the bug fields
+  # field_array: associative array of field_name -> value
+  unset($previous_form_bad_fields);
+  global $previous_form_bad_fields;
+  $previous_form_bad_fields = array();
+  
+
   reset($field_array);
-  while ( list($key, $val) = each($field_array))
+  while (list($field_name, $val) = each($field_array))
     {
-      $is_empty = (trackers_data_is_select_box($key) ? ($val==100) : ($val==''));
       # Only the field percent_complete is allowed to use the special value
       # hundred.
       # FIXME: maybe it should not use that value at all, however it would
       # require one more database migration. Something that should indeed be
       # done if at some point we feel the need for one more exception.
-      if ( $is_empty && !trackers_data_is_empty_ok($key) && $key != "percent_complete")
+      if ($field_name == "percent_complete")
+	{ continue; }
+      
+      # Check if it is empty
+      $is_empty = (trackers_data_is_select_box($field_name) ? ($val==100) : ($val==''));
+      if (!$is_empty)
+	{ continue; }
+      
+      # Check if it is mandatory
+      $mandatory_flag = trackers_data_mandatory_flag($field_name);
+      unset($is_mandatory);
+      if ($mandatory_flag == 1)
 	{
-
-	  $bad_fields[] = trackers_data_get_label($key);
+	  # Not mandatory
+	  continue;
 	}
-    }
+      elseif ($mandatory_flag == 3)
+	{
+	  # Mandatory whenever possible
+	  $is_mandatory = 1;
+	}
+      elseif ($new_item)
+	{
+	  # Mandatory when shown to the submitter while we are creating
+	  # a new item.
+	  # ($mandatory_flag = 0)
+	  $is_mandatory = 1;
+	}
+      else 
+	{
+	  # Mandatory when shown to the submitter, we are updating an item
+	  # ($mandatory_flag = 0)
+	  
+	  global $item_id, $group_id, $mandatorycheck_submitter_id;
+	  if (!$mandatorycheck_submitter_id)
+	    {
+	      # Save that information for further mandatory checks, 
+	      # to avoid avoid a SQL request per field checked
+	      $submitter_sql = "SELECT submitted_by FROM ".ARTIFACT." WHERE bug_id='$item_id' AND group_id='$group_id'";
+	      $submitter_res = db_query($submitter_sql);
+	      $mandatorycheck_submitter_id = db_result($submitter_res,0,'submitted_by');
+	    }
+	  
+	  if (trackers_check_is_shown_to_submitter($field_name, $group_id, $mandatorycheck_submitter_id))
+	    {
+	      $is_mandatory = 1;
+	    }
+	}
+	
+      if ($is_mandatory)
+	{
+	  $value = trackers_data_get_label($field_name);
+	  $previous_form_bad_fields[$field_name] = $value;
+	}
+    } 
 
-  if (count($bad_fields) > 0)
+  if (count($previous_form_bad_fields) > 0)
     {
-      fb(sprintf(ngettext("Missing field: %s. Empty values for the above listed field are not allowed. Click on the \"Back\" button of your browser and try again.", "Missing fields: %s. Empty values for the above listed fields are not allowed. Click on the \"Back\" button of your browser and try again.", count($bad_fields)), join(', ',$bad_fields)), 1);
+      # If not_new_item is true, it mean that there was no previous value to
+      # reset the entry.
+      if ($new_item) 
+	{
+	  fb(sprintf(ngettext("The field '%s' is mandatory. Fill it and re-submit the form.","The fields '%s' are mandatory. Fill them and re-submit the form.", count($previous_form_bad_fields)), join(', ',$previous_form_bad_fields)), 1);
+	}
+      else
+	{
+	  fb(sprintf(ngettext("The field '%s' is mandatory. It has been reset to its previous value. Check it and re-submit the form.","The fields '%s' are mandatory. They have been reset to their previous value. Check them and re-submit the form.", count($previous_form_bad_fields)), join(', ',$previous_form_bad_fields)), 1);
+	}
 
       return false;
     }
@@ -855,7 +948,7 @@ function trackers_check_notification($user_id, $role, $changes=false)
   # then it has precedence over a cc_change
   if ($arr_notif[$role]['CC_CHANGE'] && isset($changes['CC']))
     {
-      # it's enough to test role against 'CC' because if we are at that point
+      # its enough to test role against 'CC' because if we are at that point
       # it means that the role_change for CC was false or that role is not CC
       # So if role is 'CC' and we are here it means that the user asked to not be
       # notified on role_change as CC, unless other users are listed in the cc changes
@@ -1018,19 +1111,47 @@ function trackers_mail_followup ($item_id,$more_addresses=false,$changes=false,$
 
   $sql="SELECT * from ".ARTIFACT." WHERE bug_id='$item_id'";
 
-  $result=db_query($sql);
+  $result = db_query($sql);
   $bug_href = "http://".$GLOBALS['sys_default_domain'].$GLOBALS['sys_home'].ARTIFACT."/?func=detailitem&item_id=$item_id";
 
   if ($result && db_numrows($result) > 0)
   {
 
   $group_id = db_result($result,0,'group_id');
+ 
+  unset($content_type);
+  # CERN SPECIFIC (at least for now) BEGIN '
+  # Maybe later we ll implement a way to select mail templates, or prepared
+  # mail format (like: text / html). 
+  # But it will have to be done in a well planned way that take into account
+  # necessary cases and is not encumbered by very very specific things.
+  # Until this happen, cern will use its own functions to deals with notif.
+  # Indeed, this part will maintained and modified by CERN only.
+  #
+  # To ease maintainance, such specific things should usually not be added.
+  # Please write to savane-dev if you intend to make such changes.
+  # The upstream code cannot be cluttered by tons of things like that.
+  # This is a one time exception, or almost, needed because this cannot 
+  # be directly merged in a generic way right now. 
+  if ($GLOBALS['sys_default_domain'] == "savannah.cern.ch" || $GLOBALS['sys_debug_cerntest'])
+  {
+    $content_type = group_get_preference($group_id, "notif_content");
+    if ($content_type == "") 
+     { 
+       $content_type = '2';   # by default select maximum
+     } 
+     
+    # Now, if the content type is 0, go on with Savane standard notif.
+    # If it s something else, use trackers_mail_followup_cernspecifichack() 
+    if ($content_type > 0)
+     {
+       return trackers_mail_followup_cernspecifichack($group_id,$bug_href,$result,$content_type,$item_id,$more_addresses,$changes,$force_exclude_list);
+     }
+  }
+  # CERN SPECIFIC (at least for now) END
 
   # CONTENT OF THE MAIL MUST NOT BE TRANSLATED
 
-#  $body = "This is an automated notification sent by ".$GLOBALS['sys_name']. ".
-#It relates to:\n\t\t".ARTIFACT." #".$item_id.", project ".group_getname($group_id)."\n";
-
   unset($body);
 
       if ($changes)
@@ -1123,6 +1244,7 @@ function trackers_mail_followup ($item_id,$more_addresses=false,$changes=false,$
           { $exclude_list = $force_exclude_list; }
       }
 
+
       sendmail_mail($from, $to, $subject, $body, group_getunixname($group_id), ARTIFACT, $item_id, 0, 0, $exclude_list);
       # Useless feedback, already added by sendmail_mail()
       #fb(_("Item update sent."));
@@ -1445,15 +1567,16 @@ function trackers_criteria_list_to_text($criteria_list, $url)
 	  $morder .= ($morder ? ",".$crit : $crit);
 	  $attr = str_replace('>','',$crit);
 	  $attr = str_replace('<','',$attr);
+	  $morder = htmlspecialchars($morder);
 
 	  $arr_text[] = '<a href="'.$url.'&amp;morder='.$morder.'#results">'.
-	     trackers_data_get_label($attr).'</a><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/'.
-	     ((substr($crit, -1) == '<') ? 'down' : 'up').
+	     trackers_data_get_label($attr).'</a><img class="icon" src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/'.
+	     ((substr($crit, -1) == '>') ? 'down' : 'up').
 	     '.png" border="0" />';
 	}
     }
 
-  return join(' > ',$arr_text);
+  return join(' &gt; ',$arr_text);
 }
 
 function trackers_build_match_expression($field, &$to_match)
@@ -1621,6 +1744,484 @@ function trackers_get_msgid ($artifact, $item_id, $latest="")
   return $list;
 }
 
+############## NASTY HACK
 
+  # CERN SPECIFIC (at least for now) BEGIN '
+  # Maybe later we ll implement a way to select mail templates, or prepared
+  # mail format (like: text / html). 
+  # But it will have to be done in a well planned way that take into account
+  # necessary cases and is not encumbered by very very specific things.
+  # Until this happen, cern will use its own functions to deals with notif.
+  # Indeed, this part will maintained and modified by CERN only.
+  #
+  # To ease maintainance, such specific things should usually not be added.
+  # Please write to savane-dev if you intend to make such changes.
+  # The upstream code cannot be cluttered by tons of things like that.
+  # This is a one time exception, or almost, needed because this cannot 
+  # be directly merged in a generic way right now. 
+function trackers_mail_followup_cernspecifichack ($group_id, $bug_href, $result,$content_type, $item_id, $more_addresses=false, $changes=false,$force_exclude_list=false) {
+  global $sys_datefmt;
+
+  # MUST BE DEFINED HERE, dont ask me why
+  $subject = utils_unconvert_htmlspecialchars(db_result($result,0,'summary'));
+
+if ($content_type == '2') {   # for now means CERN present format
+                               # (last + overview + all followups)
+
+  $body = "This is an automated notification sent by ".$GLOBALS['sys_name']. ".
+It relates to:\n\t\t".ARTIFACT." #".$item_id.", project ".group_getname($group_id)."\n";
+      
+      if ($changes)
+	{
+	  $body .= "\n==============================================================================\n";
+	  $body .= " LATEST MODIFICATIONS of ".ARTIFACT." #".$item_id.":\n";
+          $body .= "==============================================================================\n\n";
+
+      
+   ### format_item_changes of savane 1.0.6
+ # FIXME: strange, with %25s it does not behave exactly like
+  # trackers_field_label_display
+  $fmt = "%24s: %23s => %-23s\n";
+
+  $separator = "\n    _______________________________________________________\n\n";
+
+  # Process most of the fields
+  reset($changes);
+  while (list($field,$h) = each($changes))
+    {
+
+      # If both removed and added items are empty skip - Sanity check
+      if (!$h['del'] && !$h['add'])
+	{ continue; }
+
+      if ($field == "details" || $field == "attach") 
+        { continue; }
+     
+      $label = trackers_data_get_label($field);
+      if (!$label)
+	{ $label = $field; }
+      $out .= sprintf($fmt, $label, $h['del'],$h['add']);
+    }
+
+  if ($out)
+    {
+      $out = "Update of ".utils_get_tracker_prefix(ARTIFACT)." #".$item_id." (project ".group_getunixname($group_id)."):\n\n".$out;
+    }
+
+
+  # Process special cases: follow-up comments
+  if ($changes['details'])
+    {
+
+      if ($out)
+        { $out .= $separator; }
+
+      $out_com = "Follow-up Comment #".db_numrows(trackers_data_get_followups($item_id));
+      if (!$out)
+        { 
+          $out_com .= ", ".utils_get_tracker_prefix(ARTIFACT)." #".$item_id." (project ".group_getunixname($group_id).")";
+        }
+
+      $out_com .= ":\n\n";
+      if ($changes['details']['type'] != 'None' && $changes['details']['type'] != '(Error - Not Found)')
+	{
+	  $out_com .= '['.$changes['details']['type']."]\n";
+	}
+      $out_com .= utils_unconvert_htmlspecialchars($changes['details']['add']);
+      unset($changes['details']);
+
+      $out .= $out_com;
+    }
+
+  # Process special cases: file attachment
+  if ($changes['attach'])
+    {
+      if ($out)
+        { $out .= $separator; }
+
+      $out_att = "Additional Item Attachment";
+      if (!$out)
+        { 
+          $out_att .= ", ".utils_get_tracker_prefix(ARTIFACT)." #".$item_id." (project ".group_getunixname($group_id).")";
+        }
+      $out_att .= ":\n\n";
+      $out_att .= sprintf("File name: %-30s Size:%d KB\n",$changes['attach']['name'],
+			  intval($changes['attach']['size']/1024) );
+      $out_att .= $changes['attach']['description']."\n".'<'.$changes['attach']['href'].'>';
+      unset($changes['attach']);
+
+      $out .= $out_att;
+    }
+
+   $body .= $out;
+   ### format_item_changes of savane 1.0.6
+
+   $body .= "\n";
+	}
+
+      $body .= "\n==============================================================================\n";
+      $body .= " OVERVIEW of ".ARTIFACT." #".$item_id.":\n";
+      $body .= "==============================================================================\n\n";
+      $body .= "URL:\n  <".$bug_href.">\n\n";
+      $body .= trackers_field_display('summary', $group_id, db_result($result,0,'summary'),false,true,true,true)."\n";
+      $body .= sprintf("%25s", "Project:").' '.group_getname($group_id)."\n";
+      $body .= trackers_field_display('submitted_by', $group_id, db_result($result,0,'submitted_by'),false,true,true,true)."\n";
+      $body .= trackers_field_display('date', $group_id, db_result($result,0,'date'),false,true,true,true)."\n";
+      
+      # All other regular fields now		 
+      $i=0;
+      while ($field_name = trackers_list_all_fields())
+	{
+	  
+	  # if the field is a special field or if not used by his project 
+	  # then skip it. Otherwise print it in ASCII format.
+	  if (!trackers_data_is_special($field_name) &&
+	      trackers_data_is_used($field_name))
+	    {
+	      
+	      $body .= trackers_field_display($field_name,
+					      $group_id,
+					      db_result($result,0,$field_name),
+					      false,
+					      true,
+					      true,
+					      true);			      
+	      
+	      $i++;
+	      $body .= "\n";
+	    }
+	}
+      $body .= "\n";
+						   
+      # Now display other special fields
+      $body .= "    _______________________________________________________\n\n".trackers_field_display('details', 
+	                               $group_id,
+				       db_result($result,0,'details'),
+                                       true,true,true,true);
+
+      # Then output the history of bug details from newest to oldest
+      $body .= "\n\n";
+      # format_item_details($item_id, $group_id, true); of savane 1.0.6
+      $result=trackers_data_get_followups($item_id); 
+      $rows=db_numrows($result);
+
+  # No followup comment -> return now
+  if ($rows > 0)
+    {
+       unset($out);
+      $out .= "    _______________________________________________________\n\nFollow-up Comments:\n\n";
+     
+  # Loop throuh the follow-up comments and format them
+  for ($i=0; $i < $rows; $i++)
+    {
+       
+      $comment_type = db_result($result, $i, 'comment_type');
+      if ($comment_type == 'None') 
+	{ $comment_type = ''; }
+      else
+	{ $comment_type = '['.$comment_type.']'; }
+	
+    	  $fmt = "\n-------------------------------------------------------\n".
+	     "Date: %-30sBy: %s\n";
+	  if ($comment_type)
+	    { $fmt .= "%s\n%s"; }
+	  else
+	    { $fmt .= "%s%s"; }
+	  $fmt .= "\n";
+
+	
+      # I wish we had sprintf argument swapping in PHP3 but
+      # we dont so do it the ugly way...
+			
+         if (db_result($result, $i, 'realname'))
+            {
+              $name = db_result($result, $i, 'realname')." <".db_result($result, $i, 'user_name').">";
+            }
+          else 
+            {
+              $name = "Anonymous"; # must no be translated, part of mails notifs
+				     }
+	  $out .= sprintf($fmt,
+			  format_date($sys_datefmt,db_result($result, $i, 'date')),
+			  $name,
+			  $comment_type,
+			  utils_unconvert_htmlspecialchars(db_result($result, $i, 'old_value'))
+			  );
+
+	  }     
+     # final touch...
+     $out .=  "\n\n\n";
+     $body .= $out;
+     }
+      # format_item_details($item_id, $group_id, true); of savane 1.0.6 end
+
+
+      # Then output the CC list
+      $body .= "\n\n";
+      # format_item_cc_list($item_id, $group_id, true); of savane 1.0.6
+   $result=trackers_data_get_cc_list($item_id);
+   $rows=db_numrows($result);
+
+  # No file attached -> return now
+  if ($rows > 0)
+    {
+      unset($out);
+      $out .= "    _______________________________________________________\n\n"."Carbon-Copy List:\n\n";
+      $fmt = "%-35s | %s\n";
+      $out .= sprintf($fmt, 'CC Address', 'Comment');
+      $out .= "------------------------------------+-----------------------------\n";
+ 
+  # Loop through the cc and format them
+  for ($i=0; $i < $rows; $i++)
+    {
+
+      $email = utils_antispam_email(db_result($result, $i, 'email'));
+      $item_cc_id = db_result($result, $i, 'bug_cc_id');
+
+      # If the CC is a user point to its user page.
+      # Do not build mailto, we do not need to help spammers.
+      $res_username = user_get_result_set_from_unix($email);
+      if ($res_username && (db_numrows($res_username) == 1))
+	{ $href_cc = utils_user_link($email); }
+      else
+	{ $href_cc = $email; }
+
+	  $out .= sprintf($fmt, $email, db_result($result, $i, 'comment'));
+
+    }
+    # final touch...
+  $out .= "\n";
+  $body .= $out;
+  }
+   # format_item_cc_list($item_id, $group_id, true); of savane 1.0.6 end
+
+      # Then output the history of bug details from newest to oldest
+      $body .= "\n\n";
+      # format_item_attached_files of savane 1.0.6
+      #format_item_attached_files($item_id, $group_id, true);
+  $result=trackers_data_get_attached_files($item_id);
+  $rows=db_numrows($result);
+
+  # No file attached -> return now
+  if ($rows > 0)
+    {
+      unset($out);
+      $out .= "    _______________________________________________________\n\nFile Attachments:\n\n";
+      $fmt = "\n-------------------------------------------------------\n".
+	 "Date: %s  Name: %s  Size: %s   By: %s\n%s\n%s";
+ # Loop throuh the attached files and format them 
+
+  for ($i=0; $i < $rows; $i++)
+    {
+
+      $item_file_id = db_result($result, $i, 'bug_file_id');
+	  $href = $GLOBALS['sys_home'].ARTIFACT."/download.php?item_id=$item_id&item_file_id=$item_file_id";
+  
+       $out .= sprintf($fmt,
+			  format_date($sys_datefmt,db_result($result, $i, 'date')),
+			  db_result($result, $i, 'filename'),
+			  utils_filesize(0, intval(db_result($result, $i, 'filesize'))),
+			  db_result($result, $i, 'user_name'),
+			  db_result($result, $i, 'description'),
+			  '<http://'.$GLOBALS['sys_default_domain'].utils_unconvert_htmlspecialchars($href).'>');
+		       
+			}
+
+                # final touch...
+ 		$out .= "\n";
+$body .= $out;
+     }
+		       
+      # format_item_attached_files of savane 1.0.6 end
+
+
+      # Finally output the message trailer
+      $body .= "\n==============================================================================\n\n";
+      $body .= "This item URL is:";
+      $body .= "\n  <".$bug_href.">";
+}
+
+if ($content_type == '1') {   # for now means ROOT wishes (UGLY ... I know!)
+  $body = "";
+  $was_new_item = false;
+
+  if (user_isloggedin()) {
+    $body .= "Posted by: ".user_getrealname($user_id).' <'.user_getname($user_id).">";
+  } else {
+    $body .= "Posted by an anonymous user";
+  }
+  $body .= "\n";
+  $body .= "Related to: [".group_getname($group_id)." ".ARTIFACT." #".$item_id."] ".utils_unconvert_htmlspecialchars(db_result($result,0,'summary'))."\n";
+  $body .= "URL: <".$bug_href.">\n\n";
+
+  if ($changes) {
+    # $body .= format_item_changes($changes)."\n";
+
+    #Process special cases first: follow-up comment
+    $fmt = "%s: %23s -> %-23s\n";
+    $was_followup = false;
+    if ($changes['details']) {
+      $body .= "Follow-up Comment:\n\n";
+      if ($changes['details']['type'] != 'None' && $changes['details']['type'] != '(Error - Not Found)') {
+        $body .= '['.$changes['details']['type']."]\n";
+      }
+      $body .= utils_unconvert_htmlspecialchars($changes['details']['add']);
+      $body .= "\n";
+      unset($changes['details']);
+      # set flag to skip output of this followup comment at the end
+      $was_followup = true;
+    }
+  } else {
+    # if new submission start with description
+    $body .= trackers_field_display('details',
+                                     $group_id,
+                                     db_result($result,0,'details'),
+                                     true,true,true,true);
+    $body .= "\n";
+    # set flag to skip output of original submission at the end
+    $was_new_item = true;
+  }
+
+  if ($changes) {
+    #Process special cases first: bug file attachment
+    if ($changes['attach']) {
+      $body .= sprintf("Attachment of file: %s   Size:%d KB  ",$changes['attach']['name'], intval($changes['attach']['size']/1024) );
+      $body .= $changes['attach']['description']."\n".'<'.$changes['attach']['href'].'>';
+      unset($changes['attach']);
+      $body .= "\n";
+    }
+
+    # All the rest of the fields now
+    reset($changes);
+    if (count($changes)) {
+      $body .= "\n";
+      while ( list($field,$h) = each($changes)) {
+        # If both removed and added items are empty skip - Sanity check
+        if (!$h['del'] && !$h['add']) { continue; }
+        $label = trackers_data_get_label($field);
+        if (!$label) { $label = $field; }
+        $off = sprintf("%d", 23-strlen($label)-2);
+        $fmt = "%s: %".$off."s -> %-23s\n";
+        $body .= sprintf($fmt, $label, $h['del'],$h['add']);
+      }
+    } else {
+      $body .= "\n";
+    }
+    $body .= "\n";
+  } else {
+    $body .= "\n";
+  }
+
+  $body .= trackers_field_display('submitted_by', $group_id, db_result($result,0,'submitted_by'),false,true,true,true,false,'',false,'',false,false,-3)."\n";
+
+  # All other regular fields now
+  $i=0;
+  while ($field_name = trackers_list_all_fields()) {
+    # if the field is a special field or if not used by his project
+    # then skip it. Otherwise print it in ASCII format.
+    if (!trackers_data_is_special($field_name) && trackers_data_is_used($field_name)) {
+      $body .= trackers_field_display($field_name, $group_id,
+                                      db_result($result,0,$field_name),
+                                      false, true, true, true, false,
+                                      '',false,'',false,false,-3);
+      $i++;
+      $body .= "\n";
+    }
+  }
+
+  # Then output the history of bug details from newest to oldest
+
+  # $body .= format_item_details($item_id, $group_id, true);
+
+  $fu_result=trackers_data_get_followups($item_id);
+  $fu_rows=db_numrows($fu_result);
+  if ($fu_rows > 0) {
+    # Loop throuh the follow-up comments and format them
+    $fmt = "\n-----Reply from %s on %s-----\n%s\n";
+    for ($i=0; $i < $fu_rows; $i++) {
+      # prevent output of most recent if already shown
+      if ($was_followup && ($i == 0)) { continue; }
+      if (db_result($fu_result, $i, 'realname')) {
+        $name = db_result($fu_result, $i, 'realname')." <".db_result($fu_result, $i, 'user_name').">";
+      } else {
+        $name = "Anonymous"; # must no be translated, part of mails notifs
+      }
+      if (user_get_timezone()) {
+        $tz = ' ('.user_get_timezone().')';
+      } else {
+        $tz = '';
+      }
+      $body .= sprintf($fmt, $name,
+                       format_date($sys_datefmt,db_result($fu_result, $i, 'date')).$tz,
+                       utils_unconvert_htmlspecialchars(db_result($fu_result, $i, 'old_value'))
+                      );
+    }
+  }
+
+  if (!$was_new_item) {
+    # Now display Original Submission
+    $body .= "\n  -----Original Message-----".trackers_field_display('details', $group_id, db_result($result,0,'details'), true,true,true,true);
+  }
+}
+
+# stuff is formatted
+
+      # See who is going to receive the notification.
+      # Plus append any other email 
+      # given at the end of the list.
+      $arr_addresses = trackers_build_notification_list($item_id,$group_id,$changes);
+      $to = join(',',$arr_addresses);
+# CERN SPECIFIC HACK
+      $from = '"noreply ['.user_getrealname(0,0).']" <'.$GLOBALS['sys_mail_replyto'].'@'.$GLOBALS['sys_mail_domain'].'>';
+#      $from = user_getrealname(0,1).' <'.$GLOBALS['sys_mail_replyto'].'@'.$GLOBALS['sys_mail_domain'].'>';
+
+# replace usernames with user_ids (as expected by sendmail_mail)
+      $repl_addresses = '';
+      $more_addr_arr = explode(',',$more_addresses);
+      while (list(,$maddr) = each($more_addr_arr)) {
+        $maddr = ereg_replace(" ","", $maddr);
+        if (validate_email($maddr)) {
+          $repl_addresses .= ($repl_addresses ? ',':'').$maddr;
+        } else {
+          $maddr_user_id = user_getid($maddr);
+          if (user_exists($maddr_user_id)) {
+            $repl_addresses .= ($repl_addresses ? ',':'').$maddr_user_id;
+          } else {
+            $repl_addresses .= ($repl_addresses ? ',':'').$maddr;
+          }
+        }
+      } # while
+
+      if ($repl_addresses)
+	{
+	  $to .= ($to ? ',':'').$repl_addresses;
+	}
+
+      # If the item is private, take into account the exclude-list
+      if (db_result($result,0,'privacy') == '2')
+        {
+           $exclude_list = db_result(db_query("SELECT ".ARTIFACT."_private_exclude_address FROM groups WHERE group_id='$group_id'"),0, ARTIFACT."_private_exclude_address");
+
+        }
+
+      # Disallow mail notification for an address, private or not
+      if ($force_exclude_list)
+      {
+        if ($exclude_list) 
+          { $exclude_list .= ",".$force_exclude_list; }
+        else
+          { $exclude_list = $force_exclude_list; }
+      }
+
+      sendmail_mail($from, $to, $subject, $body, group_getunixname($group_id), ARTIFACT, $item_id, 0, 0, $exclude_list);
+
+ # Done it upstream function already
+ # else
+ #   {
+ #     fb(_("Could not send item update."), 0);
+ #   }
+ return true;
+}
+# CERN SPECIFIC (at least for now) END
 
 ?>
