@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: show.php,v 1.25 2005/07/05 17:31:01 yeupou Exp $
+# $Id: show.php,v 1.30 2005/09/12 09:31:30 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
@@ -26,7 +26,7 @@
 
 
 
-function show_item_list ($result,
+function show_item_list ($result_arr,
 			 $offset,
 			 $total_rows,
 			 $field_arr, #4
@@ -35,14 +35,7 @@ function show_item_list ($result,
 			 $url,
 			 $nolink=false)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':show_item_list ';
-  global $sys_datefmt,$group_id,$PHP_SELF,$chunksz;
-
-  /*
-      Accepts a result set from the bugs table. Should include all columns from
-      the table, and it should be joined to USER to get the user_name.
-  */
-  $rows=db_numrows($result);
+  global $sys_datefmt,$group_id,$PHP_SELF,$chunksz,$morder;
 
   # Build the list of links to use for column headings
   # Used to trigger sort on that column
@@ -50,7 +43,7 @@ function show_item_list ($result,
     {
       $links_arr = array();
       while (list(,$field) = each($field_arr))
-	{
+	{	  
 	  $links_arr[] = $url.'&amp;order='.$field.'#results';
 	}
     }
@@ -59,7 +52,7 @@ function show_item_list ($result,
       Show extra rows for <-- Prev / Next -->
   */
 
-  $nav_bar ='<h5 align="center">';
+  $nav_bar ='<h3 align="center">';
 
   # If all bugs on screen so no prev/begin pointer at all
   if ($total_rows > $chunksz)
@@ -67,24 +60,27 @@ function show_item_list ($result,
       if ($offset > 0)
 	{
 	  $nav_bar .=
-	     '<a href="'.$url.'&amp;offset=0#results"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/first.png" border="0" alt="'._("Begin").'" />'._("Begin").'</a>'.
+	     '<font class="xsmall"><a href="'.$url.'&amp;offset=0#results"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/first.png" border="0" alt="'._("Begin").'" />'._("Begin").'</a>'.
 	     '&nbsp;&nbsp;&nbsp;&nbsp;'.
 	     '<a href="'.$url.'&amp;offset='.($offset-$chunksz).
-	     '#results"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/previous.png" border="0" alt="'._("Previous Results").'" />'._("Previous Results").'</a>';
+	     '#results"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/previous.png" border="0" alt="'._("Previous Results").'" />'._("Previous Results").'</a></font>';
 	}
       else
 	{
 	  $nav_bar .=
-	     '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/firstgrey.png" border="0" alt="'._("Begin").'" /><font class="italic">'._("Begin").'</font>'.
+	     '<font class="xsmall"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/firstgrey.png" border="0" alt="'._("Begin").'" /><font class="italic">'._("Begin").'</font>'.
 	     '&nbsp;&nbsp;&nbsp;&nbsp;'.
-	     '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/previousgrey.png" border="0" alt="'._("Previous Results").'" /><font class="italic">'._("Previous Results").'</font>';
+	     '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/previousgrey.png" border="0" alt="'._("Previous Results").'" /><font class="italic">'._("Previous Results").'</font></font>';
 	}
     }
 
 
   $offset_last = min($offset+$chunksz-1, $total_rows-1);
 
-  $nav_bar .= " &nbsp;  &nbsp; &nbsp; &nbsp; ".sprintf(_("Items %s to %s"), ($offset+1), ($offset_last+1))."  &nbsp; &nbsp; &nbsp; &nbsp; ";
+  #fb("$offset_last offset_last");
+
+  $nav_bar .= " &nbsp;  &nbsp; &nbsp; &nbsp; ".sprintf(ngettext("%d matching item", "%d matching items", $total_rows), $total_rows);
+  $nav_bar .= " - ".sprintf(_("Items %s to %s"), ($offset+1), ($offset_last+1))."  &nbsp; &nbsp; &nbsp; &nbsp; ";
 
 
   # If all items are on screen, no next/end pointer at all
@@ -98,105 +94,104 @@ function show_item_list ($result,
 	  if ($offset_end == $total_rows)
 	    { $offset_end -= $chunksz; }
 
+	  #fb("$offset_end offset_end");
+
 	  $nav_bar .=
-	     '<a href="'.$url.'&amp;offset='.($offset+$chunksz).
+	     '<font class="xsmall"><a href="'.$url.'&amp;offset='.($offset+$chunksz).
 	     '#results">'._("Next Results").'<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/next.png" border="0" alt="'._("Next Results").'" /></a>'.
 	     '&nbsp;&nbsp;&nbsp;&nbsp;'.
 	     '<a href="'.$url.'&amp;offset='.($offset_end).
-	     '#results">'._("End").'<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/last.png" border="0" alt="'._("End").'" /></a>';
+	     '#results">'._("End").'<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/last.png" border="0" alt="'._("End").'" /></a></font>';
 	}
       else
 	{
-	  $nav_bar .= '<font class="italic">'._("Next Results").'</font><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/nextgrey.png" border="0" alt="'._("Next Results").'" />'.
+	  $nav_bar .= '<font class="xsmall"><font class="italic">'._("Next Results").'</font><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/nextgrey.png" border="0" alt="'._("Next Results").'" />'.
 	     '&nbsp;&nbsp;&nbsp;&nbsp;'.
-	     '<font class="italic">'._("End").'</font><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/lastgrey.png" border="0" alt="'._("End").'" />';
+	     '<font class="italic">'._("End").'</font><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/lastgrey.png" border="0" alt="'._("End").'" /></font></font>';
 	}
     }
-  $nav_bar .= '</h5>';
+  $nav_bar .= '</h3>';
 
   # Print prev/next links
-  print $nav_bar.'<br />';
+  print $nav_bar.'<a name="results"></a><br />';
 
   print html_build_list_table_top ($title_arr,$links_arr);
 
   #see if the bugs are too old - so we can highlight them
   $nb_of_fields = count($field_arr);
 
-
-
-  for ($i=0; $i < $rows ; $i++)
+  while (list(,$thisitem) = each($result_arr))
     {
-      # Do not even show private item, apart to technician level members
-      # and submitter
-      if (db_result($result, $i, 'privacy') == "2" &&
-	  !member_check_private(0,$group_id) &&
-	  db_result($result,$i,'submitted_by') != user_getname())
+      $thisitem_id = $thisitem['bug_id'];
+      
+      print '<tr class="'.utils_get_priority_color($result_arr[$thisitem_id]["priority"], $result_arr[$thisitem_id]["status_id"]).'">'."\n";
+      
+      for ($j=0; $j<$nb_of_fields; $j++)
 	{
-	  dbg("Private item.");
-	}
-      else
-	{
-	  print '<tr class="'.utils_get_priority_color(db_result($result, $i, 'priority'), db_result($result, $i, 'status_id')).'">'."\n";
-	  $thisitem_id = db_result($result, $i, 'bug_id');
-
-	  for ($j=0; $j<$nb_of_fields; $j++)
+           # If we are in digest mode, add the digest checkbox
+	  if ($field_arr[$j] == "digest")
 	    {
-	      # If we are in digest mode, add the digest checkbox
-	      if ($field_arr[$j] == "digest")
+	      print '<td class="center">'.form_input("checkbox", "items_for_digest[]", $thisitem_id).'</td>';
+	      continue;
+	    }
+	  
+	  $value = $result_arr[$thisitem_id][$field_arr[$j]];
+	  if ($width_arr[$j])
+	    {
+	      $width = 'width="'.$width_arr[$j].'%"';
+	    }
+	  else
+	    {
+	      $width = '';
+	    }
+	  
+	  if (trackers_data_is_date_field($field_arr[$j]) )
+	    {
+	      if ($value)
 		{
-		  print '<td class="center">'.form_input("checkbox", "items_for_digest[]", $thisitem_id).'</td>';
-		  continue;
-		}
-
-	      $value = db_result($result, $i, $field_arr[$j]);
-	      if ($width_arr[$j])
-		{
-		  $width = 'width="'.$width_arr[$j].'%"';
+		  if ($field_arr[$j] == 'planned_close_date' and $value < time())
+		    { $highlight_date = ' class="highlight"'; }
+		  else
+		    { $highlight_date = ''; }
+		  print "<td $width$highlight_date>";
+		  print format_date($sys_datefmt,$value);
+		  print "</td>\n";
 		}
 	      else
-		{
-		  $width = '';
-		}
-
-	      if (trackers_data_is_date_field($field_arr[$j]) )
-		{
-		  if ($value)
-		    { print "<td $width>".format_date($sys_datefmt,$value).'</td>'."\n"; }
-		  else
-		    { print "<td align=\"middle\" $width>-</td>\n"; }
-
-		}
-	      else if ($field_arr[$j] == 'bug_id')
-		{
-
-		  if ($nolink)
-		    { print "<td $width>#$value</td>\n"; }
-		  else
+		{ print "<td align=\"middle\" $width>-</td>\n"; }
+	      
+	    }
+	  else if ($field_arr[$j] == 'bug_id')
+	    {
+	      
+	      if ($nolink)
+		{ print "<td $width>#$value</td>\n"; }
+	      else
 		    {
 		      print "<td $width>";
-
+		      
 		      print '<a href="?func=detailitem&amp;item_id='.$value.'">';
-
+		      
 		      print '&nbsp;#'.$value .'</a></td>'."\n";
-
+		      
 		    }
-
-		}
-	      else if (trackers_data_is_username_field($field_arr[$j]))
-		{
-
-		  if ($nolink)
-		    { print "<td $width>$value</td>\n"; }
-		  else
-		    { print "<td $width>".utils_user_link($value)."</td>\n"; }
-
-		}
-	      else if (trackers_data_is_select_box($field_arr[$j]))
-		{
-		  print "<td $width>". trackers_data_get_cached_field_value($field_arr[$j], $group_id, $value) .'</td>'."\n";
-
-		}
+	      
+	    }
+	  else if (trackers_data_is_username_field($field_arr[$j]))
+	    {
+	      
+	      if ($nolink)
+		{ print "<td $width>$value</td>\n"; }
 	      else
+		{ print "<td $width>".utils_user_link($value)."</td>\n"; }
+	      
+	    }
+	  else if (trackers_data_is_select_box($field_arr[$j]))
+	    {
+	      print "<td $width>". trackers_data_get_cached_field_value($field_arr[$j], $group_id, $value) .'</td>'."\n";
+	      
+	    }
+	  else
 		{
 		  if ($nolink)
 		    { print "<td $width>". $value .'&nbsp;</td>'."\n"; }
@@ -207,13 +202,13 @@ function show_item_list ($result,
 			$value .'</a>&nbsp;</td>'."\n";
 		    }
 		}
-	    }
+	  
 	}
       print "</tr>\n";
     }
-
+  
   print '</table>';
-
+  
   # Print prev/next links
   print "<br />".$nav_bar;
 
