@@ -2,12 +2,13 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: add.php,v 1.21 2005/06/30 17:19:36 toddy Exp $
+# $Id: add.php,v 1.28 2005/09/23 07:26:49 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
 #
-#  Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
+#  Copyright 2003-2005 (c) Mathieu Roy <yeupou--gnu.org>
+#                          Yves Perrin <yves.perrin--cern.ch>
 #
 #
 # The Savane project is free software; you can redistribute it and/or
@@ -45,15 +46,13 @@ print form_header($PHP_SELF, $form_id, "post", 'enctype="multipart/form-data" na
 print form_input("hidden", "func", "postadditem");
 print form_input("hidden", "group_id", $group_id);
 print '
-	<table cellpadding="0">
-	<tr><td valign="top" colspan="'.(2*$fields_per_line).'">
-        </td></tr>';
-
+     <table cellpadding="0" width="100%">';
 
 
 # Now display the variable part of the field list (depend on the project)
 
 $i=0;
+$j=0;
 $is_trackeradmin = member_check(0,$group_id,member_create_tracker_flag(ARTIFACT).'2');
 
 while ($field_name = trackers_list_all_fields()) 
@@ -87,6 +86,15 @@ while ($field_name = trackers_list_all_fields())
 						$group_id,
 						false,
 						false);
+          # check if the field is mandatory
+	  unset($star);
+	  $mandatory_flag = trackers_data_mandatory_flag($field_name);
+	  if ($mandatory_flag == 3 || $mandatory_flag == 0)	    
+	    {
+	      $star = '<font class="warn"> *</font>';
+	      $mandatory_flag = 0;
+	    }
+
 	  # Field display with special Unknown option, only for fields that
 	  # are no mandatory
 	  $value = trackers_field_display($field_name,
@@ -101,26 +109,57 @@ while ($field_name = trackers_list_all_fields())
 					  false, #10				  
 					  false,
 					  true, #12
-					  trackers_data_is_empty_ok($field_name));
-	  $star = (trackers_data_is_empty_ok($field_name) ? '':'<font class="warn"> *</font>');
+					  $mandatory_flag);
 	  
+          # Fields colors
+	  unset($field_class, $row_class);
+	  if ($previous_form_bad_fields && array_key_exists($field_name, $previous_form_bad_fields))
+	    {  
+                  # We highlight fields that were not properly/completely 
+		  # filled.
+	      $field_class = ' class="highlight"';
+	    }
+	  if ($j % 2 && $field_name != 'details')
+	    {
+		  # We keep the original submission with the default
+		  # background color, for lisibility sake
+		  #
+		  # We also use the boxitem background color only one time
+		  # out of two, to keep the page light
+	      $row_class = ' class="'.utils_altrow($j+1).'"'; 
+	    }
 
 	  if ($sz > $max_size) 
 	    {
-	      print "\n<tr>".
-		'<td valign="middle">'.$label.'</td>'.
-		'<td valign="middle" colspan="'.(2*$fields_per_line-1).'">'.
+              # Field getting one line for itself 
+
+              # Each time prepare the background color change
+	      $j++;
+
+	      print "\n<tr".$row_class.">".
+		'<td valign="middle"'.$field_class.' width="15%">'.$label.'</td>'.
+		'<td valign="middle"'.$field_class.' colspan="'.(2*$fields_per_line-1).'" width="75%">'.
 		$value.$star.'</TD>'.		      
-		"\n</TR>";
+		"\n</tr>";
 	      $i=0;
 	    } 
 	  else 
 	    {
-	      print ($i % $fields_per_line ? '':"\n<tr>");
-	      print '<td valign="middle">'.$label.'</td>'.
-		'<td valign="middle">'.$value.$star.'</td>';
+              # Field getting half of a line for itself 
+	      
+	      if (!($i % $fields_per_line))
+		{
+		  # Every one out of two, prepare the background color change.
+		  # We do that at this moment because we cannot be sure
+		  # there will be another field on this line.
+		  $j++;		  
+		}
+
+	      print ($i % $fields_per_line ? "\n":"\n<tr".$row_class.">");
+	      print '<td valign="middle"'.$field_class.' width="15%">'.$label.'</td>'.
+		'<td valign="middle"'.$field_class.' width="35%">'.$value.$star.'</td>';
 	      $i++;
-	      print ($i % $fields_per_line ? '':"\n</tr>");
+	      print ($i % $fields_per_line ? "\n":"\n</tr>");
 	    }
 	}
     }
