@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: field_usage.php,v 1.25 2005/08/31 21:05:09 yeupou Exp $
+# $Id: field_usage.php,v 1.31 2005/09/26 18:27:34 yeupou Exp $
 #
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
 #
@@ -30,28 +30,36 @@ if ($group_id && user_ismember($group_id,'A')) {
   # Initialize global bug structures
   trackers_init($group_id);
 
+
   if ($post_changes)
     {
+###########################################################################
       # A form was posted to update a field
 
       if ($submit)
 	{
 	  if (isset($n1) && isset($n2))
-	    {
-	      $display_size = "$n1/$n2";
-	    }
+	    { $display_size = "$n1/$n2"; }
 
-	  # these are checkboxes so make sure they have value 0 if needed.
-	  # 0 and 'not in the form' doesn't mean the same thing. if it is not set
-	  # but is in the form it means value 0, if it is not set and not in the form
-	  # it means use the system default.
-	  if (!isset($keep_history) && $keep_history_here)
+
+	  if (!trackers_data_is_required($field))
 	    {
-	      $keep_history = 0;
+               # Vote must be possible for members
+               # Vote cannot be possible for non logged in
+	      if ($field == "vote") 
+		{
+		  $show_on_add_nologin = 0;
+		  $show_on_add_members = 1;
+		}
 	    }
-	  if (!isset($empty_ok) && $empty_ok_here)
+	  else
 	    {
-	      $empty_ok = 0;
+              # Do not let the user change these field settings
+	      # if the field is required
+	      $show_on_add_members = trackers_data_is_showed_on_add_members($field);
+	      $show_on_add = trackers_data_is_showed_on_add($field);
+	      $show_on_add_nologin = trackers_data_is_showed_on_add_nologin($field);
+	      
 	    }
 
 	  # the additional possibility of differently treating non project
@@ -62,9 +70,18 @@ if ($group_id && user_ismember($group_id,'A')) {
 	  # bit 2 set: show for non logged in users
 	  $show_on_add = $show_on_add | $show_on_add_nologin;
 
-	  trackers_data_update_usage($field,$group_id,$label,$description,
-				$status,$place,$display_size,$empty_ok,$keep_history,
-				$show_on_add_members,$show_on_add, $form_transition_default_auth);
+	  trackers_data_update_usage($field,
+				     $group_id,
+				     $label,
+				     $description,
+				     $status,
+				     $place,
+				     $display_size,
+				     $mandatory_flag,
+				     $keep_history,
+				     $show_on_add_members,
+				     $show_on_add,
+				     $form_transition_default_auth);
 	}
       else if ($reset)
 	{
@@ -79,12 +96,20 @@ if ($group_id && user_ismember($group_id,'A')) {
   if ($update_field)
     {
 
+###########################################################################
       # Show the form to change a field setting
 
+      # HELP:
+      #   - "required" means the field must be used, no matter what
+      #   - "special" means the field is not entered by the user but by the
+      #   system
+
       trackers_header_admin(array ('title'=>_("Modify Field Usage")));
 
-      # Escape to display the form
 
+      ######
+      ## General stuff
+     
       print '<form action="'.$PHP_SELF.'" method="post">';
       print '<input type="hidden" name="post_changes" value="y" />
       <input type="hidden" name="field" value="'.$field.'" />
@@ -100,8 +125,8 @@ if ($group_id && user_ismember($group_id,'A')) {
 	  print '<input type="text" name="label" value="'.trackers_data_get_label($field).
 	    '" size="20" maxlength="85">'.$closetag;
 	  print '<span class="preinput">'._("Description:").' </span>';
-	  print '<input type="text" name="description" value="'.trackers_data_get_description($field).
-	    '" size="70" maxlength="255" />';
+	  print '<br />&nbsp;&nbsp;&nbsp;<input type="text" name="description" value="'.trackers_data_get_description($field).
+	    '" size="70" maxlength="255" /><br />';
 	}
       else
 	{
@@ -109,141 +134,176 @@ if ($group_id && user_ismember($group_id,'A')) {
 	}
 
       print '<span class="preinput">'._("Status:").' </span>&nbsp;&nbsp;';
+
       # Display the Usage box (Used, Unused select box  or hardcoded "required')
       if (trackers_data_is_required($field))
 	{
-	  print _("Required");
+	  print '<br />&nbsp;&nbsp;&nbsp;'._("Required");
 	  print '<input type="hidden" name="status" value="1" />';
 	}
       else
 	{
-	  print '<select name="status">
+	  print '<br />&nbsp;&nbsp;&nbsp;
+<select name="status">
 	   <option value="1"'.(trackers_data_is_used($field)?' selected="selected"':'').'>'._("Used").'</option>
 	   <option value="0"'.(trackers_data_is_used($field)?'':' selected="selected"').'>'._("Unused").'</option>
-      </select>';
+</select>';
 	}
-
-      # Customize field size only for text fields and text areas.
-      if (trackers_data_is_text_field($field))
-	{
-	  list($size,$maxlength) = trackers_data_get_display_size($field);
-	  print "\n\n<p>&nbsp;</p><h3>"._("Field Size:").' ('._("in characters").')</h3><ul>';
-	  print '<li><span class="preinput">'._("Visible Field Size:").' </span>';
-	  print '<input type="text" name="n1" value="'.$size.
-	    '" size="3" maxlength="3" />&nbsp;&nbsp;';
-	  print '<li><span class="preinput">'._("Maximum length:").' </span>';
-	  print '<input type="text" name="n2" value="'.$maxlength.
-	    '" size="3" maxlength="3" />&nbsp;&nbsp; ('._("up to  255").'</ul>';
-	}
-      else if (trackers_data_is_text_area($field))
-	{
-	  list($rows,$cols) = trackers_data_get_display_size($field);
-	  print "\n\n<p>&nbsp;</p><h3>"._("Field Size:").'</h3><ul>';
-	  print '<li><span class="preinput">'._("Number of columns:").' </span>';
-	  print '<input type="text" name="n1" value="'.$rows.
-	    '" size="3" maxlength="3" />&nbsp;&nbsp;';
-	  print '<li><span class="preinput">'._("Number of rows:").' </span>';
-	  print '<input type="text" name="n2" value="'.$cols.
-	    '" size="3" maxlength="3" /></ul>';
-	}
-      # Remark: Date fields have a fixed size that cannot be changed
-
-
-      # Customize Properties
+      
+      # Ask they want to save the history of the item
       if (!trackers_data_is_special($field))
 	{
-	  print "\n\n<p>&nbsp;</p><h3>"
-	    ._("Properties:").'</h3><ul>';
-	  print '<li><input type="checkbox" name="empty_ok" value="1" '.
-	    (trackers_data_is_empty_ok($field)?' checked="checked"':'').' /><input type="hidden" name="empty_ok_here" value="1" />'.
-	    ' <span class="preinput">' ._("Allow Empty Value").' </span></li>';
-	  print '<li><input type="checkbox" name="keep_history" value="1" '.
-	    (trackers_data_do_keep_history($field)?' checked="checked"':'').' /><input type="hidden" name="keep_history_here" value="1" />'.
-	    '  <span class="preinput">'._("Keep Change History").'</span></li>';
-	  print '</ul>';
+	  print '<br /><span class="preinput">'._("Item History:").' </span>
+<br />&nbsp;&nbsp;&nbsp;
+<select name="keep_history">
+	   <option value="1"'.(trackers_data_do_keep_history($field)?' selected="selected"':'').'>'._("Keep field value changes in history").'</option>
+	   <option value="0"'.(trackers_data_do_keep_history($field)?'':' selected="selected"').'>'._("Ignore field value changes in history").'</option>
+</select>';
+
 	}
 
-      # Customize screen presence
-      if (!trackers_data_is_required($field) 
-	  # && !trackers_data_is_special($field) : this was set with 
-	  #                             $field_name, which is not used in this
-	  #                             page. Fixing this obvious mistake would
-	  #                             change the whole page behavior.
-	  #                             So it's commented out but kept as 
-          #                             reminder.
-          # I suspect that the is_special affect the way the field shown, 
-          # making useless the rank parameter.
-	  )
-	{
+      ######
+      ## Content control
 
-	  # Add members must be possible for members for the vote field
-	  if ($field != "vote") 
+      print "\n\n<p>&nbsp;</p><h3>"._("Access:").'</h3>';
+ 
+      # Set mandatory bit: if the field is special, meaning it is entered
+      # by the system, or if it is "priority", assume the 
+      # admin is not entitled to modify this behavior
+      if (!trackers_data_is_special($field))
+	{
+          # "Mandatory" is not really 100% mandatory, only if it is possible
+          # for a user to fill the entry.
+          # It is "Mandatory whenever possible".
+          $mandatory_flag = trackers_data_mandatory_flag($field);
+	  print '<span class="preinput">'._("This field is:").' </span>
+<br />&nbsp;&nbsp;&nbsp;
+<select name="mandatory_flag">
+	   <option value="1"'.(($mandatory_flag == 1)?' selected="selected"':'').'>'._("Optional (empty values are accepted)").'</option> 
+	   <option value="3"'.(($mandatory_flag == 3)?' selected="selected"':'').'>'._("Mandatory").'</option>
+	   <option value="0"'.(($mandatory_flag == 0)?' selected="selected"':'').'>'._("Mandatory only if it was presented to the original submitter").'</option>
+</select><br />';
+ 	}
+
+      print '<span class="preinput">'._("On new item submission, present this field to:").' </span>';
+      unset($checkbox_members, $checkbox_loggedin, $checkbox_anonymous);
+      if (!trackers_data_is_required($field))
+	{
+          # Some fields require specific treatment
+	  if ($field != "vote" && $field != "originator_email") 
 	    {
-	      $addm_html = '<input type="checkbox" name="show_on_add_members" value="1"'.
-	     (trackers_data_is_showed_on_add_members($field)?' checked="checked"':'').' />';
+	      $checkbox_members = '<input type="checkbox" name="show_on_add_members" value="1"'.
+		(trackers_data_is_showed_on_add_members($field)?' checked="checked"':'').' />';
+	      $checkbox_anonymous = '<input type="checkbox" name="show_on_add_nologin" value="2"'.
+		(trackers_data_is_showed_on_add_nologin($field)?' checked="checked"':'').' />';	  
+              $checkbox_loggedin = '<input type="checkbox" name="show_on_add" value="1"'.
+	    (trackers_data_is_showed_on_add($field)?' checked="checked"':'').' />';
             }
 	  else
 	    {
-	      $addm_html = '<input type="hidden" name="show_on_add_members" value="1" />'._("Always");
+              # Vote must be possible for members
+	      # Vote cannot be possible for non logged in
+   	     if ($field != "vote") 
+              {
+	        $checkbox_members = '+';
+	        $checkbox_anonymous = 0;
+                $checkbox_loggedin = '<input type="checkbox" name="show_on_add" value="1"'.
+	    (trackers_data_is_showed_on_add($field)?' checked="checked"':'').' />';
+              }
+
+              # Originator email is, by the code, available only to
+              # anonymous
+   	     if ($field != "vote") 
+              { 
+ 	        $checkbox_members = 0;
+	        $checkbox_loggedin = 0;
+                $checkbox_anonymous = '<input type="checkbox" name="show_on_add_nologin" value="2"'.
+		(trackers_data_is_showed_on_add_nologin($field)?' checked="checked"':'').' />';	  
+
+              }
+
 	    }
 
-	  $add_html = '<input type="checkbox" name="show_on_add" value="1"'.
-	     (trackers_data_is_showed_on_add($field)?' checked="checked"':'').' />';
-	  # Nologin is not possible for non-logged people for the vote field
-	  if ($field != "vote") 
-	    {
-	      $add_nologin_html = '<input type="checkbox" name="show_on_add_nologin" value="2"'.
-		(trackers_data_is_showed_on_add_nologin($field)?' checked="checked"':'').' />';
-	    }
-	  else
-	    {
-	      $add_nologin_html = '<input type="hidden" name="show_on_add_nologin" value="0" />'._("Never");
-	    }
 	}
       else
 	{
-
-	  # Do not let the user change these field settings but put them in the
-	  # form to preserve the existing setting or use the default values
-	  # imposed at the system level
-	  $addm_html = '<input type="hidden" name="show_on_add_members" '.
-	     'value="'.(trackers_data_is_showed_on_add_members($field)? 1:0).'" />'.
-	     (trackers_data_is_showed_on_add_members($field)? _("Always"):_("Never"));
-	  $add_html = '<input type="hidden" name="show_on_add" '.
-	     'value="'.(trackers_data_is_showed_on_add($field)? 1:0).'" />'.
-	     (trackers_data_is_showed_on_add($field)? _("Always"):_("Never").'');
-	  
-	  $add_nologin_html = '<input type="hidden" name="show_on_add_nologin" '.
-	    'value="'.(trackers_data_is_showed_on_add_nologin($field)? 2:0).'" />'.
-	    (trackers_data_is_showed_on_add_nologin($field)? _("Always"):_("Never").'');
-
-
+	  # Do not let the user change these field settings
+	  if (trackers_data_is_showed_on_add_members($field))
+	    {
+	      $checkbox_members = '+';
+	    }
+	  if (trackers_data_is_showed_on_add($field))
+	    {
+	      $checkbox_loggedin = '+';
+	    }
+	  if (trackers_data_is_showed_on_add_nologin($field))
+	    {
+	      $checkbox_anonymous = '+';
+	    }
+	}
+      
+      if ($checkbox_members) 
+	{
+	  print '<br />&nbsp;&nbsp;&nbsp;'.$checkbox_members.' '._("Project Members");
+	}
+      if ($checkbox_loggedin) 
+	{
+	  print '<br />&nbsp;&nbsp;&nbsp;'.$checkbox_loggedin.' '._("Logged-in Users");
+	}      
+      if ($checkbox_anonymous) 
+	{
+	  print '<br />&nbsp;&nbsp;&nbsp;'.$checkbox_anonymous.' '._("Anonymous Users");
 	}
 
+
+
+      ######
+      ## Display control
+
       print "\n\n<p>&nbsp;</p><h3>"._("Display:").'</h3>';
+ 
       # yeupou--gnu.org 2005-07-18
       # I suspect that the is_special affect the way the field shown, 
       # making useless the rank parameter.
       # Check the previous comments
       if (!trackers_data_is_special($field))
         {
-           print '<span class="preinput">'._("Rank on screen:").' </span>&nbsp;&nbsp;';
-           print '<input type="text" name="place" value="'.trackers_data_get_place($field).
-	'" size="6" maxlength="6" />'."\n";
+	  print '<span class="preinput">'._("Rank on screen:").' </span><br />&nbsp;&nbsp;&nbsp;';
+	  print '<input type="text" name="place" value="'.trackers_data_get_place($field).
+	    '" size="6" maxlength="6" /><br />'."\n";
         }
       else 
         {
            print '<input type="hidden" name="place" value="'.trackers_data_get_place($field).'" />';
         }
-      print '<ul>';
-      print '<li>'.$addm_html.' <span class="preinput">'._("on the submission form used by project members").'</span></li>';
-      print '<li>'.$add_html.' <span class="preinput">'._("on the submission form used by other logged in users").'</span></li>';
-      print '<li>'.$add_nologin_html.' <span class="preinput">'._("on the submission form used by non logged in users").'</span></li></ul>';
-      
+
+      # Customize field size only for text fields and text areas.
+      if (trackers_data_is_text_field($field))
+	{
+	  list($size,$maxlength) = trackers_data_get_display_size($field);
+
+	  print '<span class="preinput">'._("Visible size of the field:").' </span><br />&nbsp;&nbsp;&nbsp;';
+	  print '<input type="text" name="n1" value="'.$size.'" size="3" maxlength="3" /><br />';
+	  print '<span class="preinput">'._("Maximum size of the field content (up to 255):").' </span><br />&nbsp;&nbsp;&nbsp;';
+	  print '<input type="text" name="n2" value="'.$maxlength.'" size="3" maxlength="3" /><br />';
+	}
+      else if (trackers_data_is_text_area($field))
+	{
+	  list($rows,$cols) = trackers_data_get_display_size($field);
+
+	  print '<span class="preinput">'._("Number of columns of the field:").' </span><br />&nbsp;&nbsp;&nbsp;';
+	  print '<input type="text" name="n1" value="'.$rows.'" size="3" maxlength="3" /><br />';
+	  print '<span class="preinput">'._("Number of rows  of the field:").' </span><br />&nbsp;&nbsp;&nbsp;';
+	  print '<input type="text" name="n2" value="'.$cols.'" size="3" maxlength="3" /><br />';
+	}
+
+      ######
+      ## Transitions
+     
       $transition_default_auth = db_result(db_query("SELECT transition_default_auth FROM ".ARTIFACT."_field_usage WHERE group_id='$group_id' AND bug_field_id='".trackers_data_get_field_id($field)."'"), 0, 'transition_default_auth');
 
-      print "\n\n<p>&nbsp;</p><h3>"._("By default, transitions (from one value to another) are:").'</h3><ul>';
-      print '<li><input type="radio" name="form_transition_default_auth" value="A" '.(($transition_default_auth!='F')?' checked="checked"':'').' /> '._("Allowed").'</li><li><input type="radio" name="form_transition_default_auth" value="F" '.(($transition_default_auth=='F')?'checked="checked"':'').' /> '._("Forbidden").'</li></ul>';
+      print "\n\n<p>&nbsp;</p><h3>"._("By default, transitions (from one value to another) are:").'</h3>';
+      print '&nbsp;&nbsp;&nbsp;<input type="radio" name="form_transition_default_auth" value="A" '.(($transition_default_auth!='F')?' checked="checked"':'').' /> '._("Allowed").'<br />&nbsp;&nbsp;&nbsp;<input type="radio" name="form_transition_default_auth" value="F" '.(($transition_default_auth=='F')?'checked="checked"':'').' /> '._("Forbidden");
 
       print '
       	<p align="center">
@@ -260,10 +320,9 @@ if ($group_id && user_ismember($group_id,'A')) {
     }
   else
     {
-
-      /*
-	  Show main page
-      */
+      
+###########################################################################
+      ## Show main page
 
       trackers_header_admin(array ('title'=>_("Field Usage")));
 
@@ -373,6 +432,7 @@ if ($group_id && user_ismember($group_id,'A')) {
 
 } else {
 
+###########################################################################
   #browse for group first message
 
   if (!$group_id)
