@@ -2,13 +2,13 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: detail.php,v 1.44 2005/09/01 13:13:53 toddy Exp $
+# $Id: detail.php,v 1.50 2005/09/11 13:39:32 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
 #
-#  Copyright 2002-2005 (c) Mathieu Roy <yeupou--at--gnu.org>
-#                          Yves Perrin <yves.perrin--at--cern.ch>
+#  Copyright 2002-2005 (c) Mathieu Roy <yeupou--gnu.org>
+#                          Yves Perrin <yves.perrin--cern.ch>
 #
 #
 # The Savane project is free software; you can redistribute it and/or
@@ -60,8 +60,16 @@ if (db_numrows($result) > 0)
 	  exit_error(_("This item is private."));
 	}
     }
+  
+  # Check if it is possible for the current user to post a comment. If not
+  # add a message
+  if (!group_restrictions_check($group_id, ARTIFACT, 2))
+    {
+      $private_intro .= ' '._("You are not allowed to post comments on this tracker with your current authentification level.");
+    }
 
-  trackers_header(array ('title'=>_("Item Detail:").' '.$item_id));
+
+  trackers_header(array ('title'=>$item_name.", ".utils_cutstring(db_result($result,0,'summary'))));
 
   print $private_intro;
 
@@ -72,78 +80,160 @@ if (db_numrows($result) > 0)
   print form_input("hidden", "group_id", $group_id);
   print form_input("hidden", "item_id", $item_id);
 
-  print '<table cellpadding="0" width="100%">';
-  print '<tr><td><font class="preinput">'._("Submitted by:").'</font>&nbsp;'.utils_user_link(user_getname(db_result($result,0,'submitted_by')),user_getrealname(db_result($result,0,'submitted_by'))).'</td>';
-  print '<td colspan="6" align="center" valign="top"><span class="noprint"><input type="submit" name="submit" value="'._("Submit Changes").'" class="bold"></span></td>';
-  print '</tr>';
-  print '<tr><td><font class="preinput">'._("Submitted on:").'</font>&nbsp;'.format_date($sys_datefmt,db_result($result,0,'date')).'</td>';
-  print '<td>&nbsp;</td>';
-  print '</tr>';
+  # Colspan explanation:
+  #
+  #  We want the following, twice much space for the value than for the label
+  #
+  #  | Label:  Value________| Label:  Value______ |
+  #  | Label:  Value_____________________________ |
+  #
+  #  So we have 4 column large via colspan.
+
+  print '
+
+  <table cellpadding="0" width="100%">
+      <tr>
+          <td class="preinput" width="15%">'._("Submitted by:").'&nbsp;</td>
+          <td width="35%">'.utils_user_link(user_getname(db_result($result,0,'submitted_by')), user_getrealname(db_result($result,0,'submitted_by'))).'</td>
+          <td colspan="'.($fields_per_line).'" align="center"  width="50%" valign="top"><span class="noprint"><input class="bold" type="submit" name="submit" value="'._("Submit Changes").'" ></span></td>
+      </tr>
+      <tr>
+          <td class="preinput" width="15%">'._("Submitted on:").'&nbsp;</td>
+          <td width="35%">'.format_date($sys_datefmt,db_result($result,0,'date')).'</td>
+          <td colspan="'.($fields_per_line).'" align="center"  width="50%" valign="top">&nbsp;</td>
+      </tr>';
   $votes = db_result($result,0,'vote');
+
   if ($votes) 
     {
       # display vote here if any, anything else is handled below
       print '
       <tr>
-          <td class="preinput">'._("Votes:").'&nbsp;<a href="#votes">'.$votes.'</a></td><td>&nbsp;</td>
+          <td class="preinput" width="15%">'._("Votes:").'&nbsp;</td>
+          <td width="35%"><a href="#votes">'.$votes.'</a></td>
+          <td colspan="'.($fields_per_line).'" width="50%">&nbsp;</td>
       </tr>
 ';
 
     }
 
-  print '<tr><td colspan="'.$fields_per_line.'">&nbsp</td></tr>';
+  print '<tr><td colspan="'.($fields_per_line*2).'">&nbsp</td></tr>';
 
   # Print special fields
-
   $i=0;
+  $j=0;
   while ( $field_name = trackers_list_all_fields() ) 
     {
-
-
       # if the field is a special field (except summary and details) 
       # or if not used by this project  then skip it.
       if ( (!trackers_data_is_special($field_name)  || $field_name=='summary' || $field_name=='details') &&
 	   trackers_data_is_used($field_name) ) 
 	{
 
-	  # if the submitter was anonymous, print the originator email field
+	  # print the originator email field only if it was posted by
+	  # an anonymous user
 	  if ($field_name != 'originator_email' ||
 	      ($field_name == 'originator_email' && db_result($result,0,'submitted_by') == '100'))
 	    {
 	   
 	  # display the bug field
 	  # if field size is greatest than max_size chars then force it to
-	  # appear alone on a new line or it won't fit in the page
-	  $field_value = db_result($result,0,$field_name);
-	  list($sz,) = trackers_data_get_display_size($field_name);
+	  # appear alone on a new line or it wont fit in the page
+	      $field_value = db_result($result,0,$field_name);
+	      list($sz,) = trackers_data_get_display_size($field_name);
 
-	  if ($field_name=='details') 
-	    { $field_value = utils_make_links($field_value); }
+	      if ($field_name == 'details') 
+		{ $field_value = utils_make_links($field_value); }
+	      
+	      $field_display = trackers_field_display($field_name,$group_id,$field_value,false,true,true);
 
-	  $field_display = trackers_field_display($field_name,$group_id,$field_value,false,true,true);
+	      $label = trackers_field_label_display($field_name,$group_id,false,false);
+	      $value = trackers_field_display($field_name,$group_id,$field_value,false,false,true);
 	
-          # Save the assigned to value for later
-	  if ($field_name == 'assigned_to')
-           { 
-	     $item_assigned_to = trackers_field_display($field_name,$group_id,$field_value,false,false,true); 
-           }
+              # Save the assigned to value for later.
+	      # Also make the user link for this same field
+	      if ($field_name == 'assigned_to')
+		{ 
+		  $item_assigned_to = trackers_field_display($field_name,$group_id,$field_value,false,false,true); 
+		  
+		  $value = utils_user_link(user_getname($field_value), user_getrealname($field_value));
+		}
+	      # Details need a specific div
+	      if ($field_name == 'details')
+		{
+		  $value = '<div class="trackersoriginalsubmission">'.$value.'</div>';
+		}
 
 
-	  if ($sz > $max_size) 
-	    {
-	      print "\n<tr>".
-		'<td valign="top" colspan="'.$fields_per_line.'">'.
-		$field_display.'</td>'."\n</tr>";
-	      $i=0;
-	    } 
-	  else 
-	    {
-	      print ($i % $fields_per_line ? '':"\n<tr>");
-	      print '<td valign="top">'.$field_display.'</td>';
-	      $i++;
-	      print ($i % $fields_per_line ? '':"\n</tr>");
+              # Fields colors
+	      unset($field_class, $row_class);
+	      if ($previous_form_bad_fields && array_key_exists($field_name, $previous_form_bad_fields))
+		{  
+                  # We highlight fields that were not properly/completely 
+		  # filled.
+		  $field_class = ' class="highlight"';
+		}
+	      if ($j % 2 && $field_name != 'details')
+		{
+		  # We keep the original submission with the default
+		  # background color, for lisibility sake
+		  #
+		  # We also use the boxitem background color only one time
+		  # out of two, to keep the page light
+		  $row_class = ' class="'.utils_altrow($j+1).'"'; 
+		}
+		  
+	      if ($sz > $max_size)
+		{
+		  # Field getting one line for itself 
+
+                  # Each time change the background color
+		  $j++;
+
+		  print "\n<tr".$row_class.">".
+		    '<td valign="middle" '.$field_class.' width="15%">'.$label.'</td>'.
+		    '<td valign="middle" '.$field_class.' colspan="'.(2*$fields_per_line-1).'" width="75%">'.
+		    $value.'</td>'.
+		    "\n</tr>";
+		  $i=0;
+		}
+	      else
+		{
+                  # Field getting half of a line for itself 
+		  
+		  
+		  if (!($i % $fields_per_line))
+		    {
+		      # Every one out of two, prepare the background color change.
+   		      # We do that at this moment because we cannot be sure
+ 		      # there will be another field on this line.
+		      $j++;		  
+		    }
+
+		  print ($i % $fields_per_line ? '':"\n<tr".$row_class.">");
+		  print '<td valign="middle"'.$field_class.' width="15%">'.$label.'</td>'.
+		    '<td valign="middle"'.$field_class.' width="35%">'.$value.'</td>';
+		  $i++;
+		  print ($i % $fields_per_line ? '':"\n</tr>");
+		}
+	      
+	      
+	      
+// 	      if ($sz > $max_size) 
+// 		{
+// 		  print "\n<tr>".
+// 		    '<td valign="top" colspan="'.$fields_per_line.'">'.
+// 		    $field_display.'</td>'."\n</tr>";
+// 		  $i=0;
+// 		} 
+// 	      else 
+// 		{
+// 		  print ($i % $fields_per_line ? '':"\n<tr>");
+// 		  print '<td valign="top">'.$field_display.'</td>';
+// 		  $i++;
+// 		  print ($i % $fields_per_line ? '':"\n</tr>");
+// 		}
 	    }
-	}  
         }
     }
       
@@ -168,23 +258,25 @@ if (db_numrows($result) > 0)
 # ################################ Comments 
 
   print '<h3>'.html_anchor(_("Follow-up Comments"), 'comments').'</h3><div class="noprint">';
-  printf (_("(Note: you can add pointers to others items by typing %s where %s is one of %s and %s the item id number.)"), 
+  if (group_restrictions_check($group_id, ARTIFACT, 2)) 
+   {
+     printf (_("(Note: you can add pointers to others items by typing %s where %s is one of %s and %s the item id number.)"), 
 	  "<font class=\"italic\">artifact #nnn</font>",
 	  "<font class=\"italic\">artifact</font>",
 	  "<font class=\"italic\">support, bug, task, patch</font>",
 	  "<font class=\"italic\">nnn</font>");
-  print '<p>&nbsp;&nbsp;&nbsp;';
-  print trackers_field_textarea('details','');
-  print '<p>';
+     print '<p>&nbsp;&nbsp;&nbsp;';
+     print trackers_field_textarea('details','');
+     print '<p>';
 
-  if (!user_isloggedin()) 
-    {
-      print '<h2 class="warn">'._("You are not logged in").'</h2><p>';
-      printf (_("Please %slog in,%s so followups can be emailed to you."),'<a href="'.$GLOBALS['sys_home'].'account/login.php?uri='.urlencode($REQUEST_URI).'">','</a>');
-      print '</p>';
-    }
-
-  print '<p>&nbsp;</p></div>';
+     if (!user_isloggedin()) 
+       {
+         print '<h2 class="warn">'._("You are not logged in").'</h2><p>';
+         printf (_("Please %slog in,%s so followups can be emailed to you."),'<a href="'.$GLOBALS['sys_home'].'account/login.php?uri='.urlencode($REQUEST_URI).'">','</a>');
+         print '</p>';
+       }
+     print '<p>&nbsp;</p></div>';
+   }
 
   print show_item_details($item_id,$group_id,0,$item_assigned_to);
 
@@ -194,14 +286,17 @@ if (db_numrows($result) > 0)
 
   print '<h3>'.html_anchor(_("Attached Files"), "attached").'</h3>';
   
-  print '<p class="noprint"><font class="preinput"> '._("Attach File:").'</font><br />
+  if (group_restrictions_check($group_id, ARTIFACT, 2)) 
+   {
+     print '<p class="noprint"><font class="preinput"> '._("Attach File:").'</font><br />
       &nbsp;&nbsp;&nbsp;<input type="file" name="input_file" size="40">
       <br />
       <font class="preinput">'._("File Description:").'</font><br />
       &nbsp;&nbsp;&nbsp;<input type="text" name="file_description" size="60" maxlength="255">
       </p><p>';
+   }
 	  
-  show_item_attached_files($item_id,$group_id);
+  print show_item_attached_files($item_id,$group_id);
 
   print '</p>&nbsp;<p>';
 
