@@ -2,13 +2,13 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: mod.php,v 1.32 2005/09/01 13:13:53 toddy Exp $
+# $Id: mod.php,v 1.48 2005/09/22 08:29:22 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
 #
-#  Copyright 2002-2005 (c) Mathieu Roy <yeupou--at--gnu.org>
-#                          Yves Perrin <yves.perrin--at--cern.ch>
+#  Copyright 2002-2005 (c) Mathieu Roy <yeupou--gnu.org>
+#                          Yves Perrin <yves.perrin--cern.ch>
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -36,20 +36,20 @@ $result=db_query($sql);
 if (db_numrows($result) > 0)
 {
 
-  # Defines the item name, converting bugs to bug.
-  # (Ideally, the artifact bugs should be named bug)
+# Defines the item name, converting bugs to bug.
+# (Ideally, the artifact bugs should be named bug)
   $item_name = utils_get_tracker_prefix(ARTIFACT)." #".$item_id;
-  # Defines the item link
+# Defines the item link
   $item_link = utils_link("?func=detailitem&item_id=".$item_id, $item_name);
 
-  # Check whether this item is private or not. If it is private, show only to
-  # the submitter or to people that got the right to see private items
+# Check whether this item is private or not. If it is private, show only to
+# the submitter or to people that got the right to see private items
   unset($private_intro);
   if (db_result($result,0,'privacy') == "2")
     {
       if (member_check_private(0, $group_id))
 	{
-	  # Nothing worth being mentioned
+        # Nothing worth being mentioned
 	}
       elseif (db_result($result,0,'submitted_by') == user_getid())
 	{
@@ -61,36 +61,41 @@ if (db_numrows($result) > 0)
 	}
     }
 
-  # Prepare all the necessary fields in case the user wants to
-  # Create a new task based on this bug
-
-  # assigned_to is passed along
-  $assigned_to = db_result($result,0,'assigned_to');
-
-  # Check if hours is used. If so pass it along as well
-  if ( trackers_data_is_used('hours') )
-    {
-      $hours = db_result($result,0,'hours');
-    }
-  else
-    {
-      $hours = '';
-    }
-
-  # Insert a reference to the originating bug in the task description
-  $task_details = db_result($result,0,'details')."\n\nSee ".ARTIFACT." #$item_id\nhttp://".
-     $GLOBALS['sys_default_domain']."/bugs/?func=detailitem&item_id=$item_id&group_id=$group_id";
-
-  trackers_header(array ('title'=>_("Modify an Item"),
-			 'create_task'=>'Create task',
-			 'summary' => db_result($result,0,'summary'),
-			 'details' => $task_details,
-			 'assigned_to' => $assigned_to,
-			 'hours' => $hours,
-			 'item_id' => $item_id
+  # yeupou, 2005-09-11: I dont think this stuff still means something.
+  # so it is commented out.
+#
+#  # Prepare all the necessary fields in case the user wants to
+#  # Create a new task based on this bug
+#
+#  # assigned_to is passed along
+#  $assigned_to = db_result($result,0,'assigned_to');
+#
+#  # Check if hours is used. If so pass it along as well
+#  if ( trackers_data_is_used('hours') )
+#    {
+#      $hours = db_result($result,0,'hours');
+#    }
+#  else
+#    {
+#      $hours = '';
+#    }
+#
+#  # Insert a reference to the originating bug in the task description
+#  # yeupou, 2005-09-11: What task description?
+#  $task_details = db_result($result,0,'details')."\n\nSee ".ARTIFACT." #$item_id\nhttp://".
+#    $GLOBALS['sys_default_domain']."/bugs/?func=detailitem&item_id=$item_id&group_id=$group_id";
+#
+  
+  trackers_header(array ('title'=>$item_name.", ".utils_cutstring(db_result($result,0,'summary')),
+#			 'create_task'=>'Create task',
+#			 'summary' => db_result($result,0,'summary'),
+#			 'details' => $task_details,
+#			 'assigned_to' => $assigned_to,
+#			 'hours' => $hours,
+#			 'item_id' => $item_id
 			 ));
 
-  # ################################ Check if the user have a specific role
+# ################################ Check if the user have a specific role
 
   if (member_check(0,$group_id,member_create_tracker_flag(ARTIFACT).'2', 1))
     {
@@ -105,36 +110,47 @@ if (db_numrows($result) > 0)
     {
       print help(_("You are technician for this tracker."),
 		 array(
-		       _("technician")=>_("you can be assigned tracker's items, but you cannot reassign items, change their status or priority")
+		       _("technician")=>_("you can be assigned tracker's items, but you cannot reassign items, change priority nor open/close")
 		       ));
     }
   elseif (member_check(0,$group_id,member_create_tracker_flag(ARTIFACT).'3', 1))
     {
       print help(_("You are manager for this tracker."),
 		 array(
-		       _("manager")=>_("you can fully manage the trackers items, including assigning items to technicians, reassign items over trackers and projects, changing priority and status of items")
+		       _("manager")=>_("you can fully manage the trackers items, including assigning items to technicians, reassign items over trackers and projects, changing priority and open/close items")
 		       ));
     }
 
-  # ################################ Start the form
-
+# ################################ Start the form
+  
   print '<h2 class="'.utils_get_priority_color(db_result($result,0,'priority'), db_result($result,0,'status_id')).'">'.sprintf(_("<i>%s</i> overview:"), $item_link).' '.db_result($result,0,'summary').'</h2>';
-
-print form_header($PHP_SELF, $form_id, "post", 'enctype="multipart/form-data" name="item_form"');
-print form_input("hidden", "func", "postmoditem");
-print form_input("hidden", "group_id", $group_id);
-print form_input("hidden", "item_id", $item_id);
-
+  
+  print form_header($PHP_SELF, $form_id, "post", 'enctype="multipart/form-data" name="item_form"');
+  print form_input("hidden", "func", "postmoditem");
+  print form_input("hidden", "group_id", $group_id);
+  print form_input("hidden", "item_id", $item_id);
+  
+  # Colspan explanation:
+  #
+  #  We want the following, twice much space for the value than for the label
+  #
+  #  | Label:  Value________| Label:  Value______ |
+  #  | Label:  Value_____________________________ |
+  #
+  #  So we have 4 column large via colspan.
+  
   print '
 
-    <table cellpadding="0" width="100%">
+  <table cellpadding="0" width="100%">
       <tr>
-          <td class="preinput">'._("Submitted by:").'&nbsp;</td><td>'.utils_user_link(user_getname(db_result($result,0,'submitted_by')), user_getrealname(db_result($result,0,'submitted_by'))).'</td>
-          <td colspan="6" align="center" valign="top"><span class="noprint"><input class="bold" type="submit" name="submit" value="'._("Submit Changes and Browse Items").'" ></span></td>
+          <td class="preinput" width="15%">'._("Submitted by:").'&nbsp;</td>
+          <td width="35%">'.utils_user_link(user_getname(db_result($result,0,'submitted_by')), user_getrealname(db_result($result,0,'submitted_by'))).'</td>
+          <td colspan="'.($fields_per_line).'" width="50%" align="center" valign="top"><span class="noprint"><input class="bold" type="submit" name="submit" value="'._("Submit Changes and Browse Items").'" ></span></td>
       </tr>
       <tr>
-          <td class="preinput">'._("Submitted on:").'&nbsp;</td><td>'.format_date($sys_datefmt,db_result($result,0,'date')).'</td>
-          <td colspan="6" align="center" valign="top"><input class="noprint" type="submit" name="submitreturn" value="'._("Submit Changes and Return to this Item").'"></td>
+          <td class="preinput" width="15%">'._("Submitted on:").'&nbsp;</td>
+          <td width="35%">'.format_date($sys_datefmt,db_result($result,0,'date')).'</td>
+          <td colspan="'.($fields_per_line).'" width="50%" align="center" valign="top"><input class="noprint" type="submit" name="submitreturn" value="'._("Submit Changes and Return to this Item").'"></td>
       </tr>';
   
   $votes = db_result($result,0,'vote');
@@ -143,19 +159,23 @@ print form_input("hidden", "item_id", $item_id);
       # display vote here if any, anything else is handled below
       print '
       <tr>
-          <td class="preinput">'._("Votes:").'&nbsp;</td><td><a href="#votes">'.$votes.'</a></td>
-          <td>&nbsp;</td>
+          <td class="preinput" width="15%">'._("Votes:").'&nbsp;</td>
+          <td width="35%"><a href="#votes">'.$votes.'</a></td>
+          <td colspan="'.($fields_per_line).'" width="50%">&nbsp;</td>
       </tr>
 ';
 
     }
 
-  $field_per_linex2=2*$fields_per_line;
-  print '<tr><td colspan="'.$fields_per_linex2.'">&nbsp</td></tr>';
+  print '<tr><td colspan="'.($fields_per_line*2).'">&nbsp</td></tr>';
 
   # Now display the variable part of the field list (depend on the project)
 
+  # $i is used to count the number of field
+  # $j is used to select the appropriate background color
   $i=0;
+  $j=0;
+
   while ($field_name = trackers_list_all_fields())
     {
       # if the field is a special field (except summary and details)
@@ -163,84 +183,132 @@ print form_input("hidden", "item_id", $item_id);
       if ((!trackers_data_is_special($field_name) || $field_name=='summary' || $field_name=='details') &&
 	  trackers_data_is_used($field_name))
 	{
-
-	  # if the submitter was anonymous, print the originator email field
+	  
+          # if the submitter was anonymous, print the originator email field
 	  if ($field_name != 'originator_email' ||
 	      ($field_name == 'originator_email' && db_result($result,0,'submitted_by') == '100'))
 	    {
 	      
-	  # display the bug field
-	  # if field size is greatest than max_size chars then force it to
-	  # appear alone on a new line or it won't fit in the page
+             # display the bug field
+             # if field size is greatest than max_size chars then force it to
+             # appear alone on a new line or it wont fit in the page
 
-	  # Look for the field value in the database only if we missing
-	  # its values. If we already have a value, we are probably in
-	  # step 2 of a search on item/group (dependancy, reassignation).
+             # Look for the field value in the database only if we missing
+             # its values. If we already have a value, we are probably in
+             # step 2 of a search on item/group (dependancy, reassignation).
 
-          # If nocache is set, we were explicetely asked to rely only
-          # on database content
-	  if (!$$field_name || $nocache)
-	    { $field_value = db_result($result,0,$field_name); }
-	  else
-	    { $field_value = $$field_name; }
+             # If nocache is set, we were explicetely asked to rely only
+             # on database content
+	      if (!$$field_name || $nocache)
+		{ $field_value = db_result($result,0,$field_name); }
+	      else
+		{ $field_value = htmlentities(stripslashes($$field_name)); }
+	      
+	      list($sz,) = trackers_data_get_display_size($field_name);
+	      $label = trackers_field_label_display($field_name,$group_id,false,false);
+	      
+              # Save the assigned to value for later
+	      if ($field_name == 'assigned_to')
+		{ $item_assigned_to = trackers_field_display($field_name,$group_id,$field_value,false,false,true); 
+		}
 
-	  list($sz,) = trackers_data_get_display_size($field_name);
-	  $label = trackers_field_label_display($field_name,$group_id,false,false);
+               # original submission field must be displayed read-only
+               # assigned_to, status_id and priority too, for technicians
+               # (if super_user, do nothing)
+	      if (!user_is_super_user())
+		{ $mbcheck = member_check(0,$group_id,member_create_tracker_flag(ARTIFACT).'1', 1); }
 
-          # Save the assigned to value for later
-	  if ($field_name == 'assigned_to')
-           { $item_assigned_to = trackers_field_display($field_name,$group_id,$field_value,false,false,true); 
-           }
+	      if ($field_name =='details' ||
+		  $mbcheck && $field_name =='status_id' ||
+		  $mbcheck && $field_name =='assigned_to' ||
+		  $mbcheck && $field_name =='priority' ||
+		  $mbcheck && $field_name =='originator_email')
+		{
+		  dbg("field_name:$field_name is read-only, mbcheck_is_not_manager:$mbcheck_is_not_manager");
+		  $value = utils_make_links(trackers_field_display($field_name,$group_id,$field_value,false,false,true));
+		  
+		  # Details need a specific div
+		  if ($field_name == 'details')
+		    {
+		      $value = '<div class="trackersoriginalsubmission">'.$value.'</div>';
+		    }
+		  
+		}
+	      else
+		{
+		  $value = trackers_field_display($field_name,$group_id,$field_value,false,false,$printer,false,false,_("None"),false,_("Any"),true);
+		}
 
-	  # original submission field must be displayed read-only
-	  # assigned_to, status_id and priority too, for technicians
-	  # (if super_user, do nothing)
-	  if (!user_is_super_user())
-	    { $mbcheck = member_check(0,$group_id,member_create_tracker_flag(ARTIFACT).'1', 1); }
+	      # check if the field is mandatory
+	      unset($star);
+	      $mandatory_flag = trackers_data_mandatory_flag($field_name);
+	      if ($mandatory_flag == 3 ||
+		  ($mandatory_flag == 0 && 
+		   trackers_check_is_shown_to_submitter($field_name, $group_id, db_result($result,0,'submitted_by'))))
+		  
+		{
+		  $star = '<font class="warn"> *</font>';
+		}
 
-	  if ($field_name =='details' ||
-	      $mbcheck && $field_name =='status_id' ||
-	      $mbcheck && $field_name =='assigned_to' ||
-	      $mbcheck && $field_name =='priority' ||
-	      $mbcheck && $field_name =='originator_email')
-	    {
-	      dbg("field_name:$field_name is read-only, mbcheck_is_not_manager:$mbcheck_is_not_manager");
-	      $value = utils_make_links(trackers_field_display($field_name,$group_id,$field_value,false,false,true));
+              # Fields colors
+	      unset($field_class, $row_class);
+	      if ($previous_form_bad_fields && array_key_exists($field_name, $previous_form_bad_fields))
+		{  
+                  # We highlight fields that were not properly/completely 
+		  # filled.
+		  $field_class = ' class="highlight"';
+		}
+	      if ($j % 2 && $field_name != 'details')
+		{
+		  # We keep the original submission with the default
+		  # background color, for lisibility sake
+		  #
+		  # We also use the boxitem background color only one time
+		  # out of two, to keep the page light
+		  $row_class = ' class="'.utils_altrow($j+1).'"'; 
+		}
+		  
+	      if ($sz > $max_size)
+		{
+		  # Field getting one line for itself 
 
+                  # Each time change the background color
+		  $j++;
+
+		  print "\n<tr".$row_class.">".
+		    '<td valign="middle" '.$field_class.' width="15%">'.$label.$star.'</td>'.
+		    '<td valign="middle" '.$field_class.' colspan="'.(2*$fields_per_line-1).'" width="75%">'.
+		    $value.'</td>'.
+		    "\n</tr>";
+		  $i=0;
+		}
+	      else
+		{
+		  # Field getting half of a line for itself 
+		  
+		  
+		  if (!($i % $fields_per_line))
+		    {
+		      # Every one out of two, prepare the background color change.
+   		      # We do that at this moment because we cannot be sure
+ 		      # there will be another field on this line.
+		      $j++;		  
+		    }
+
+		  print ($i % $fields_per_line ? '':"\n<tr".$row_class.">");
+		  print '<td valign="middle"'.$field_class.' width="15%">'.$label.$star.'</td><td valign="middle"'.$field_class.' width="35%">'.$value.'</td>';
+		  $i++;
+		  print ($i % $fields_per_line ? '':"\n</tr>");
+		}
 	    }
-	  else
-	    {
-              $value = trackers_field_display($field_name,$group_id,$field_value,false,false,$printer,false,false,_("None"),false,_("Any"),true);
-	    }
-
-
-	  $star = (trackers_data_is_empty_ok($field_name) ? '':'<font class="error"> *</font>');
-
-	  if ($sz > $max_size)
-	    {
-	      print "\n<tr>".
-		'<td valign="middle">'.$label.$star.'</td>'.
-		'<td valign="middle" colspan="'.(2*$fields_per_line-1).'">'.
-		$value.'</td>'.
-		"\n</tr>";
-	      $i=0;
-	    }
-	  else
-	    {
-	      print ($i % $fields_per_line ? '':"\n<tr>");
-	      print '<td valign="middle">'.$label.$star.'</td>'.
-		'<td valign="middle">'.$value.'</td>';
-	      $i++;
-	      print ($i % $fields_per_line ? '':"\n</tr>");
-	    }
-         }
 	}
     }
 
   print '</table>';
+  print '<p class="warn"><font class="smaller">* '._("Mandatory Fields").'</font></p>';
   print '<p>&nbsp;</p>';
 
-  # ################################ Shortcuts
+# ################################ Shortcuts
 
   print '<div class="noprint"><h2 class="'.utils_get_priority_color(db_result($result,0,'priority'), db_result($result,0,'status_id')).'">'.sprintf(_("<i>%s</i> details:"), $item_link).'</h2>';
   print '&nbsp;&nbsp;- <a href="#comments">'._("Follow-up Comments").'</a><br />';
@@ -259,7 +327,7 @@ print form_input("hidden", "item_id", $item_id);
   print '&nbsp;&nbsp;- <a href="#history">'._("History").'</a><br />';
   print '<p>&nbsp;<p></div>';
 
-  # ################################ Comments
+# ################################ Comments
 
   print '<h3>'.html_anchor(_("Follow-up Comments"), 'comments').'</h3>';
   print '<p class="noprint">';
@@ -295,30 +363,30 @@ print form_input("hidden", "item_id", $item_id);
               print '<br />&nbsp;&nbsp;&nbsp;';
 
 	    }
-         }
+	}
       else
-         {
-           print '<font class="warn">'._("Strangely enough, there is no canned response available.").'</font>';
-         }
+	{
+	  print '<font class="warn">'._("Strangely enough, there is no canned response available.").'</font>';
+	}
 
     }
   else
     {
 
-       print trackers_canned_response_box ($group_id,'canned_response');
-       print '&nbsp;&nbsp;&nbsp;<a class="smaller" href="'.$GLOBALS['sys_home'].ARTIFACT.'/admin/field_values.php?group_id='.$group_id.'&create_canned=1">('._("Or define a new Canned Response").')</a>';
+      print trackers_canned_response_box ($group_id,'canned_response');
+      print '&nbsp;&nbsp;&nbsp;<a class="smaller" href="'.$GLOBALS['sys_home'].ARTIFACT.'/admin/field_values.php?group_id='.$group_id.'&create_canned=1">('._("Or define a new Canned Response").')</a>';
 
     }
-   print '<br /><font class="preinput">'._("Previous Comment Style:").'</font><br />&nbsp;&nbsp;&nbsp;';
+  print '<br /><font class="preinput">'._("Previous Comment Style:").'</font><br />&nbsp;&nbsp;&nbsp;';
   if ($quotation_style != "quoted") 
-   {
+    {
       print '<input type="submit" name="change_quotation_style" value="'._("Quoted, ready to be copied/pasted into your new comment").'" />';
-   }
+    }
   else 
-   {
+    {
       print '<input type="submit" name="change_quotation_style" value="'._("Verbatim, unmodified").'" />';
 
-   }
+    }
 
    
 
@@ -328,7 +396,7 @@ print form_input("hidden", "item_id", $item_id);
 
   print '</p>&nbsp;<p>';
 
-  # ################################ Attached Files
+# ################################ Attached Files
 
   print '<h3>'.html_anchor(_("Attached Files"), "attached").'</h3>';
 
@@ -343,7 +411,7 @@ print form_input("hidden", "item_id", $item_id);
 
   print '</p>&nbsp;<p>';
 
-  # ################################ Dependencies
+# ################################ Dependencies
 
   print '<h3>'.html_anchor(_("Dependencies"), "dependencies").'</h3>';
   print '<p class="noprint"><font class="preinput">';
@@ -351,8 +419,8 @@ print form_input("hidden", "item_id", $item_id);
     { print _("Search an item (to fill a dependancy against):"); }
   else
     {
-      # Print a specific message if we are already at step 2 of filling
-      # a dependency.
+# Print a specific message if we are already at step 2 of filling
+# a dependency.
       print _("New search, in case the previous one was not satisfactory (to fill a dependancy against):");
     }
 
@@ -362,7 +430,7 @@ print form_input("hidden", "item_id", $item_id);
 
   function specific_depends_on_artifact ($art, $content)
     {
-      # Function too trivial to generalized in usual includes.
+# Function too trivial to generalized in usual includes.
       if (ARTIFACT == $art)
 	{ $checked = ' selected="selected"'; }
       print '<option value="'.$art.'"'.$checked.'>'.$content.'</option>';
@@ -371,7 +439,7 @@ print form_input("hidden", "item_id", $item_id);
 
   print '<font class="preinput">'._("Of:").'</font><br />
 &nbsp;&nbsp;&nbsp;<select name="depends_search_only_artifact">'
-.'<option value="all">'._("any Trackers").'</option>';
+    .'<option value="all">'._("any Trackers").'</option>';
 
   specific_depends_on_artifact("support", _("the Support Tracker Only"));
   specific_depends_on_artifact("bugs", _("the Bug Tracker Only"));
@@ -381,8 +449,8 @@ print form_input("hidden", "item_id", $item_id);
   print '</select> ';
   print _("of");
   print ' <select name="depends_search_only_project">'
-   .'<option value="any">'._("any Project").'</option>'
-   .'<option value="notany" selected="selected">'._("this Project Only").'</option>
+    .'<option value="any">'._("any Project").'</option>'
+    .'<option value="notany" selected="selected">'._("this Project Only").'</option>
    </select>&nbsp;';
 
   if (!$depends_search)
@@ -391,12 +459,12 @@ print form_input("hidden", "item_id", $item_id);
     }
   else
     {
-      # Print a specific message if we are already at step 2 of filling
-      # a dependency.
+# Print a specific message if we are already at step 2 of filling
+# a dependency.
       print '<input type="submit" name="submit" value="'._("New search").'">';
     }
 
-  # Search results, if we are already at step 2 of filling
+# Search results, if we are already at step 2 of filling
   if ($depends_search)
     {
       print '</p><p><font class="preinput">';
@@ -405,43 +473,46 @@ print form_input("hidden", "item_id", $item_id);
 
       unset($success);
 
-      # If we have less than 4 characters, to avoid giving lot of feedback
-      # and put an exit to the report, just consider the search as a failure.
+# If we have less than 4 characters, to avoid giving lot of feedback
+# and put an exit to the report, just consider the search as a failure.
       if (strlen($depends_search) > 3)
 	{
 
-	  # Build the list of trackers to take account of.
+# Build the list of trackers to take account of.
 	  if ($depends_search_only_artifact == "all")
 	    { $artifacts = array("support", "bugs", "task", "patch"); }
 	  else
 	    { $artifacts = array($depends_search_only_artifact); }
 
-	  # Actually search on each asked trackers.
+# Actually search on each asked trackers.
 	  while (list($num, $tracker) = each($artifacts))
 	    {
 	      if ($depends_search_only_project == "notany")
 		{ $GLOBALS['only_group_id'] = $group_id; }
 
-              # Do not ask for all words,
+# Do not ask for all words,
               $GLOBALS['exact'] = 0;
 
 	      $result_search = search_run($depends_search, $tracker, 0);
 	      $success = db_numrows($result_search) + $success;
 
-	      # Print the result, if existing.
+# Print the result, if existing.
 	      if (db_numrows($result_search) != 0)
 		{
-		  while (list($res_id, $res_summary, $res_date, $res_user, $res_group)  = db_fetch_array($result_search))
+		  while (list($res_id, $res_summary, $res_date, $res_privacy, $res_submitter_id, $res_submitter_name, $res_group)  = db_fetch_array($result_search))
 		    {
-		      # Avoid item depending on itself.
+# Avoid item depending on itself.
+# Hide private items. For now, they are excluded for dependancies.
+# We ll implement that later if necessary.
+		      if ($res_privacy == 2)
+			{ continue; }
 		      if ($res_id != $item_id || $tracker != ARTIFACT)
 			{
-			  # Right now only print id, summary and group.
-			  # We may change that depending on users feedback.
+# Right now only print id, summary and group.
+# We may change that depending on users feedback.
 			  print '<br />';
 			  print '&nbsp;&nbsp;&nbsp;<input type="checkbox" name="dependent_on_'.$tracker.'[]" value="'.$res_id.'">'.$tracker.' #'.$res_id._(': ').$res_summary;
-                          if (group_getname($res_group))
-                            { print ', '._("group").' '.group_getname($res_group); }
+			  print ', '._("group").' '.group_getname($res_group); 
 			}
 		    }
 		}
@@ -468,7 +539,7 @@ print form_input("hidden", "item_id", $item_id);
 
   print '</p><p>&nbsp;</p>';
 
-  # ################################ Mail notification
+# ################################ Mail notification
 
   print '<h3>'.html_anchor(_("Mail Notification Carbon-Copy List"), "cc").'</h3>';
   print '<p class="noprint">';
@@ -484,7 +555,7 @@ print form_input("hidden", "item_id", $item_id);
 
   print '<p>&nbsp;</p>';
 
-  # ################################ Votes
+# ################################ Votes
 
   if (trackers_data_is_used("vote"))
     {
@@ -493,20 +564,20 @@ print form_input("hidden", "item_id", $item_id);
       if (!$new_vote) 
         { $new_vote = $votes_given; }
 
-      # ATM, the mod page is only for technicians/manager. They always have
-      # the right to vote, as they are project member anyway.
+# ATM, the mod page is only for technicians/manager. They always have
+# the right to vote, as they are project member anyway.
       print '<h3>'.html_anchor(_("Votes"), "votes").'</h3>';
       print '<p>'.sprintf(ngettext("There is %s vote so far.", "There are %s votes so far.", $votes), $votes).' '._("Votes easily highlight which items people would like to see resolved in priority, independantly of the priority of the item set by tracker managers.").'</p><p class="noprint">';
        
-      # Show how many vote he already gave and allows to remove or give more
-      # votes.
-      # The number of remaining points must be 100 - others votes
+# Show how many vote he already gave and allows to remove or give more
+# votes.
+# The number of remaining points must be 100 - others votes
       print '<font class="preinput">'._("Your vote:").'</font><br />&nbsp;&nbsp;&nbsp;<input type="text" name="new_vote" size="3" maxlength="3" value="'.$new_vote.'" /> '.sprintf(ngettext("/ %s remaining vote", "/ %s remaining votes", $votes_remaining), $votes_remaining);
       print '</p>';
       print '<p>&nbsp;</p>';
     }
 
-  # ################################ Reassign an item, if manager of the tracker
+# ################################ Reassign an item, if manager of the tracker
   if (member_check(0,$group_id, member_create_tracker_flag(ARTIFACT).'3'))
     {
       print '<h3 class="noprint">'.html_anchor(_("Reassign this item"), "reassign").'</h3>';
@@ -516,7 +587,7 @@ print form_input("hidden", "item_id", $item_id);
 
       function specific_reassign_artifact ($art, $content)
 	{
-	  # Function too trivial to generalized in usual includes.
+# Function too trivial to generalized in usual includes.
 	  if (!$GLOBALS[reassign_change_artifact] && ARTIFACT == $art || $GLOBALS[reassign_change_artifact] == $art)
 	    { $checked = ' selected="selected"'; }
 	  print '<option value="'.$art.'"'.$checked.'>'.$content.'</option>';
@@ -536,8 +607,8 @@ print form_input("hidden", "item_id", $item_id);
 	{  print _("Move to the project:"); }
       else
 	{
-	  # Print a specific message if we are already at step 2 of
-	  # reassignation to another project.
+# Print a specific message if we are already at step 2 of
+# reassignation to another project.
 	  print _("New search, in case the previous one was not satisfactory (to reassign the item to another project):");
 	}
 
@@ -548,33 +619,33 @@ print form_input("hidden", "item_id", $item_id);
 	}
       else
 	{
-	  # Print a specific message if we are already at step 2 of filling
-	  # a ressign.
+# Print a specific message if we are already at step 2 of filling
+# a ressign.
 	  print ' <input type="submit" name="submit" value="'._("New search").'">';
 	}
 
 
-      # Search results, if we are already at step 2 of filling
+# Search results, if we are already at step 2 of filling
       if ($reassign_change_project_search)
 	{
 	  print '</p><p><font class="preinput">';
 	  printf (_("To which project this bug should be reassigned to? This is the result of your search of '%s' in the database:"), $reassign_change_project_search);
 	  print '</font>';
 
-	  # Print a null-option, someone may change his mine without having
-	  # to use the back button of his browser.
+# Print a null-option, someone may change his mine without having
+# to use the back button of his browser.
 	  print '<br />&nbsp;&nbsp;&nbsp;<input type="radio" name="reassign_change_project" value="0" checked> '._("Do not reassign to another project.");
 
 	  unset($success);
 	  $result_search = search_run($reassign_change_project_search, "soft", 0);
 	  $success = db_numrows($result_search);
 
-	  # Print the result, if existing.
+# Print the result, if existing.
 	  if (db_numrows($result_search) != 0)
 	    {
 	      while (list($res_group_name, $res_unix_group_name, $res_group_id)  = db_fetch_array($result_search))
 		{
-		  # Not reassigning to itself.
+# Not reassigning to itself.
 		  if ($res_unix_group_name != $group_name)
 		    {
 		      print '<br />';
@@ -595,15 +666,15 @@ print form_input("hidden", "item_id", $item_id);
 
 
 
-  #  ################################ Submit
+#  ################################ Submit
 
   print '<p>&nbsp;</p>';
 
   print '<p align="center" class="noprint"><input type="submit" name="submit" class="bold" value="'._("Submit Changes and Browse Items").'"> <input type="submit" name="submitreturn" value="'._("Submit Changes and Return to this Item").'"></form><p>';
 
 
-  # ################################ History
-  # May require in the future to think about only showing recent changes.
+# ################################ History
+# May require in the future to think about only showing recent changes.
 
   print '<p>&nbsp;</p><p>&nbsp;</p>';
   print show_item_history($item_id,$group_id);
