@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: search.php,v 1.5 2005/06/30 17:19:36 toddy Exp $
+# $Id: search.php,v 1.7 2005/09/14 11:02:00 yeupou Exp $
 #
 #  Copyright 2003 (c) Frederik Orellana <frederik.orellana@cern.ch>
 #
@@ -22,7 +22,8 @@
 
 
 trackers_header(array ('title'=>_("Search")));
-search_box('', ARTIFACT, 65);
+print _("With the following form, you can perform a search in the items summaries and details. If you need to perform more complex search, use the query forms in Browse items page");
+print html_show_boxoptions($title, search_box('', ARTIFACT, 45));
 trackers_footer(array());
 
 ?>
