@@ -2,12 +2,12 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: utils.php,v 1.74 2005/08/20 22:16:28 beuc Exp $
+# $Id: utils.php,v 1.77 2005/09/13 13:30:34 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
 #
-#  Copyright 2002-2005 (c) Mathieu Roy <yeupou--at--gnu.org>,
+#  Copyright 2002-2005 (c) Mathieu Roy <yeupou--gnu.org>,
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -92,7 +92,17 @@ function utils_altrow ($i)
   return html_get_alt_row_color ($i);
 }
 
-
+function utils_cutstring ($string, $lenght=35)
+{
+  $string = rtrim($string);
+  if (strlen($string) > $lenght)
+    {
+      $string = substr($string, 0, $lenght);
+      $string = substr($string, 0, strrpos($string, ' '));
+      $string .= "...";
+    }
+  return $string;
+}
 
 # This function returns a string of the date $value with the format $format
 # and if this date is not set, return the default value $default_value
@@ -376,11 +386,20 @@ function utils_make_links($data='',$group_id = 0)
   $lines = split("\n",$data);
   foreach ($lines as $key => $line)
     {
-      # Don't mess with HTML links already there by escaping
+      # 1 and 2 could maybe be replaced by a better regexp, as they may in
+      # some very rare case, break content. But we havent found such case.
+      # Feel free to propose better regexp.
+      
+      # 1. Don't mess with HTML links already there by escaping
       # the protocol separator with ":##"
       $line = eregi_replace("(<a href=\"[a-z]+)://([^<[:space:]]+)://([^<[:space:]]+)</a>", '\1:##\2:##\3</a>', $line);
       $line = eregi_replace("(<a href=\"[a-z]+)://([^<\"[:space:]]+)\"", '\1:##\2"', $line);
 
+      # 2. Dont mess with links surrounded by < >
+      # (Which are in fact html special chars)
+      $line = str_replace('&gt;', ' ##>', $line);
+      $line = str_replace('&lt;', '<## ', $line);
+
       # Make usual links: prefix every "www." with "http://"
       $line = eregi_replace("(^|[[:space:]]+)www\.","\\1http://www.",$line);
 
@@ -390,11 +409,11 @@ function utils_make_links($data='',$group_id = 0)
       # below. See bug #2689 on http://gna.org/ for reference.
       $line = eregi_replace("([a-z]+://[^<>[:space:]]+)@", "\\1&#64;", $line);
 
-      # When detecting URIs, we expect to parse text, not HTML.
-      # That way &lt;http://blabla&gt; (eg <http://blabla>) is
-      # correctly converted (recognised URL is http://blabla and not
-      # http://blabla&gt).
-      $line = html_entity_decode($line);
+
+      # Don't mess with HTML links already there by escaping
+      # the protocol separator with ":##"
+      $line = eregi_replace("(<a href=\"[a-z]+)://([^<[:space:]]+)://([^<[:space:]]+)</a>", '\1:##\2:##\3</a>', $line);
+      $line = eregi_replace("(<a href=\"[a-z]+)://([^<\"[:space:]]+)\"", '\1:##\2"', $line);
 
       # do a markup for normal links, e.g. http://test.org
       $line = eregi_replace("([a-z]+://[^<>[:space:]]+[a-z0-9/]+)", '<a href="\1">\1</a>', $line);
@@ -404,6 +423,9 @@ function utils_make_links($data='',$group_id = 0)
 
       # Revert the escaping of already provided HTML links, done above
       $line = str_replace(":##", "://", $line);
+      $line = str_replace(' ##>', '&gt;', $line);
+      $line = str_replace('<## ', '&lt;', $line);
+
 
       # Links between items
       # FIXME: it should be i18n, but in a clever way, meaning that everytime
