@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: index.php,v 1.59 2005/08/31 21:05:08 yeupou Exp $
+# $Id: index.php,v 1.64 2005/09/20 09:22:59 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #
@@ -42,18 +42,35 @@ if (!$GLOBALS['sys_unix_group_name'])
       fb(_("Configuration problem: sys_name is not set"), 1); 
     }
 } 
+
 # Check whether the local admin group exists. This is useful only during
 # installation process.
 if ($conn && !$sys_group_id)
 {
   if (!user_isloggedin()) 
     {
-      fb(_("Installation incomplete: you must now create for yourself a user account. Once it is done, you will have to login and register the local administration project"), 1);
+      # If there is no database, we will first found that no user is logged in
+      # Check if there is a database.
+      $result = db_query("SHOW TABLES LIKE 'groups'");
+      if (!db_numrows($result))
+	{
+	  # No valid database
+	  fb(sprintf(_("Installation incomplete: while the connection to the SQL server is ok, the database '%s' was not found. Please, create it according to the documentation shipped with your Savane package"), $GLOBALS['sys_dbname']), 1);
+	}
+      else
+	{
+	  # Not logged-in, probably no user account
+	  fb(_("Installation incomplete: you must now create for yourself a user account. Once it is done, you will have to login and register the local administration project"), 1);
+	}
     }
   else
-    {      
+    {    
+      # No admin groups
       fb(_("Installation incomplete: you must now register the local administration project, select \"Register New Project\" in the left menu"), 1);
     }
+  # I18N
+  # The string is a URL on localhost, e.g. http://127.0.0.1/testconfig.php
+  fb(sprintf(_("By the way, have you checked the setup of your web server at %s?"), 'http://127.0.0.1'.$GLOBALS['sys_home'].'testconfig.php'), 1);
 }
 
 $HTML->header(array('title'=>_("Welcome")));
