@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: groups.php,v 1.20 2005/08/03 19:14:04 beuc Exp $
+# $Id: groups.php,v 1.24 2005/09/19 11:21:01 yeupou Exp $
 #
 #  Copyright 2003-2005 (c) Frederik Orellana <frederik.orellana--cern.ch>
 #                          Mathieu Roy <yeupou--gnu.org>
@@ -74,6 +74,9 @@ if ($rows_without_history != $rows)
 {
   # If number of rows differ, assume that history is flawed. Print a
   # feedback incitating to fix the installation and override flawed result
+  # 
+  # The following update script was maybe forgot:
+  # update/1.0.6/update_group_history.pl
   fb(_("Groups history appears to be flawed. This is a site installation problem. Please report the incident to administrators, asking them to get in touch with their Savane supplier."), 1);
   $result = $result_without_history;
   $rows = $rows_without_history;
@@ -154,6 +157,7 @@ function update_tbl()
       # Check for duplicates
       if (!form_check($form_id))
 	{ return 0; }
+      unset($form_cleaned_already);
 
       while ($val = db_fetch_array($result_upd))
 	{
@@ -174,7 +178,11 @@ function update_tbl()
 		      if(member_add($row_user[user_id], $val[group_id], 'P'))
 		      {
 			send_pending_user_email($val[group_id], $row_user[user_id], $GLOBALS["form_message"]);
-			form_clean($form_id);
+			if (!$form_cleaned_already)
+			  {
+			    form_clean($form_id);
+			    $form_cleaned_already = 1;
+			  }
 		      }
 		    }
 		}
@@ -240,9 +248,9 @@ $rows_w=db_numrows($result_w);
 if (!$result_w || $rows_w < 1)
     {
       print _("I am not watching any partners.");
-      print '<p>'._("Watching a partner (receiving a copy of all the notification sent to him) permits to be his backup when he is away from the office, or to do QA to all his/her activities on a project.");
-      print '</p><p>'._("To watch someone, click 'Watch Partner' in any project memberlist page (membership to that project is required, indeed).");
-      print '<br />&nbsp;';
+      print '<p>'._("Watching a partner (receiving a copy of all notifications sent to them) permits you to be their backup when they are away from the office, or to review all their activities on a project.");
+      print '</p><p>'._("To watch someone, click 'Watch partner' in the project memberlist page. You need to be member of that project yourself.");
+      print '<br />';
       print db_error();
     }
 else
@@ -293,7 +301,7 @@ print $HTML->box_top(_("Request for Inclusion"),'',1);
 
 print '<div class="boxitem">'._("Search a Group")."\n";
   print '<p class="text">';
-print _("If there is a project - or several - you would like to be member of, to be able to fully contribute, it is possible to search his/their name(s) in the whole group database with the following search tool. A list of groups will be generated, depending on the word(s) typed in this form.")."\n";
+print _("If there is a project - or several - you would like to be member of, to be able to fully contribute, it is possible to search for the names in the whole group database with the following search tool. A list of groups will be generated, depending on the word(s) typed in this form.")."\n";
 print '</p>';
 
 print '
@@ -335,7 +343,7 @@ if ($words)
       # This tool is to search groups for inclusion, not to look around
       # to get information about groups.
       print '<p class="text">';
-      print _("To request inclusion in one or several groups, check the correspondants boxes, write a meaningful message for the project administrator, that will approve or disapprove the request, and submit the form.");
+      print _("To request inclusion in one or several groups, check the correspondant boxes, write a meaningful message for the project administrator who will approve or disapprove the request, and submit the form.");
 
       print '</p>'.form_header($PHP_SELF);
 
