@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: index.php,v 1.63 2005/06/30 17:19:36 toddy Exp $
+# $Id: index.php,v 1.65 2005/09/21 15:03:35 yeupou Exp $
 #
 #  Copyright 2005      (c) Mathieu Roy <yeupou--gnu.org>
 #
@@ -107,20 +107,21 @@ if (user_isloggedin())
 
   if ($result && $rows > 0)
     {
-      print '<br /><div class="boxtitle">'._("News Waiting for Approval").'</div>';
+      print '<br /><div class="box"><div class="boxtitle">'._("News Waiting for Approval").'</div>';
       for ($j=0; $j<$rows; $j++)
 	{
 	  print '<div class="'.utils_get_alt_row_color($j).'">';
 	  print '<a href="'.$GLOBALS[sys_home].'news/approve.php?approve=1&amp;id='.db_result($result, $j, 'id').'&amp;group='.group_getunixname(db_result($result, $j, 'group_id')).'">'.db_result($result, $j, 'summary').'</a><br />';
 	  # FIXME: num. of new comments?
-	  print '<font class="smaller">'.sprintf(_("Project %s, %s"), group_getname(db_result($result, $j, 'group_id')), format_date($sys_datefmt,db_result($result,$j,'date'))).'</a>';
+	  print '<font class="smaller">'.sprintf(_("Project %s, %s"), group_getname(db_result($result, $j, 'group_id')), format_date($sys_datefmt,db_result($result,$j,'date'))).'</font>';
 	  print '</div>';
 	}
+      print '</div>';
     }
 
 
   #### Latest Approved News
-  print '<br /><div class="boxtitle">'._("News").'</div>';
+  print '<br /><div class="box"><div class="boxtitle">'._("News").'</div>';
   reset($usergroups);
   reset($usergroups_groupid);
   # Build an sql request that will fetch any relevant news
@@ -141,7 +142,7 @@ if (user_isloggedin())
 	  print '<div class="'.utils_get_alt_row_color($j).'">';
 	  print '<a href="'.$GLOBALS[sys_home].'forum/forum.php?forum_id='.db_result($result, $j, 'forum_id').'">'.db_result($result, $j, 'summary').'</a><br />';
 	  # FIXME: num. of new comments?
-	  print '<font class="smaller">'.sprintf(_("Project %s, %s"), group_getname(db_result($result, $j, 'group_id')), format_date($sys_datefmt,db_result($result,$j,'date'))).'</a>';
+	  print '<font class="smaller">'.sprintf(_("Project %s, %s"), group_getname(db_result($result, $j, 'group_id')), format_date($sys_datefmt,db_result($result,$j,'date'))).'</font>';
 	  print '</div>';
 	}
     }
@@ -149,6 +150,7 @@ if (user_isloggedin())
     {
       print _("None found");
     }
+  print '</div>';
 
  ################ LEFT PART ############################
 
@@ -163,10 +165,11 @@ if (user_isloggedin())
   my_incoming_unassigned_item_list($usergroups);
 
   ### Items newly assigned (not necessarily new items)
-  print '<br /><div class="boxtitle">'._("Newly Assigned Items").'</div>';
+  print '<br /><div class="box"><div class="boxtitle">'._("Newly Assigned Items").'</div>';
   reset($usergroups);
   reset($usergroups_groupid);
   my_incoming_assigned_item_list($usergroups);
+  print '</div>';
 
   print html_splitpage(3);
 
