@@ -2,12 +2,12 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: items.php,v 1.3 2005/06/30 17:19:36 toddy Exp $
+# $Id: items.php,v 1.7 2005/09/21 15:03:35 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
 #
-#  Copyright 2002-2005 (c) Mathieu Roy <yeupou--at--gnu.org>
+#  Copyright 2002-2005 (c) Mathieu Roy <yeupou--gnu.org>
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -77,25 +77,26 @@ if (user_isloggedin())
 
   site_user_header(array('toptab'=>'myitems'));
 
+  # we get site-specific content
+  utils_get_content("my/items");
+
   $fopen = '<select name="form_open"><option value="open" '.($open == "open" ? 'selected="selected"':'').'>'._("Open").'</option><option value="closed" '.($open == "closed" ? 'selected="selected"':'').'>'._("Closed").'</option></select> ';
   $fthreshold = '<select name="form_threshold"><option value="1" '.($threshold == 1 ? 'selected="selected"':'').'>'._("Lowest").'</option><option value="3" '.($threshold == 3 ? 'selected="selected"':'').'>'._("Low").'</option><option value="5" '.($threshold == 5 ? 'selected="selected"':'').'>'._("Normal").'</option><option value="7" '.($threshold == 7 ? 'selected="selected"':'').'>'._("High").'</option><option value="9" '.($threshold == 9 ? 'selected="selected"':'').'>'._("Immediate").'</option></select> ';
 
-  print '<form action="'.$PHP_SELF.'" method="get">';
-  print '<h3>';
-  printf (_("Show %s new items or of %s priority at least."), $fopen, $fthreshold);
-  print '&nbsp;&nbsp;&nbsp;&nbsp;<input type="submit" value="'._("Apply").'"  /></h3></form>';
-
-  # we get site-specific content
-  utils_get_content("my/items");
+  $form_opening = '<form action="'.$PHP_SELF.'#options" method="get">';
+  $form_submit = '<input class="bold"  type="submit" value="'._("Apply").'" />';
+  print html_show_displayoptions(sprintf(_("Show %s new items or of %s priority at least."), $fopen, $fthreshold),
+				 $form_opening,
+				 $form_submit);
 
 
  ################ RIGHT PART ############################
 
   print html_splitpage(1);
 
-  print '<br /><div class="boxtitle">'._("Assigned to me").'</div>';
+  print '<br /><div class="box"><div class="boxtitle">'._("Assigned to me").'</div>';
   print my_item_list("assignee", $threshold, $open);
-
+  print '</div>';
 
 
 //   # Forums that are actively monitored
@@ -175,8 +176,9 @@ if (user_isloggedin())
 				    
   print html_splitpage(2);
 
-  print '<br /><div class="boxtitle">'._("Submitted by me").'</div>';
+  print '<br /><div class="box"><div class="boxtitle">'._("Submitted by me").'</div>';
   print my_item_list("submitter", $threshold, $open);
+  print '</div>';
 
   print html_splitpage(3);
 
