@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: approve.php,v 1.15 2005/06/30 17:19:36 toddy Exp $
+# $Id: approve.php,v 1.16 2005/09/11 14:36:02 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -366,10 +366,10 @@ if ($group_id && member_check(0, $group_id,'N3'))
 	  print '</ul>';
 	}
 
-      # Finally, we show approved items for this week
+      # We show all approved items.
       if (user_is_super_user() && $group_id == $GLOBALS['sys_group_id'])
 	{
-	  $sql="SELECT * FROM news_bytes WHERE (is_approved=1 OR (is_approved=0  AND group_id='$group_id')) AND date > '$old_date'";
+	  $sql="SELECT * FROM news_bytes WHERE (is_approved=1 OR (is_approved=0  AND group_id='$group_id'))";
 
 	}
       else
@@ -383,12 +383,12 @@ if ($group_id && member_check(0, $group_id,'N3'))
       if ($rows < 1)
 	{
 	  print '<h3>'
-	    ._("No news items approved these past two weeks").'</h3>';
+	    ._("No news items approved").'</h3>';
 	}
       else
 	{
 	  print '<h3>'
-	    ._("These items were approved these past two weeks:").'</h3><ul>';
+	    ._("These items were approved:").'</h3><ul>';
 	  for ($i=0; $i<$rows; $i++) {
 	    print '<li';
             if (db_result($result,$i,'group_id') == $GLOBALS['sys_group_id']){ print ' class="boxhighlight"'; }
