@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: index.php,v 1.29 2005/06/30 17:19:36 toddy Exp $
+# $Id: index.php,v 1.31 2005/09/09 16:41:04 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -85,12 +85,13 @@ site_project_header(array('group'=>$group_id,
 
 /* permit to the user to specify something */
 
-print '<form action="'. $PHP_SELF .'" method="get">';
+$form_opening = '<form action="'. $PHP_SELF .'#options" method="get">';
+$form = sprintf(_("Print summaries for the %s latest news."), '<input type="text" name="limit" size="4" value="'.$limit.'" />');
 if ($group_name)
-{ print '<input type="hidden" name="group" value="'.$group_name.'" />'; }
-print '<h3>';
-printf (_("Print summaries for the %s latest news."), '<input type="text" name="limit" size="4" value="'.$limit.'" />');
-print '&nbsp;&nbsp;&nbsp;&nbsp;<input type="submit" value="'._("Apply").'"  /></h3></form>';
+{ $form .= '<input type="hidden" name="group" value="'.$group_name.'" />'; }
+$form_submit = '<input class="bold" type="submit" value="'._("Apply").'"  />';
+
+print html_show_displayoptions($form, $form_opening, $form_submit);
 
 print "<br />\n";
 
