@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: editgroupnotifications.php,v 1.12 2005/06/30 17:19:36 toddy Exp $
+# $Id: editgroupnotifications.php,v 1.16 2005/09/29 11:50:42 yeupou Exp $
 #
 #  Copyright 2003-2004 (c) Yves Perrin <Yves.Perrin@cern.ch>
 #                          Mathieu Roy <yeupou--at--gnu.org>
@@ -43,6 +43,20 @@ if ($update)
 	   ."new_news_address=".($form_news_address? "'$form_news_address' " : "''")
 	   . " WHERE group_id=$group_id");
 
+ 
+  # CERN SPECIFIC (at least for now) BEGIN
+  ######### Notification content
+
+  if ($sys_default_domain == "savannah.cern.ch" || $sys_debug_cerntest)
+    {
+      if (group_set_preference($group_id, "notif_content", addslashes($notif_content)))
+	{ fb(_("Successfully updated notification content settings")); }
+      else
+	{ fb(_("Failed to update notification content settings"), 1); } 
+    }
+  # CERN SPECIFIC (at least for now) END
+
+
   ######### Reminder
   if (group_set_preference($group_id, "batch_frequency", addslashes($form_frequency)))
     { fb(_("Successfully Updated Reminder Settings")); }
@@ -95,6 +109,24 @@ trackers_data_show_notification_settings($group_id, 'patch', 0);
 print '<h2>'._("News Tracker Email Notification Settings").'</h2>';
 print '<span class="preinput">'._("Carbon-Copy List:").'</span><br />&nbsp;&nbsp;<INPUT TYPE="TEXT" NAME="form_news_address" VALUE="'.$row_grp['new_news_address'].'" SIZE="40" MAXLENGTH="255" />';
 
+# CERN SPECIFIC (at least for now) BEGIN
+# As it is CERN specific, it will not be translated, as LCG Savannah is
+# in english only.
+if ($sys_default_domain == "savannah.cern.ch" || $sys_debug_cerntest)
+{
+  print '<br /><h2>'."Notification Email Content".'</h2>';
+  print '<p>'."The notification emails include the last change [minimum] (standard of upstream Savane), but can also append the item overview [average] and possibly all the followup comments [maximum] (traditional LCG Savannah).".'</p>';
+  $mail_content = array("0" => "Minimum (standard of upstream Savane)", "1" => "Medium", "2" => "Maximum (traditional LCG Savannah)");
+  print '<span class="preinput">'."Email content:".'</span> &nbsp;&nbsp;';
+  $current_content = group_get_preference($group_id, "notif_content");
+  if ($current_content == "") 
+    { $current_content = 2; }
+  print html_build_select_box_from_array($mail_content,
+					 "notif_content",
+					 $current_content);
+}
+# CERN SPECIFIC (at least for now) END
+
 print '<br /><h2>'._("Reminder").'</h2>';
 print '<p>'._("You can configure the project so that reminder emails get sent to project members who have opened items with priority higher than 5 assigned to them.").'<br/><font class="warn">'._("This will be done regardless of the fact project members have or have not requested to receive such reminders via their personal notification settings!").'</font></p>
 ';
