@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: useradmin.php,v 1.15 2005/06/30 17:19:36 toddy Exp $
+# $Id: useradmin.php,v 1.16 2005/09/14 08:24:07 yeupou Exp $
 #
 #  Copyright 2003-2004 (c) Frederik Orellana <frederik.orellana--cern.ch>
 #                          Derek Feichtinger <derek.feichtinger--cern.ch>
@@ -218,12 +218,22 @@ if ($action=='approve_for_group' && $user_id) {
   foreach ($user_id as $user) {
     member_approve($user, $group_id);
     if($email=user_get_email($user)){
-      $message = sprintf(_("You've been approved as a member of the group %s on %s,\nwhere you are registered as %s."), group_getname($group_id), $GLOBALS['sys_name'], user_getname($user)) . "\n\n".
-	 sprintf(_("-- the %s team."),$GLOBALS['sys_name'])."\n";
+      # As mail content sent to a user different from the one browsing the 
+      # page, this cannot be translated.
+      $title = "Project membership approved";
+      $message = sprintf("You've been approved as a member of the group %s on %s,\nwhere you are registered as %s.", group_getname($group_id), $GLOBALS['sys_name'], user_getname($user)) . "\n\n".
+	 sprintf("-- the %s team.", $GLOBALS['sys_name'])."\n";
+      $message = sprintf("You've been approved as a member of the group %s on %s,\nwhere you are registered as %s.", group_getname($group_id), $GLOBALS['sys_name'], user_getname($user)) . "\n\n".
+	sprintf("-- the %s team.",$GLOBALS['sys_name'])."\n";
+#      $title = _("Project membership approved");
+#      $message = sprintf(_("You've been approved as a member of the group %s on %s,\nwhere you are registered as %s."), group_getname($group_id), $GLOBALS['sys_name'], user_getname($user)) . "\n\n".
+#	 sprintf(_("-- the %s team."),$GLOBALS['sys_name'])."\n";
+#      $message = sprintf(_("You've been approved as a member of the group %s on %s,\nwhere you are registered as %s."), group_getname($group_id), $GLOBALS['sys_name'], user_getname($user)) . "\n\n".
+#	 sprintf(_("-- the %s team."),$GLOBALS['sys_name'])."\n";
 
       sendmail_mail($GLOBALS['sys_replyto'] . "@".$GLOBALS['sys_lists_domain'],
 		    $email,
-		    ' '._("Project membership approved"),
+		    $title,
 		    $message);
     }
   }
