@@ -2,13 +2,14 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: userperms.php,v 1.33 2005/06/30 17:19:36 toddy Exp $
+# $Id: userperms.php,v 1.35 2005/09/14 18:33:45 toddy Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
-#                          Mathieu Roy <yeupou--at--gnu.org>
+#                          Mathieu Roy <yeupou--gnu.org>
 #
-#  Copyright 2004      (c) Mathieu Roy <yeupou--at--gnu.org>
+#  Copyright 2004-2005 (c) Mathieu Roy <yeupou--gnu.org>
+#                          Yves Perrin <yves.perrin--cern.ch>
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -143,20 +144,40 @@ if ($update)
     }
 
   # ##### Update posting restrictions
+  # (if equal to 0, manually set to NULL, since 0 have a different meaning)
+  $newitem_restrict_event1 = "bugs_restrict_event1";
+  $newitem_restrict_event2 = "bugs_restrict_event2";
+  $bugs_flags = ($$newitem_restrict_event2)*100 + $$newitem_restrict_event1;
+  if (!$bugs_flags)
+    { $bugs_flags = 'NULL'; }
 
-  $bugs_flags="bugs_restrict";
-  $task_flags="task_restrict";
-  $patch_flags="patch_restrict";
-  $support_flags="support_restrict";
-  $news_flags="news_restrict";
+  $newitem_restrict_event1 = "task_restrict_event1";
+  $newitem_restrict_event2 = "task_restrict_event2";
+  $task_flags = ($$newitem_restrict_event2)*100 + $$newitem_restrict_event1;
+  if (!$task_flags)
+    { $task_flags = 'NULL'; }
+
+  $newitem_restrict_event1 = "support_restrict_event1";
+  $newitem_restrict_event2 = "support_restrict_event2";
+  $support_flags = ($$newitem_restrict_event2)*100 + $$newitem_restrict_event1;
+  if (!$support_flags)
+    { $support_flags = 'NULL'; }
+
+  $newitem_restrict_event1 = "patch_restrict_event1";
+  $newitem_restrict_event2 = "patch_restrict_event2";
+  $patch_flags = ($$newitem_restrict_event2)*100 + $$newitem_restrict_event1;
+  if (!$patch_flags)
+    { $patch_flags = 'NULL'; }
+
+  $news_flags="news_restrict_event1";
 
   # Update the table
   $sql = 'UPDATE groups_default_permissions SET '
-     ."bugs_rflags=".$$bugs_flags.","
+     ."bugs_rflags=".$bugs_flags.","
      ."news_rflags=".$$news_flags.","
-     ."task_rflags=".$$task_flags.", "
-     ."patch_rflags=".$$patch_flags.", "
-     ."support_rflags=".$$support_flags." "
+     ."task_rflags=".$task_flags.", "
+     ."patch_rflags=".$patch_flags.", "
+     ."support_rflags=".$support_flags." "
      ."WHERE group_id='$group_id'";
 
   $result = db_query($sql);
@@ -205,7 +226,7 @@ print '<form action="'.$PHP_SELF.'" method="post">
 # Exists also in trackers config (missing for news).
 
   $title_arr=array();
-  $title_arr[]="";
+  $title_arr[]=_("Applies when ...");
   $title_arr[]=_("Support Tracker");
   $title_arr[]=_("Bug Tracker");
   $title_arr[]=_("Task Tracker");
@@ -214,12 +235,16 @@ print '<form action="'.$PHP_SELF.'" method="post">
 
   print '<h3>'._("Group trackers posting restrictions").'</h3>';
 
+  print '<p>';
+  print _("Here you can set the minimal authentification level required in order to post on the trackers.");
+  print '</p>';
+
   print html_build_list_table_top ($title_arr);
 
   $i++;
   print '
   <tr class="'. utils_get_alt_row_color($i) .'">
-    <td>'._("Authentication level required").'</td>';
+    <td>'._("Posting new items").'</td>';
   html_select_restriction_box("support", group_getrestrictions($group_id, "support"));
   html_select_restriction_box("bugs", group_getrestrictions($group_id, "bugs"));
   html_select_restriction_box("task", group_getrestrictions($group_id, "task"));
@@ -227,6 +252,19 @@ print '<form action="'.$PHP_SELF.'" method="post">
   html_select_restriction_box("news", group_getrestrictions($group_id, "news"));
   print '  </tr>';
 
+  $i++;
+  print '
+  <tr class="'. utils_get_alt_row_color($i) .'">
+    <td>'._("Posting comments").'</td>';
+  html_select_restriction_box("support", group_getrestrictions($group_id, "support", 2),'', '', 2);
+  html_select_restriction_box("bugs", group_getrestrictions($group_id, "bugs", 2),'', '', 2);
+  html_select_restriction_box("task", group_getrestrictions($group_id, "task", 2),'', '', 2);
+  html_select_restriction_box("patch", group_getrestrictions($group_id, "patch", 2),'', '', 2);
+# not yet effective!
+  print '<td align="center">---</td>';
+#  html_select_restriction_box("news", group_getrestrictions($group_id, "news", 2),'', '', 2);
+  print '  </tr>';
+
   print '
 </table>
 <p align="center"><input type="submit" name="update" value="'._("Update Permissions").'"></p>';
