@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: memberlist-gpgkeys.php,v 1.4 2005/06/30 17:19:36 toddy Exp $
+# $Id: memberlist-gpgkeys.php,v 1.5 2005/09/14 15:51:30 toddy Exp $
 #
 #  Copyright 2005      (c) Mathieu Roy <yeupou--at--gnu.org>
 #
@@ -33,7 +33,7 @@ if (!$download) {
 			    'group'=>$group_id,
 			    'toptab'=>'keys'));
 
-  print '<p>'._("Follows the content of this project keyring. These are the successfully registered keys of projects members.").'</p>';
+  print '<p>'._("Below is the content of this project's keyring. These are the successfully registered keys of project members.").'</p>';
   print nl2br(htmlspecialchars($keyring));
   print '<p>'.sprintf(_("You can %sdownload the keyring%s and import it with the command %s"), '<a href="'.$PHP_SELF.'?group='.$group_name.'&amp;download=1">', '</a>', '<i>gpg --import &lt;file&gt;</i>').'</p>';
 
