@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: memberlist.php,v 1.29 2005/06/30 17:19:36 toddy Exp $
+# $Id: memberlist.php,v 1.33 2005/09/23 14:42:56 toddy Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -57,7 +57,9 @@ if ((!$group_id) && $form_grp)
      print '<h3>';
      if ($detailed)
 { $checked = " selected"; }
-printf (_("Browse with the %s memberlist."), '<select name="detailed"><option value="0">'._("Basic").'</option><option value="1"'.$checked.'>'._("Detailed").'</option></select>');
+# I18N
+# %s currently is "basic" or "detailed"
+printf (_("Browse with the %s memberlist."), '<select name="detailed"><option value="0">'._("basic").'</option><option value="1"'.$checked.'>'._("detailed").'</option></select>');
 print '&nbsp;&nbsp;&nbsp;&nbsp;<input type="submit" value="'._("Apply").'"></h3></form>';
 
 print '<br />';
@@ -65,13 +67,13 @@ print '<br />';
 
 if (!member_check(0,$group_id))
 {
-  printf(_("If you would like to contribute to this project by becoming a member, %s, designated in bold text below."),
-	 '<a href="'.$GLOBALS['sys_home'].'my/groups.php?words='.group_getname($group_id).'#searchgroup">'._("contact one of the project admins")."</a>");
+  printf(_("If you would like to contribute to this project by becoming a member, %scontact one of the project admins%s, designated in bold text below."),
+	 '<a href="'.$GLOBALS['sys_home'].'my/groups.php?words='.group_getname($group_id).'#searchgroup">', '</a>');
   print '<br /><br />';
 }
 else
 {
-  print _("Note that you can 'watch' a member of your project. It allows you, for instance, to be the backup of someone when he's away from the office, to do the QA to all of his activities on this project: you will receive a copy of his mail notifications related to this project.");
+  print _("Note that you can 'watch' a member of your project. It allows you, for instance, to be the backup of someone when they are away from the office, or to review all their activities on this project: you will receive a copy of their mail notifications related to this project.");
   print '<br /><br />';
 
 }
@@ -231,7 +233,7 @@ while ($row_memb=db_fetch_array($res_memb))
 	  if ($row_memb['user_id'] != $thisuser && !trackers_data_is_watched($thisuser,$row_memb['user_id'],$group_id))
 	    {
 	      # permit to add a watchee only if not already in the watched list
-	      print "\t\t<td align=\"middle\"><a href=\"".$GLOBALS['sys_home']."my/?func=addwatchee&amp;group_id=$group_id&amp;watchee_id=".$row_memb['user_id']."\">"._("Watch Him")."</a></td>\n";
+	      print "\t\t<td align=\"middle\"><a href=\"".$GLOBALS['sys_home']."my/groups.php?func=addwatchee&amp;group_id=$group_id&amp;watchee_id=".$row_memb['user_id']."\">"._("Watch partner")."</a></td>\n";
 	    }
 	  else
 	    {
