@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: confirmation.php,v 1.74 2005/07/05 08:33:21 yeupou Exp $
+# $Id: confirmation.php,v 1.75 2005/09/27 14:56:59 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -233,7 +233,10 @@ $message_admin .= "Description:
       # (we need to copy the None field)
       db_query("INSERT INTO task_field_value (bug_field_id,group_id,value_id,value,description,order_id,status) VALUES (103,$group_id,100,'None','',10,'P')");
       db_query("INSERT INTO task_field_value (bug_field_id,group_id,value_id,value,description,order_id,status) VALUES (103,$group_id,1,'Project Approval','Pending project registration',11,'P')");
-
+      # We also need to make the task tracker post restriction of comment
+      # accepting posting from logged-in users, otherwise they wont be able
+      # to comment their registration
+      db_query("INSERT INTO groups_default_permissions (group_id,task_rflags) VALUES ($group_id,300)");
     }
   else
     {
