@@ -2,13 +2,14 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: index.php,v 1.47 2005/06/30 17:19:37 toddy Exp $
+# $Id: index.php,v 1.49 2005/09/28 08:12:18 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
-#                          Mathieu Roy <yeupou--at--gnu.org>
+#                          Mathieu Roy <yeupou--gnu.org>
 # 
-#  Copyright 2004      (c) Mathieu Roy <yeupou--gnu.org>
+#  Copyright 2004-2005 (c) Mathieu Roy <yeupou--gnu.org>
+#                          Yves Perrin <yves.perrin--cern.ch>
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -67,7 +68,7 @@ $words = htmlspecialchars($words);
 if (!$words)
 {
   search_send_header();
-  echo '<p>'._("Enter your search words above.").'</p>';
+  print '<p>'._("Enter your search words above.").'</p>';
   $HTML->footer(array());
   exit;
 }
@@ -120,9 +121,9 @@ if ($type_of_search == "soft")
       $title_arr[] = _("Description");
       $title_arr[] = _("Type");
 
-      echo html_build_list_table_top($title_arr);
+      print html_build_list_table_top($title_arr);
 
-      echo "\n";
+      print "\n";
 
       for ( $i = 0; $i < $rows; $i++ )
 	{
@@ -138,7 +139,9 @@ if ($type_of_search == "soft")
 	. '<td>'.db_result($result,$i,'short_description').'</td>'
 	. '<td>'.db_result($res_type, 0, 'name')."</td></tr>\n";
 	}
-      echo "</table>\n";
+      print "</table>\n";
+      
+      print '<p> Note that <span class="bold">private</span> projects are not shown on this page </p>';
     }
 
 }
@@ -166,9 +169,9 @@ else if ($type_of_search == "people")
       $title_arr[] = _("Login");
       $title_arr[] = _("Name");
 
-      echo html_build_list_table_top ($title_arr);
+      print html_build_list_table_top ($title_arr);
 
-      echo "\n";
+      print "\n";
 
       for ( $i = 0; $i < $rows; $i++ )
 	{
@@ -178,7 +181,7 @@ else if ($type_of_search == "people")
 
 	    . "<td>".db_result($result,$i,'realname')."</td></tr>\n";
 	}
-      echo "</table>\n";
+      print "</table>\n";
     }
 
 }
@@ -225,9 +228,9 @@ else if ($type_of_search == "people")
       $title_arr[] = _("Author");
       $title_arr[] = _("Date");
 
-      echo html_build_list_table_top ($title_arr);
+      print html_build_list_table_top ($title_arr);
 
-      echo "\n";
+      print "\n";
 
       for ( $i = 0; $i < $rows; $i++ )
 	{
@@ -237,7 +240,7 @@ else if ($type_of_search == "people")
 	    . "<td>".db_result($result, $i, "user_name")."</td>"
 	    . "<td>".format_date($sys_datefmt,db_result($result,$i,"date"))."</td></tr>\n";
 	}
-      echo "</table>\n";
+      print "</table>\n";
     }
 
 } */
@@ -273,9 +276,9 @@ else if ($type_of_search == 'bugs' ||
       $title_arr[] = _("Submitted By");
       $title_arr[] = _("Date");
 
-      echo html_build_list_table_top ($title_arr);
+      print html_build_list_table_top ($title_arr);
 
-      echo "\n";
+      print "\n";
 
       $j;
       for ( $i = 0; $i < $rows; $i++ )
@@ -301,13 +304,13 @@ else if ($type_of_search == 'bugs' ||
 	      $j++;
 	    }
 	}
-      echo "</table>\n";
+      print "</table>\n";
     }
 }
 else
 {
   search_send_header();
-  echo '<h2 class="error">'._("Error").' - '._("Invalid Search!!").'</h1>';
+  print '<h2 class="error">'._("Error").' - '._("Invalid Search!!").'</h1>';
 
 }
 
@@ -316,7 +319,7 @@ $nextprev_url = $GLOBALS['sys_home']."search/?type_of_search=$type_of_search&amp
 if (isset($type))
 {  $nextprev_url .= "&amp;type=$type"; }
 if ($group_id)
-{  $nextprev_url .= "&amp;group_id=$group_id"; }
+{  $nextprev_url .= "&amp;only_group_id=$group_id"; }
 
 html_nextprev($nextprev_url,$rows,$rows_returned);
 
