@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: index.php,v 1.11 2005/06/30 17:19:37 toddy Exp $
+# $Id: index.php,v 1.16 2005/09/22 09:27:53 yeupou Exp $
 #
 #  Copyright 2004-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
 #                          Yves Perrin <yves.perrin--at--cern.ch>
@@ -52,26 +52,31 @@ else
 $since = mktime($hour,$min,0,$since_month, $since_day, $since_year);
 $until = mktime($hour,$min,0,$until_month, $until_day, $until_year);
 
-print '<p>&nbsp;&nbsp;</p>';
+$form_opening = '<form action="'.$PHP_SELF.'#options" method="GET">';
+$form_submit = '<input class="bold" value="'._("Apply").'" name="update" type="submit">';
+# I18N
+# The strings are two dates.
+# Example: "From 12. September 2005 till 14. September 2005"
+print html_show_displayoptions(sprintf(_("From %s till %s."),
+				       calendar_selectbox("day",$since_day,"since_day").calendar_selectbox("month",$since_month,"since_month").'<input type="text" value="'.addslashes($since_year).'" name="since_year" size="4" maxlength="4" />',
+				       
+				       calendar_selectbox("day",$until_day,"until_day").calendar_selectbox("month",$until_month,"until_month").'<input type="text" value="'.addslashes($until_year).'" name="until_year" size="4" maxlength="4" />'),
+			       $form_opening,
+			       $form_submit);
+
 print '
-<h3>'.html_anchor(sprintf(_("From %s till %s"),format_date($sys_datefmt,$since),format_date($sys_datefmt,$until)),"between").'</h3>';
+<p><h3>'.html_anchor(sprintf(_("From %s till %s"),format_date($sys_datefmt,$since),format_date($sys_datefmt,$until)),"between").'</h3>';
 
 if ($since > $until)
 {
   print '<p class="error">'._("Apparently, the period you asked for is incoherent.").'</p>';
 }
 
-print '<form action="'.$PHP_SELF.'#between" method="GET">';
-print sprintf(_("From %s till %s"),
-	      calendar_selectbox("day",$since_day,"since_day").calendar_selectbox("month",$since_month,"since_month").'<input type="text" value="'.addslashes($since_year).'" name="since_year" size="4" maxlength="4" />',
-	      calendar_selectbox("day",$until_day,"until_day").calendar_selectbox("month",$until_month,"until_month").'<input type="text" value="'.addslashes($until_year).'" name="until_year" size="4" maxlength="4" />');
-print ' <input value="'._("Apply").'" name="update" type="submit">';
-print '</form>';
 
 
 print '
 <h4>'._("Accounts:").'</h4>
-<p>';
+';
 
 $count_users = stats_getusers();
 $count_groups = stats_getprojects();
@@ -103,8 +108,8 @@ $total_support = stats_getitems("support");
 
 
 print '</p>
-<h4>'._("Trackers:").'</h4>
-<p>';
+<p><h4>'._("Trackers:").'</h4>
+';
 
 ### FIXME: ngettext force us to split several sentences in different bit.
 ### It may be severily unsuitable for proper translation.
@@ -211,11 +216,11 @@ print '<p>&nbsp;</p>';
 
 ##################### GENERAL
 print '
-<h3>'.html_anchor(_("General"),"general").'</h3>';
+<p><h3>'.html_anchor(_("General"),"general").'</h3>';
 
 print '
 <h4>'._("Accounts:").'</h4>
-<p>';
+';
 
 $content = array();
 
@@ -242,8 +247,8 @@ unset($content);
 
 
 print '</p>
-<h4>'._("Trackers:").'</h4>
-<p>';
+<p><h4>'._("Trackers:").'</h4>
+';
 
 $content = array();
 
@@ -323,7 +328,49 @@ graphs_build($content,0,0);
 unset($content);
 
 
-print "</p>\n";
+
+print '</p>
+<p><h4>'._("Themes:").'</h4>
+';
+
+# Get the more popular themes. 7 at most, all superior to 0%
+$themes_list = theme_list(1);
+$popular_themes = array();
+while (list(,$theme) = each($themes_list))
+{
+  # Get the number of users of the theme
+  unset($count);
+  $count = stats_getthemeusers($theme);
+  if ($theme == $GLOBALS['sys_themedefault'])
+    { 
+      # If it is the default theme, add the users that use the default
+      $count += stats_getthemeusers("");
+    }
+
+  # Compute the percentage of users using it
+  $percent = ($count / $count_users) * 100;
+  
+  # Store it only if superior to 0
+  if (round($percent))
+    {
+      $popular_themes[$theme] = $percent;
+    }
+}
+
+# Print the most popular theme
+arsort($popular_themes);
+unset($themes);
+while (list($theme,$percent) = each($popular_themes))
+{
+  if ($themes)
+    { $themes .= ", "; }
+  $themes .= sprintf(_("%s (%s%%)"), $theme, round($percent));
+}
+
+print sprintf(_("Most popular color themes are: %s."), $themes);
+
+print '
+</p>';
 
 site_footer(0);
 
